from .wordnet_a import wordnet_terms_a
from .wordnet_b import wordnet_terms_b
from .wordnet_c import wordnet_terms_c
from .wordnet_d import wordnet_terms_d
from .wordnet_e import wordnet_terms_e
from .wordnet_f import wordnet_terms_f
from .wordnet_g import wordnet_terms_g
from .wordnet_h import wordnet_terms_h
from .wordnet_i import wordnet_terms_i
from .wordnet_j import wordnet_terms_j
from .wordnet_k import wordnet_terms_k
from .wordnet_l import wordnet_terms_l
from .wordnet_m import wordnet_terms_m
from .wordnet_n import wordnet_terms_n
from .wordnet_o import wordnet_terms_o
from .wordnet_p import wordnet_terms_p
from .wordnet_q import wordnet_terms_q
from .wordnet_r import wordnet_terms_r
from .wordnet_s import wordnet_terms_s
from .wordnet_t import wordnet_terms_t
from .wordnet_u import wordnet_terms_u
from .wordnet_v import wordnet_terms_v
from .wordnet_w import wordnet_terms_w
from .wordnet_x import wordnet_terms_x
from .wordnet_y import wordnet_terms_y
from .wordnet_z import wordnet_terms_z
