
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

d_abbreviations = {
    'approx.': 'approximately',
    'appt.': 'appointment',
    'apt.': 'apartment',
    'ave.': 'avenue',
    'adj.': 'adjective',
    'adm.': 'administration',
    'abbr.': 'abbreviation',
    'abr.': 'abridged',
    'aka.': 'aka',
    'acad.': 'academic',
    'assoc.': 'association',
    'blvd.': 'boulevard',
    'biol.': 'biology',
    'bibliog.': 'bibliography',
    'bot.': 'botany',
    'cyn.': 'canyon',
    'cp.': 'compare',
    'cap.': 'capital',
    'chap.': 'chapter',
    'chem.': 'chemical',
    'co.': 'company',
    'colloq.': 'colloquial',
    'conf.': 'conference',
    'cont.': 'containing',
    'com.': 'commercial',
    'cr.': 'credit',
    'crit.': 'criticism',
    'dept.': 'department',
    'dr.': 'dr~~',
    'diff.': 'different',
    'def.': 'definition',
    'est.': 'established',
    'ea.': 'each',
    'e.g.': 'example',
    'etc.': 'etc',
    'gen.': 'general',
    'impt.': 'important',
    'ln.': 'lane',
    'mr.': 'mr~~',
    'min.': 'minute',
    'misc.': 'miscellaneous',
    'mrs.': 'mrs~~',
    'no.': 'number',
    'nec.': 'necessary',
    'rd.': 'road',
    're.': 'regarding',
    'st.': 'street',
    'sim.': 'similar',
    'tel.': 'telephone',
    'temp.': 'temp',
    'vet.': 'vet',
    'vs.': 'versus'
}
