
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_i_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.171458'}

wordnet_terms_i = [
    'ia',
    'iaa',
    'iaea',
    'iago',
    'iamb',
    'iambic',
    'iambs',
    'iambus',
    'ian',
    'ianfu',
    'iapetus',
    'iatrogenic',
    'ibadan',
    'iberia',
    'iberian',
    'iberis',
    'ibert',
    'ibex',
    'ibis',
    'ibises',
    'ibm',
    'ibrahim',
    'ibrd',
    'ibsen',
    'ibsenian',
    'ibuprofen',
    'ic',
    'icaco',
    'icao',
    'icarus',
    'icbm',
    'icc',
    'ice',
    'iceberg',
    'icebergs',
    'iceboat',
    'icebound',
    'icebox',
    'icebreaker',
    'icecap',
    'icecream',
    'iced',
    'icefall',
    'icehouse',
    'iceland',
    'icelander',
    'icelandic',
    'iceman',
    'icepick',
    'icetray',
    'ichneumon',
    'ichneumonidae',
    'ichor',
    'ichorous',
    'ichthyolatry',
    'ichthyologist',
    'ichthyology',
    'ichthyosaur',
    'ichthyosauria',
    'ichthyosauridae',
    'ichthyosaurs',
    'ichthyosaurus',
    'ichthyosis',
    'ichyostega',
    'icicle',
    'iciness',
    'icing',
    'icings',
    'icky',
    'icon',
    'iconic',
    'iconoclasm',
    'iconoclast',
    'iconoclastic',
    'iconography',
    'iconolatry',
    'iconology',
    'iconoscope',
    'icons',
    'icosahedral',
    'icosahedron',
    'icsh',
    'ictal',
    'ictalurus',
    'icteria',
    'icteric',
    'icteridae',
    'icterogenic',
    'icterus',
    'ictic',
    'ictiobus',
    'ictodosaur',
    'ictodosauria',
    'ictonyx',
    'ictus',
    'icu',
    'icy',
    'id',
    'ida',
    'idaho',
    'idahoan',
    'iddm',
    'idea',
    'ideal',
    'idealisation',
    'idealise',
    'idealised',
    'idealism',
    'idealist',
    'idealistic',
    'ideality',
    'idealization',
    'idealize',
    'idealized',
    'idealizes',
    'idealizing',
    'ideally',
    'idealogue',
    'ideals',
    'ideas',
    'ideate',
    'ideation',
    'ideational',
    'idempotent',
    'identical',
    'identically',
    'identicalness',
    'identifiable',
    'identification',
    'identified',
    'identifier',
    'identifies',
    'identify',
    'identifying',
    'identikit',
    'identities',
    'identity',
    'ideogram',
    'ideograms',
    'ideograph',
    'ideographic',
    'ideography',
    'ideologic',
    'ideological',
    'ideologies',
    'ideologist',
    'ideologue',
    'ideology',
    'ides',
    'idesia',
    'idf',
    'idiocy',
    'idiographic',
    'idiolatry',
    'idiolect',
    'idiom',
    'idiomatic',
    'idiomatical',
    'idiopathic',
    'idiopathy',
    'idiosyncrasy',
    'idiosyncratic',
    'idiot',
    'idiotic',
    'iditarod',
    'idle',
    'idleness',
    'idler',
    'idles',
    'idling',
    'idly',
    'ido',
    'idocrase',
    'idol',
    'idolater',
    'idolatress',
    'idolatrous',
    'idolatry',
    'idolisation',
    'idolise',
    'idolised',
    'idoliser',
    'idolization',
    'idolize',
    'idolized',
    'idolizer',
    'idolizes',
    'idols',
    'idp',
    'idun',
    'idwal',
    'idyl',
    'idyll',
    'idyllic',
    'idyllically',
    'ie',
    'ied',
    'if',
    'ifc',
    'iffy',
    'ig',
    'iga',
    'igbo',
    'igd',
    'ige',
    'igg',
    'igigi',
    'iglesias',
    'igloo',
    'iglu',
    'igm',
    'ignatius',
    'igneous',
    'ignescent',
    'ignitable',
    'ignite',
    'ignited',
    'igniter',
    'ignites',
    'ignitible',
    'igniting',
    'ignition',
    'ignitor',
    'ignobility',
    'ignoble',
    'ignobleness',
    'ignobly',
    'ignominious',
    'ignominiousness',
    'ignominy',
    'ignoramus',
    'ignorance',
    'ignorant',
    'ignorantness',
    'ignore',
    'ignored',
    'ignores',
    'ignoring',
    'iguana',
    'iguanas',
    'iguania',
    'iguanid',
    'iguanidae',
    'iguanodon',
    'iguanodons',
    'iguanodontidae',
    'iguassu',
    'iguazu',
    'ii',
    'iii',
    'iis',
    'ijssel',
    'ijsselmeer',
    'ijtihad',
    'ike',
    'ikhanaton',
    'ikon',
    'il',
    'ilama',
    'ileitis',
    'ileocolic',
    'ileostomy',
    'ileum',
    'ileus',
    'ilex',
    'iliac',
    'iliad',
    'iliamna',
    'ilion',
    'ilium',
    'ilk',
    'ill',
    'illampu',
    'illation',
    'illative',
    'illecebrum',
    'illegal',
    'illegalise',
    'illegality',
    'illegalize',
    'illegally',
    'illegibility',
    'illegible',
    'illegitimacy',
    'illegitimate',
    'illiberal',
    'illiberality',
    'illicit',
    'illicitly',
    'illicitness',
    'illicium',
    'illimani',
    'illimitable',
    'illinois',
    'illinoisan',
    'illiteracy',
    'illiterate',
    'illness',
    'illnesses',
    'illogic',
    'illogical',
    'illogicality',
    'illogicalness',
    'ills',
    'illume',
    'illuminance',
    'illuminant',
    'illuminate',
    'illuminated',
    'illuminating',
    'illumination',
    'illumine',
    'illusion',
    'illusional',
    'illusionary',
    'illusionist',
    'illusions',
    'illusive',
    'illusory',
    'illustrate',
    'illustrated',
    'illustrates',
    'illustrating',
    'illustration',
    'illustrations',
    'illustrative',
    'illustrator',
    'illustrious',
    'illustriousness',
    'illyria',
    'illyrian',
    'ilmen',
    'ilmenite',
    'ilo',
    'ilosone',
    'ilx',
    'ilxx',
    'ilxxx',
    'image',
    'imagery',
    'images',
    'imaginable',
    'imaginary',
    'imagination',
    'imaginative',
    'imaginativeness',
    'imagine',
    'imagined',
    'imaging',
    'imagism',
    'imago',
    'imam',
    'imaret',
    'imaum',
    'imavate',
    'imbalance',
    'imbalanced',
    'imbauba',
    'imbecile',
    'imbecilic',
    'imbecility',
    'imbed',
    'imbibe',
    'imbiber',
    'imbibing',
    'imbibition',
    'imbricate',
    'imbricated',
    'imbrication',
    'imbroglio',
    'imbrue',
    'imbue',
    'imbued',
    'imf',
    'imidazole',
    'imide',
    'iminazole',
    'imipramine',
    'imitate',
    'imitated',
    'imitates',
    'imitating',
    'imitation',
    'imitations',
    'imitative',
    'imitator',
    'immaculate',
    'immaculately',
    'immaculateness',
    'immanence',
    'immanency',
    'immanent',
    'immanuel',
    'immaterial',
    'immaterialise',
    'immateriality',
    'immaterialize',
    'immature',
    'immatureness',
    'immaturity',
    'immeasurable',
    'immeasurably',
    'immediacy',
    'immediate',
    'immediately',
    'immediateness',
    'immense',
    'immensely',
    'immenseness',
    'immensity',
    'immensurable',
    'immerse',
    'immersed',
    'immersing',
    'immersion',
    'immigrant',
    'immigrants',
    'immigrate',
    'immigrated',
    'immigration',
    'imminence',
    'imminency',
    'imminent',
    'imminentness',
    'immingle',
    'immiscible',
    'immix',
    'immobile',
    'immobilisation',
    'immobilise',
    'immobility',
    'immobilization',
    'immobilize',
    'immobilized',
    'immobilizes',
    'immobilizing',
    'immoderate',
    'immoderately',
    'immoderateness',
    'immoderation',
    'immodest',
    'immodesty',
    'immolate',
    'immolated',
    'immolation',
    'immoral',
    'immorality',
    'immortal',
    'immortalise',
    'immortality',
    'immortalize',
    'immortalized',
    'immortals',
    'immortelle',
    'immotile',
    'immotility',
    'immovability',
    'immovable',
    'immovableness',
    'immovably',
    'immoveable',
    'immune',
    'immunisation',
    'immunise',
    'immunised',
    'immunity',
    'immunization',
    'immunize',
    'immunized',
    'immunoassay',
    'immunochemical',
    'immunochemistry',
    'immunocompetence',
    'immunocompetent',
    'immunocompromised',
    'immunodeficiency',
    'immunodeficient',
    'immunoelectrophoresis',
    'immunofluorescence',
    'immunogen',
    'immunogenic',
    'immunogenicity',
    'immunoglobulin',
    'immunoglobulins',
    'immunohistochemistry',
    'immunologic',
    'immunological',
    'immunologically',
    'immunologist',
    'immunology',
    'immunopathology',
    'immunosuppressant',
    'immunosuppressed',
    'immunosuppression',
    'immunosuppressive',
    'immunosuppressor',
    'immunotherapeutic',
    'immunotherapy',
    'immure',
    'immurement',
    'immutability',
    'immutable',
    'immutableness',
    'imo',
    'imp',
    'impact',
    'impacted',
    'impaction',
    'impacts',
    'impair',
    'impaired',
    'impairer',
    'impairers',
    'impairing',
    'impairment',
    'impairments',
    'impairs',
    'impala',
    'impalas',
    'impale',
    'impaled',
    'impalement',
    'impaling',
    'impalpability',
    'impalpable',
    'impanel',
    'imparipinnate',
    'impart',
    'impartation',
    'imparted',
    'impartial',
    'impartiality',
    'impartially',
    'imparting',
    'imparts',
    'impassable',
    'impasse',
    'impassioned',
    'impassive',
    'impassiveness',
    'impassivity',
    'impasto',
    'impatience',
    'impatient',
    'impatiently',
    'impeach',
    'impeachability',
    'impeached',
    'impeachment',
    'impeccability',
    'impeccable',
    'impeccant',
    'impecunious',
    'impecuniousness',
    'impedance',
    'impede',
    'impeded',
    'impedes',
    'impediment',
    'impedimenta',
    'impeding',
    'impel',
    'impelled',
    'impellent',
    'impeller',
    'impelling',
    'impend',
    'impendence',
    'impendency',
    'impendent',
    'impending',
    'impenetrability',
    'impenetrable',
    'impenetrableness',
    'impenitence',
    'impenitency',
    'impenitent',
    'imperative',
    'imperativeness',
    'imperceptibility',
    'imperceptible',
    'imperceptibly',
    'imperfect',
    'imperfectibility',
    'imperfectible',
    'imperfection',
    'imperfections',
    'imperfective',
    'imperfectly',
    'imperfectness',
    'imperforate',
    'imperial',
    'imperialism',
    'imperialist',
    'imperialistic',
    'imperil',
    'imperious',
    'imperiousness',
    'imperishability',
    'imperishable',
    'imperishableness',
    'imperishingness',
    'imperium',
    'impermanence',
    'impermanency',
    'impermanent',
    'impermeability',
    'impermeable',
    'impermeableness',
    'impermissibility',
    'impermissible',
    'impersonal',
    'impersonate',
    'impersonates',
    'impersonation',
    'impersonator',
    'impertinence',
    'impertinent',
    'imperturbability',
    'imperturbable',
    'imperturbableness',
    'imperviable',
    'impervious',
    'imperviousness',
    'impetiginous',
    'impetigo',
    'impetuosity',
    'impetuous',
    'impetuousness',
    'impetus',
    'impiety',
    'impinge',
    'impingement',
    'impinges',
    'impinging',
    'impious',
    'impiousness',
    'impish',
    'impishness',
    'implacable',
    'implant',
    'implantation',
    'implanted',
    'implanting',
    'implants',
    'implausibility',
    'implausible',
    'implausibleness',
    'implement',
    'implemental',
    'implementation',
    'implemented',
    'implementing',
    'implements',
    'implicate',
    'implicated',
    'implicates',
    'implication',
    'implicational',
    'implications',
    'implicative',
    'implicit',
    'implicitness',
    'implied',
    'implies',
    'implike',
    'implode',
    'implore',
    'imploring',
    'implosion',
    'imply',
    'implying',
    'impolicy',
    'impolite',
    'impolitely',
    'impoliteness',
    'impolitic',
    'imponderable',
    'import',
    'importance',
    'important',
    'importation',
    'imported',
    'importee',
    'importer',
    'importing',
    'imports',
    'importunate',
    'importune',
    'importunity',
    'impose',
    'imposed',
    'imposes',
    'imposing',
    'imposingly',
    'imposition',
    'impossibility',
    'impossible',
    'impossibleness',
    'impossibly',
    'impost',
    'imposter',
    'impostor',
    'imposture',
    'impotence',
    'impotency',
    'impotent',
    'impound',
    'impounded',
    'impounding',
    'impoundment',
    'impoverish',
    'impoverished',
    'impoverishment',
    'impracticability',
    'impracticable',
    'impracticableness',
    'impractical',
    'impracticality',
    'imprecate',
    'imprecation',
    'imprecations',
    'imprecise',
    'impreciseness',
    'imprecision',
    'impregnability',
    'impregnable',
    'impregnate',
    'impregnated',
    'impregnates',
    'impregnation',
    'impresario',
    'impress',
    'impressed',
    'impressible',
    'impressing',
    'impression',
    'impressionable',
    'impressionism',
    'impressionist',
    'impressionistic',
    'impressionists',
    'impressions',
    'impressive',
    'impressively',
    'impressiveness',
    'impressment',
    'imprimatur',
    'imprint',
    'imprinted',
    'imprinting',
    'imprints',
    'imprison',
    'imprisoned',
    'imprisoning',
    'imprisonment',
    'improbability',
    'improbable',
    'improbableness',
    'impromptu',
    'improper',
    'improperly',
    'improperness',
    'impropriety',
    'improvable',
    'improve',
    'improved',
    'improvement',
    'improvements',
    'improver',
    'improves',
    'improvidence',
    'improvident',
    'improving',
    'improvisation',
    'improvise',
    'improvised',
    'improvising',
    'improvize',
    'imprudence',
    'imprudent',
    'imprudently',
    'impudence',
    'impudent',
    'impudently',
    'impugn',
    'impugnable',
    'impuissance',
    'impuissant',
    'impulse',
    'impulses',
    'impulsion',
    'impulsive',
    'impulsiveness',
    'impunity',
    'impure',
    'impureness',
    'impurities',
    'impurity',
    'imputable',
    'imputation',
    'impute',
    'imputed',
    'imputes',
    'imputing',
    'imputrescible',
    'imu',
    'imuran',
    'in',
    'inability',
    'inaccessibility',
    'inaccessible',
    'inaccessibly',
    'inaccuracy',
    'inaccurate',
    'inachis',
    'inaction',
    'inactivate',
    'inactivated',
    'inactivates',
    'inactivation',
    'inactive',
    'inactiveness',
    'inactivity',
    'inadequacy',
    'inadequate',
    'inadequately',
    'inadequateness',
    'inadmissibility',
    'inadmissible',
    'inadvertence',
    'inadvertency',
    'inadvertent',
    'inadvertently',
    'inadvisability',
    'inadvisable',
    'inaesthetic',
    'inalienable',
    'inalienably',
    'inalterable',
    'inamorata',
    'inamorato',
    'inane',
    'inanimate',
    'inanimateness',
    'inanition',
    'inanity',
    'inanna',
    'inapplicability',
    'inapplicable',
    'inapposite',
    'inappositeness',
    'inappreciable',
    'inappropriate',
    'inappropriately',
    'inappropriateness',
    'inapt',
    'inaptitude',
    'inaptness',
    'inarguable',
    'inarticulate',
    'inartistic',
    'inasmuch',
    'inattention',
    'inattentive',
    'inattentiveness',
    'inaudibility',
    'inaudible',
    'inaudibleness',
    'inaugural',
    'inaugurate',
    'inaugurated',
    'inauguration',
    'inauspicious',
    'inauspiciousness',
    'inauthentic',
    'inboard',
    'inborn',
    'inbound',
    'inbred',
    'inbreeding',
    'inbuilt',
    'inc',
    'inca',
    'incalculable',
    'incalescence',
    'incan',
    'incandesce',
    'incandescence',
    'incandescent',
    'incandescing',
    'incantation',
    'incantations',
    'incapability',
    'incapable',
    'incapableness',
    'incapacitate',
    'incapacitated',
    'incapacitating',
    'incapacity',
    'incarcerate',
    'incarcerated',
    'incarceration',
    'incarnadine',
    'incarnate',
    'incarnated',
    'incarnation',
    'incas',
    'incase',
    'incased',
    'incasement',
    'incaution',
    'incautious',
    'incautiousness',
    'incendiarism',
    'incendiary',
    'incense',
    'incensed',
    'incentive',
    'inception',
    'inceptive',
    'incertain',
    'incertitude',
    'incessancy',
    'incessant',
    'incessantly',
    'incessantness',
    'incest',
    'incestuous',
    'inch',
    'incheon',
    'inches',
    'inchoate',
    'inchoative',
    'inchon',
    'inchworm',
    'incidence',
    'incident',
    'incidental',
    'incidentally',
    'incidents',
    'incienso',
    'incinerate',
    'incinerated',
    'incinerates',
    'incinerating',
    'incineration',
    'incinerator',
    'incipience',
    'incipiency',
    'incipient',
    'incise',
    'incised',
    'incision',
    'incisions',
    'incisive',
    'incisiveness',
    'incisor',
    'incisors',
    'incisura',
    'incisure',
    'incitation',
    'incite',
    'incitement',
    'inciter',
    'incites',
    'inciting',
    'incitive',
    'incivility',
    'inclemency',
    'inclement',
    'inclementness',
    'inclination',
    'inclinations',
    'incline',
    'inclined',
    'inclines',
    'inclining',
    'inclinometer',
    'inclose',
    'inclosure',
    'include',
    'included',
    'includes',
    'including',
    'inclusion',
    'inclusive',
    'incognizable',
    'incognizance',
    'incognizant',
    'incognoscible',
    'incoherence',
    'incoherency',
    'incoherent',
    'incombustible',
    'income',
    'incomes',
    'incoming',
    'incommensurable',
    'incommensurate',
    'incommode',
    'incommodious',
    'incommodiousness',
    'incommunicado',
    'incommunicative',
    'incommutability',
    'incommutable',
    'incomparable',
    'incompatibility',
    'incompatible',
    'incompetence',
    'incompetency',
    'incompetent',
    'incomplete',
    'incompletely',
    'incompleteness',
    'incomprehensibility',
    'incomprehensible',
    'incomprehension',
    'incomprehensive',
    'incompressibility',
    'incompressible',
    'incomputable',
    'inconceivability',
    'inconceivable',
    'inconceivableness',
    'inconceivably',
    'inconclusive',
    'inconclusiveness',
    'inconel',
    'incongruent',
    'incongruity',
    'incongruous',
    'incongruousness',
    'inconsequence',
    'inconsequent',
    'inconsequential',
    'inconsiderable',
    'inconsiderate',
    'inconsiderately',
    'inconsiderateness',
    'inconsideration',
    'inconsistencies',
    'inconsistency',
    'inconsistent',
    'inconsolable',
    'inconspicuous',
    'inconspicuously',
    'inconspicuousness',
    'inconstancy',
    'inconstant',
    'incontestable',
    'incontestible',
    'incontinence',
    'incontinency',
    'incontinent',
    'incontrovertibility',
    'incontrovertible',
    'incontrovertibleness',
    'inconvenience',
    'inconvenienced',
    'inconvenient',
    'inconveniently',
    'inconvertibility',
    'inconvertible',
    'incoordination',
    'incorporate',
    'incorporated',
    'incorporates',
    'incorporating',
    'incorporation',
    'incorporative',
    'incorporeal',
    'incorporeality',
    'incorrect',
    'incorrectly',
    'incorrectness',
    'incorrigible',
    'incorrigibly',
    'incorrupt',
    'incorrupted',
    'incorruptibility',
    'incorruptible',
    'incorruption',
    'incorruptness',
    'increase',
    'increased',
    'increases',
    'increasing',
    'increasingly',
    'incredibility',
    'incredible',
    'incredibleness',
    'incredulity',
    'incredulous',
    'increment',
    'incremental',
    'increments',
    'incriminate',
    'incriminates',
    'incriminating',
    'incrimination',
    'incriminatory',
    'incrust',
    'incrustation',
    'incubate',
    'incubates',
    'incubation',
    'incubator',
    'incubus',
    'inculcate',
    'inculcation',
    'inculpability',
    'inculpable',
    'inculpableness',
    'inculpate',
    'inculpation',
    'inculpative',
    'inculpatory',
    'incumbency',
    'incumbent',
    'incumbrance',
    'incur',
    'incurability',
    'incurable',
    'incurableness',
    'incurably',
    'incurious',
    'incurred',
    'incurrence',
    'incurring',
    'incursion',
    'incursive',
    'incurvate',
    'incurvates',
    'incurvation',
    'incurvature',
    'incurved',
    'incus',
    'indaba',
    'indapamide',
    'indebted',
    'indebtedness',
    'indecency',
    'indecent',
    'indecipherable',
    'indecision',
    'indecisive',
    'indecisiveness',
    'indecorous',
    'indecorousness',
    'indecorum',
    'indefatigability',
    'indefatigable',
    'indefatigableness',
    'indefeasible',
    'indefensible',
    'indefinable',
    'indefinite',
    'indefinitely',
    'indefiniteness',
    'indefinity',
    'indehiscent',
    'indelible',
    'indelicacy',
    'indelicate',
    'indemnification',
    'indemnifies',
    'indemnify',
    'indemnity',
    'indene',
    'indent',
    'indentation',
    'indentations',
    'indented',
    'indention',
    'indenture',
    'indentured',
    'independence',
    'independency',
    'independent',
    'independently',
    'inderal',
    'indescribable',
    'indestructibility',
    'indestructible',
    'indeterminable',
    'indeterminacy',
    'indeterminate',
    'indeterminateness',
    'indetermination',
    'index',
    'indexation',
    'indexed',
    'indexer',
    'indexes',
    'indexical',
    'indexing',
    'indexless',
    'india',
    'indiaman',
    'indian',
    'indiana',
    'indianan',
    'indianapolis',
    'indians',
    'indic',
    'indicant',
    'indicants',
    'indicate',
    'indicated',
    'indicates',
    'indicating',
    'indication',
    'indications',
    'indicative',
    'indicator',
    'indicatoridae',
    'indicators',
    'indicatory',
    'indict',
    'indictability',
    'indictable',
    'indicted',
    'indiction',
    'indictment',
    'indictments',
    'indicus',
    'indie',
    'indies',
    'indifference',
    'indifferent',
    'indigen',
    'indigence',
    'indigene',
    'indigenous',
    'indigenousness',
    'indigent',
    'indigestibility',
    'indigestible',
    'indigestibleness',
    'indigestion',
    'indigirka',
    'indignant',
    'indignation',
    'indignity',
    'indigo',
    'indigofera',
    'indigotin',
    'indinavir',
    'indirect',
    'indirection',
    'indirections',
    'indirectly',
    'indirectness',
    'indiscernible',
    'indiscipline',
    'indiscreet',
    'indiscreetly',
    'indiscreetness',
    'indiscrete',
    'indiscretion',
    'indiscretions',
    'indiscriminate',
    'indiscriminately',
    'indiscriminating',
    'indispensability',
    'indispensable',
    'indispensableness',
    'indispose',
    'indisposed',
    'indisposition',
    'indisputability',
    'indisputable',
    'indissoluble',
    'indistinct',
    'indistinctly',
    'indistinctness',
    'indistinguishability',
    'indistinguishable',
    'indite',
    'indium',
    'individual',
    'individualisation',
    'individualise',
    'individualised',
    'individualism',
    'individualist',
    'individualistic',
    'individualistically',
    'individuality',
    'individualization',
    'individualize',
    'individualized',
    'individually',
    'individuals',
    'individuate',
    'individuates',
    'individuating',
    'individuation',
    'indivisible',
    'indochina',
    'indocile',
    'indocin',
    'indoctrinate',
    'indoctrination',
    'indolence',
    'indolent',
    'indomethacin',
    'indomitability',
    'indomitable',
    'indonesia',
    'indonesian',
    'indoor',
    'indoors',
    'indorse',
    'indorsement',
    'indorser',
    'indra',
    'indrawn',
    'indri',
    'indriidae',
    'indris',
    'indubitability',
    'indubitable',
    'induce',
    'induced',
    'inducement',
    'inducer',
    'induces',
    'inducing',
    'inducive',
    'induct',
    'inductance',
    'inducted',
    'inductee',
    'inductees',
    'induction',
    'inductive',
    'inductor',
    'indue',
    'indulge',
    'indulged',
    'indulgence',
    'indulgences',
    'indulgent',
    'indulges',
    'indulging',
    'indument',
    'indumentum',
    'indurate',
    'induration',
    'indus',
    'indusia',
    'indusial',
    'indusium',
    'industrial',
    'industrialisation',
    'industrialise',
    'industrialised',
    'industrialism',
    'industrialist',
    'industrialization',
    'industrialize',
    'industrialized',
    'industries',
    'industrious',
    'industriousness',
    'industry',
    'indwell',
    'indweller',
    'indwelling',
    'inebriant',
    'inebriate',
    'inebriated',
    'inebriation',
    'inebriety',
    'inedible',
    'ineffable',
    'ineffective',
    'ineffectiveness',
    'ineffectual',
    'ineffectuality',
    'ineffectualness',
    'inefficacious',
    'inefficaciousness',
    'inefficacy',
    'inefficiency',
    'inefficient',
    'inefficiently',
    'inelaborate',
    'inelastic',
    'inelasticity',
    'inelegance',
    'inelegant',
    'ineligibility',
    'ineligible',
    'ineluctability',
    'ineluctable',
    'inept',
    'ineptitude',
    'ineptness',
    'inequality',
    'inequitable',
    'inequities',
    'inequity',
    'ineradicable',
    'inerrable',
    'inerrancy',
    'inerrant',
    'inert',
    'inertia',
    'inertial',
    'inertness',
    'inescapable',
    'inessential',
    'inessentiality',
    'inestimable',
    'inevitability',
    'inevitable',
    'inevitableness',
    'inevitably',
    'inexact',
    'inexactitude',
    'inexactness',
    'inexcusable',
    'inexhaustible',
    'inexorability',
    'inexorable',
    'inexorableness',
    'inexpedience',
    'inexpediency',
    'inexpedient',
    'inexpensive',
    'inexpensiveness',
    'inexperience',
    'inexperienced',
    'inexperient',
    'inexpert',
    'inexpiable',
    'inexplicable',
    'inexplicit',
    'inexplicitness',
    'inexpressible',
    'inexpressibly',
    'inexpressive',
    'inexpugnable',
    'inexpungeable',
    'inexpungible',
    'inextensible',
    'inexterminable',
    'inextinguishable',
    'inextirpable',
    'inextricable',
    'infallibility',
    'infallible',
    'infamous',
    'infamy',
    'infancy',
    'infant',
    'infanticide',
    'infantile',
    'infantilism',
    'infantry',
    'infantryman',
    'infantrymen',
    'infants',
    'infarct',
    'infarction',
    'infatuate',
    'infatuated',
    'infatuation',
    'infatuations',
    'infeasibility',
    'infeasible',
    'infect',
    'infected',
    'infecting',
    'infection',
    'infections',
    'infectious',
    'infective',
    'infects',
    'infelicitous',
    'infelicity',
    'infer',
    'inference',
    'inferences',
    'inferential',
    'inferior',
    'inferiority',
    'inferiors',
    'infernal',
    'infernals',
    'inferno',
    'inferred',
    'inferring',
    'infertile',
    'infertility',
    'infest',
    'infestans',
    'infestation',
    'infestations',
    'infested',
    'infesting',
    'infests',
    'infidel',
    'infidelity',
    'infield',
    'infielder',
    'infiltrate',
    'infiltrated',
    'infiltration',
    'infiltrator',
    'infinite',
    'infinitely',
    'infiniteness',
    'infinitesimal',
    'infinitival',
    'infinitive',
    'infinitude',
    'infinity',
    'infirm',
    'infirmary',
    'infirmity',
    'infix',
    'inflame',
    'inflamed',
    'inflaming',
    'inflammability',
    'inflammable',
    'inflammation',
    'inflammatory',
    'inflatable',
    'inflate',
    'inflated',
    'inflater',
    'inflates',
    'inflation',
    'inflationary',
    'inflator',
    'inflect',
    'inflected',
    'inflection',
    'inflectional',
    'inflections',
    'inflexibility',
    'inflexible',
    'inflexibleness',
    'inflexibly',
    'inflexion',
    'inflict',
    'inflicted',
    'inflicting',
    'infliction',
    'inflicts',
    'infliximab',
    'inflorescence',
    'inflorescences',
    'inflow',
    'inflowing',
    'influence',
    'influenced',
    'influences',
    'influencing',
    'influent',
    'influential',
    'influenza',
    'influx',
    'info',
    'infolding',
    'infomercial',
    'inform',
    'informal',
    'informality',
    'informally',
    'informant',
    'informatics',
    'information',
    'informational',
    'informative',
    'informatory',
    'informed',
    'informer',
    'informercial',
    'informing',
    'informs',
    'infotainment',
    'infra',
    'infract',
    'infraction',
    'infrahuman',
    'inframaxillary',
    'infrangible',
    'infrared',
    'infrasonic',
    'infrastructure',
    'infrequency',
    'infrequent',
    'infrequently',
    'infrigidation',
    'infringe',
    'infringement',
    'infructescence',
    'infundibulum',
    'infuriate',
    'infuriated',
    'infuriating',
    'infuriation',
    'infuscate',
    'infuse',
    'infused',
    'infuses',
    'infusing',
    'infusion',
    'infusions',
    'infusoria',
    'infusorian',
    'inga',
    'ingathering',
    'inge',
    'ingeminate',
    'ingenious',
    'ingeniousness',
    'ingenue',
    'ingenuity',
    'ingenuous',
    'ingenuousness',
    'inger',
    'ingerman',
    'ingest',
    'ingesta',
    'ingested',
    'ingesting',
    'ingestion',
    'ingests',
    'inglenook',
    'inglorious',
    'ingot',
    'ingots',
    'ingraft',
    'ingrain',
    'ingrained',
    'ingraining',
    'ingrate',
    'ingratiate',
    'ingratiating',
    'ingratiation',
    'ingratiatory',
    'ingratitude',
    'ingredient',
    'ingredients',
    'ingres',
    'ingress',
    'ingrian',
    'ingroup',
    'ingrowing',
    'ingrown',
    'ingrowth',
    'inguen',
    'inguinal',
    'inguinale',
    'ingurgitate',
    'inh',
    'inhabit',
    'inhabitable',
    'inhabitancy',
    'inhabitant',
    'inhabitants',
    'inhabitation',
    'inhabited',
    'inhabiting',
    'inhabits',
    'inhalant',
    'inhalation',
    'inhalator',
    'inhale',
    'inhaled',
    'inhaler',
    'inhales',
    'inhaling',
    'inharmonic',
    'inharmonious',
    'inharmoniousness',
    'inhere',
    'inherence',
    'inherency',
    'inherent',
    'inherently',
    'inheres',
    'inherit',
    'inheritable',
    'inheritance',
    'inherited',
    'inheriting',
    'inheritor',
    'inheritress',
    'inheritrix',
    'inherits',
    'inhibit',
    'inhibited',
    'inhibiting',
    'inhibition',
    'inhibitor',
    'inhibitors',
    'inhibitory',
    'inhibits',
    'inhomogeneity',
    'inhomogeneous',
    'inhospitable',
    'inhospitableness',
    'inhospitality',
    'inhuman',
    'inhumane',
    'inhumaneness',
    'inhumanity',
    'inhumation',
    'inhume',
    'inhumed',
    'inimical',
    'inimitable',
    'inion',
    'iniquitous',
    'iniquity',
    'initial',
    'initialisation',
    'initialise',
    'initialism',
    'initialization',
    'initialize',
    'initially',
    'initials',
    'initiate',
    'initiated',
    'initiates',
    'initiating',
    'initiation',
    'initiative',
    'initiator',
    'initiatory',
    'inject',
    'injectable',
    'injectant',
    'injected',
    'injecting',
    'injection',
    'injections',
    'injector',
    'injects',
    'injudicious',
    'injudiciousness',
    'injun',
    'injunction',
    'injunctions',
    'injure',
    'injured',
    'injures',
    'injuries',
    'injuring',
    'injurious',
    'injuriousness',
    'injury',
    'injustice',
    'injustices',
    'ink',
    'inka',
    'inkberry',
    'inkblot',
    'inked',
    'inkeles',
    'inkiness',
    'inkle',
    'inkling',
    'inkpad',
    'inkpot',
    'inks',
    'inkstand',
    'inkwell',
    'inky',
    'inla',
    'inlaid',
    'inland',
    'inlay',
    'inlaying',
    'inlays',
    'inlet',
    'inmarriage',
    'inmarry',
    'inmate',
    'inmates',
    'inmost',
    'inn',
    'innards',
    'innate',
    'innately',
    'innateness',
    'inner',
    'innermost',
    'innersole',
    'innervate',
    'innervated',
    'innervating',
    'innervation',
    'inning',
    'innings',
    'innkeeper',
    'innocence',
    'innocencies',
    'innocency',
    'innocense',
    'innocent',
    'innocuous',
    'innominate',
    'innovate',
    'innovation',
    'innovational',
    'innovations',
    'innovative',
    'innovativeness',
    'innovator',
    'innoxious',
    'innsbruck',
    'innuendo',
    'innumerable',
    'innumerableness',
    'innumerate',
    'innumerous',
    'inocor',
    'inoculant',
    'inoculate',
    'inoculated',
    'inoculates',
    'inoculating',
    'inoculation',
    'inoculator',
    'inoculum',
    'inodorous',
    'inoffensive',
    'inoperable',
    'inoperative',
    'inopportune',
    'inopportuneness',
    'inordinate',
    'inordinateness',
    'inorganic',
    'inosculate',
    'inosculation',
    'inosine',
    'inositol',
    'inpatient',
    'inpour',
    'inpouring',
    'input',
    'inputs',
    'inquest',
    'inquietude',
    'inquire',
    'inquired',
    'inquirer',
    'inquiries',
    'inquiring',
    'inquiringly',
    'inquiry',
    'inquisition',
    'inquisitive',
    'inquisitively',
    'inquisitiveness',
    'inquisitor',
    'inquisitorial',
    'inquisitory',
    'inr',
    'inroad',
    'inroads',
    'inrush',
    'ins',
    'insalubrious',
    'insalubriousness',
    'insalubrity',
    'insane',
    'insanely',
    'insaneness',
    'insanitary',
    'insanity',
    'insatiable',
    'insatiably',
    'insatiate',
    'inscribe',
    'inscribed',
    'inscribing',
    'inscription',
    'inscriptions',
    'inscriptive',
    'inscrutability',
    'inscrutable',
    'insect',
    'insecta',
    'insectan',
    'insecticidal',
    'insecticide',
    'insecticides',
    'insectifuge',
    'insectivora',
    'insectivore',
    'insectivores',
    'insectivorous',
    'insects',
    'insecure',
    'insecureness',
    'insecurity',
    'inseminate',
    'inseminated',
    'insemination',
    'insensate',
    'insensibility',
    'insensible',
    'insensitive',
    'insensitiveness',
    'insensitivity',
    'insentience',
    'insentient',
    'inseparable',
    'inseparably',
    'insert',
    'inserted',
    'inserting',
    'insertion',
    'insertions',
    'inserts',
    'insessores',
    'inset',
    'inshore',
    'inside',
    'insider',
    'insidious',
    'insidiousness',
    'insight',
    'insightful',
    'insightfulness',
    'insights',
    'insignia',
    'insignificance',
    'insignificant',
    'insignificantly',
    'insincere',
    'insincerely',
    'insincerity',
    'insinuate',
    'insinuated',
    'insinuating',
    'insinuation',
    'insipid',
    'insipidity',
    'insipidness',
    'insipidus',
    'insist',
    'insisted',
    'insistence',
    'insistency',
    'insistent',
    'insistently',
    'insisting',
    'insists',
    'insobriety',
    'insolate',
    'insolation',
    'insole',
    'insolence',
    'insolent',
    'insolubility',
    'insoluble',
    'insolvable',
    'insolvency',
    'insolvent',
    'insomnia',
    'insomniac',
    'insouciance',
    'insouciant',
    'inspan',
    'inspect',
    'inspected',
    'inspecting',
    'inspection',
    'inspections',
    'inspector',
    'inspectorate',
    'inspectors',
    'inspectorship',
    'inspects',
    'inspiration',
    'inspirational',
    'inspirations',
    'inspiratory',
    'inspire',
    'inspired',
    'inspirer',
    'inspires',
    'inspiring',
    'inspirit',
    'inspiriting',
    'inspissate',
    'inspissation',
    'inst',
    'instability',
    'instal',
    'install',
    'installation',
    'installations',
    'installed',
    'installing',
    'installment',
    'installments',
    'installs',
    'instalment',
    'instance',
    'instances',
    'instancy',
    'instant',
    'instantaneous',
    'instantaneously',
    'instantaneousness',
    'instantiate',
    'instantiates',
    'instantiation',
    'instantiations',
    'instantly',
    'instants',
    'instar',
    'instauration',
    'instead',
    'instep',
    'instigant',
    'instigate',
    'instigated',
    'instigates',
    'instigation',
    'instigative',
    'instigator',
    'instil',
    'instill',
    'instillation',
    'instillator',
    'instilled',
    'instilling',
    'instillment',
    'instilment',
    'instinct',
    'instinctive',
    'instinctively',
    'instincts',
    'institute',
    'instituted',
    'institutes',
    'institution',
    'institutional',
    'institutionalise',
    'institutionalised',
    'institutionalize',
    'institutionalized',
    'institutions',
    'instroke',
    'instruct',
    'instructed',
    'instructing',
    'instruction',
    'instructional',
    'instructions',
    'instructive',
    'instructor',
    'instructors',
    'instructorship',
    'instructress',
    'instructs',
    'instrument',
    'instrumental',
    'instrumentalism',
    'instrumentalist',
    'instrumentalists',
    'instrumentalities',
    'instrumentality',
    'instrumentate',
    'instrumentation',
    'instruments',
    'insubordinate',
    'insubordination',
    'insubstantial',
    'insubstantiality',
    'insufferable',
    'insufferably',
    'insufficiencies',
    'insufficiency',
    'insufficient',
    'insufficiently',
    'insufflate',
    'insufflation',
    'insulant',
    'insular',
    'insularism',
    'insularity',
    'insulate',
    'insulated',
    'insulates',
    'insulating',
    'insulation',
    'insulator',
    'insulators',
    'insulin',
    'insult',
    'insulted',
    'insulting',
    'insults',
    'insuperable',
    'insupportable',
    'insurability',
    'insurable',
    'insurance',
    'insure',
    'insured',
    'insurer',
    'insures',
    'insurgence',
    'insurgency',
    'insurgent',
    'insurgents',
    'insuring',
    'insurmountable',
    'insurrection',
    'insurrectional',
    'insurrectionary',
    'insurrectionism',
    'insurrectionist',
    'insusceptible',
    'intact',
    'intactness',
    'intaglio',
    'intake',
    'intangibility',
    'intangible',
    'intangibleness',
    'integer',
    'integers',
    'integral',
    'integrality',
    'integrals',
    'integrate',
    'integrated',
    'integrates',
    'integrating',
    'integration',
    'integrative',
    'integrator',
    'integrity',
    'integument',
    'integumental',
    'integumentary',
    'intellect',
    'intellection',
    'intellects',
    'intellectual',
    'intellectualisation',
    'intellectualization',
    'intellectually',
    'intellectuals',
    'intelligence',
    'intelligent',
    'intelligently',
    'intelligentsia',
    'intelligibility',
    'intelligible',
    'intelnet',
    'intemperance',
    'intemperate',
    'intemperateness',
    'intend',
    'intended',
    'intending',
    'intends',
    'intense',
    'intensely',
    'intensification',
    'intensified',
    'intensifier',
    'intensify',
    'intensifying',
    'intension',
    'intensional',
    'intensity',
    'intensive',
    'intensively',
    'intensiveness',
    'intensol',
    'intent',
    'intention',
    'intentional',
    'intentionality',
    'intentionally',
    'intentions',
    'intently',
    'intentness',
    'inter',
    'interact',
    'interacting',
    'interaction',
    'interactional',
    'interactions',
    'interactive',
    'interacts',
    'interahamwe',
    'interbrain',
    'interbred',
    'interbreed',
    'interbreeding',
    'interbreeds',
    'intercalary',
    'intercalate',
    'intercalation',
    'intercede',
    'interceded',
    'intercellular',
    'intercept',
    'intercepted',
    'interception',
    'interceptor',
    'intercession',
    'intercessor',
    'interchange',
    'interchangeability',
    'interchangeable',
    'interchangeableness',
    'interchangeably',
    'interchanged',
    'interchanging',
    'interchurch',
    'intercollegiate',
    'intercom',
    'intercommunicate',
    'intercommunication',
    'intercommunion',
    'interconnect',
    'interconnected',
    'interconnectedness',
    'interconnecting',
    'interconnection',
    'interconnections',
    'intercontinental',
    'intercorporate',
    'intercostal',
    'intercourse',
    'intercrossed',
    'interdenominational',
    'interdepartmental',
    'interdepend',
    'interdependence',
    'interdependency',
    'interdependent',
    'interdict',
    'interdiction',
    'interdisciplinary',
    'interest',
    'interested',
    'interestedness',
    'interesting',
    'interestingness',
    'interests',
    'interface',
    'interfaces',
    'interfacial',
    'interfaith',
    'interfere',
    'interfered',
    'interference',
    'interferes',
    'interfering',
    'interferometer',
    'interferon',
    'intergalactic',
    'interim',
    'interior',
    'interiorise',
    'interiorize',
    'interiors',
    'interject',
    'interjected',
    'interjecting',
    'interjection',
    'interlace',
    'interlaced',
    'interlaces',
    'interlacing',
    'interlaken',
    'interlanguage',
    'interlard',
    'interlayer',
    'interleaf',
    'interleave',
    'interleaved',
    'interleukin',
    'interlibrary',
    'interlineal',
    'interlinear',
    'interlingua',
    'interlink',
    'interlinked',
    'interlinking',
    'interlobular',
    'interlock',
    'interlocked',
    'interlocking',
    'interlocks',
    'interlocutor',
    'interlocutors',
    'interlocutory',
    'interlope',
    'interloper',
    'interlude',
    'interluded',
    'interludes',
    'intermarriage',
    'intermarriages',
    'intermarry',
    'intermaxillary',
    'intermediary',
    'intermediate',
    'intermediation',
    'intermediator',
    'interment',
    'intermeshed',
    'intermezzo',
    'interminable',
    'intermingle',
    'intermission',
    'intermit',
    'intermittence',
    'intermittency',
    'intermittent',
    'intermittently',
    'intermix',
    'intermixed',
    'intermixture',
    'intermolecular',
    'intermural',
    'intern',
    'internal',
    'internalisation',
    'internalise',
    'internality',
    'internalization',
    'internalize',
    'internalized',
    'internally',
    'international',
    'internationale',
    'internationalisation',
    'internationalise',
    'internationalism',
    'internationalist',
    'internationalistic',
    'internationality',
    'internationalization',
    'internationalize',
    'internationalized',
    'internationally',
    'interne',
    'internecine',
    'interned',
    'internee',
    'internees',
    'internet',
    'interning',
    'internist',
    'internment',
    'internode',
    'internship',
    'internuncio',
    'interoception',
    'interoceptive',
    'interoceptor',
    'interoperability',
    'interoperable',
    'interpellate',
    'interpellation',
    'interpenetrate',
    'interpenetration',
    'interpersonal',
    'interphone',
    'interplanetary',
    'interplay',
    'interpol',
    'interpolate',
    'interpolation',
    'interpolations',
    'interpose',
    'interposed',
    'interposes',
    'interposing',
    'interposition',
    'interpret',
    'interpretable',
    'interpretation',
    'interpretations',
    'interpretative',
    'interpreted',
    'interpreter',
    'interpreters',
    'interpreting',
    'interpretive',
    'interprets',
    'interracial',
    'interred',
    'interreflection',
    'interregnum',
    'interrelate',
    'interrelated',
    'interrelatedness',
    'interrelation',
    'interrelations',
    'interrelationship',
    'interrogate',
    'interrogating',
    'interrogation',
    'interrogative',
    'interrogator',
    'interrogatory',
    'interrupt',
    'interrupted',
    'interrupter',
    'interrupting',
    'interruption',
    'interruptions',
    'interrupts',
    'interscholastic',
    'interschool',
    'intersect',
    'intersectant',
    'intersected',
    'intersecting',
    'intersection',
    'intersections',
    'intersects',
    'intersex',
    'intersexual',
    'interspecies',
    'interspecific',
    'interspersal',
    'intersperse',
    'interspersed',
    'interspersion',
    'interstate',
    'interstellar',
    'interstice',
    'interstices',
    'interstitial',
    'interstratify',
    'intertidal',
    'intertribal',
    'intertrigo',
    'intertwine',
    'intertwined',
    'intertwines',
    'intertwining',
    'interval',
    'intervals',
    'intervene',
    'intervened',
    'intervenes',
    'intervening',
    'intervenor',
    'intervention',
    'intervertebral',
    'interview',
    'interviewed',
    'interviewee',
    'interviewer',
    'interviewing',
    'interviews',
    'interweave',
    'interweaving',
    'interwoven',
    'intestacy',
    'intestate',
    'intestinal',
    'intestine',
    'intestines',
    'inti',
    'intifada',
    'intifadah',
    'intima',
    'intimacies',
    'intimacy',
    'intimal',
    'intimate',
    'intimated',
    'intimately',
    'intimation',
    'intimidate',
    'intimidated',
    'intimidates',
    'intimidating',
    'intimidation',
    'into',
    'intolerable',
    'intolerably',
    'intolerance',
    'intolerant',
    'intonate',
    'intonation',
    'intonations',
    'intone',
    'intoned',
    'intoxicant',
    'intoxicate',
    'intoxicated',
    'intoxicating',
    'intoxication',
    'intracellular',
    'intracerebral',
    'intracranial',
    'intractability',
    'intractable',
    'intractableness',
    'intractably',
    'intracutaneous',
    'intradepartmental',
    'intradermal',
    'intradermic',
    'intrados',
    'intragroup',
    'intralinguistic',
    'intralobular',
    'intramolecular',
    'intramural',
    'intramuscular',
    'intramuscularly',
    'intranet',
    'intransigence',
    'intransigency',
    'intransigent',
    'intransitive',
    'intransitiveness',
    'intransitivise',
    'intransitivity',
    'intransitivize',
    'intraocular',
    'intrapulmonary',
    'intrasentential',
    'intraspecies',
    'intraspecific',
    'intrastate',
    'intrauterine',
    'intravasation',
    'intravenous',
    'intravenously',
    'intraventricular',
    'intrench',
    'intrenchment',
    'intrepid',
    'intrepidity',
    'intricacy',
    'intricate',
    'intricately',
    'intrigue',
    'intrigued',
    'intriguer',
    'intrigues',
    'intriguing',
    'intrinsic',
    'intrinsical',
    'intrinsically',
    'intro',
    'introduce',
    'introduced',
    'introduces',
    'introducing',
    'introduction',
    'introductory',
    'introit',
    'introitus',
    'introject',
    'introjected',
    'introjection',
    'intromission',
    'intromit',
    'intron',
    'introns',
    'intropin',
    'introspect',
    'introspection',
    'introspective',
    'introspectiveness',
    'introuvable',
    'introversion',
    'introversive',
    'introvert',
    'introverted',
    'introvertish',
    'introvertive',
    'intrude',
    'intruded',
    'intruder',
    'intrudes',
    'intruding',
    'intrusion',
    'intrusive',
    'intrusiveness',
    'intrust',
    'intubate',
    'intubation',
    'intuit',
    'intuition',
    'intuitionism',
    'intuitionist',
    'intuitive',
    'intuitively',
    'intumesce',
    'intumescence',
    'intumescency',
    'intumescent',
    'intussuscept',
    'intussuscepted',
    'intussusception',
    'inuit',
    'inula',
    'inulin',
    'inunct',
    'inunction',
    'inundate',
    'inundated',
    'inundation',
    'inure',
    'inured',
    'inutile',
    'inutility',
    'invade',
    'invaded',
    'invader',
    'invaders',
    'invades',
    'invading',
    'invaginate',
    'invagination',
    'invalid',
    'invalidate',
    'invalidated',
    'invalidates',
    'invalidating',
    'invalidation',
    'invalidator',
    'invalidism',
    'invalidity',
    'invalidness',
    'invalids',
    'invaluable',
    'invaluableness',
    'invar',
    'invariability',
    'invariable',
    'invariableness',
    'invariably',
    'invariance',
    'invariant',
    'invasion',
    'invasions',
    'invasive',
    'invective',
    'invectives',
    'inveigh',
    'inveigle',
    'invent',
    'invented',
    'inventing',
    'invention',
    'inventions',
    'inventive',
    'inventiveness',
    'inventor',
    'inventories',
    'inventors',
    'inventory',
    'inventorying',
    'invents',
    'inverse',
    'inversely',
    'inversion',
    'invert',
    'invertase',
    'invertebrate',
    'invertebrates',
    'inverted',
    'inverter',
    'invertible',
    'inverts',
    'invest',
    'invested',
    'investigate',
    'investigated',
    'investigates',
    'investigating',
    'investigation',
    'investigations',
    'investigative',
    'investigator',
    'investigatory',
    'investing',
    'investiture',
    'investment',
    'investments',
    'investor',
    'investors',
    'invests',
    'inveterate',
    'invidia',
    'invidious',
    'invigilate',
    'invigilation',
    'invigilator',
    'invigorate',
    'invigorated',
    'invigorates',
    'invigorating',
    'invigoration',
    'invigorator',
    'invincibility',
    'invincible',
    'inviolable',
    'inviolate',
    'invirase',
    'invisibility',
    'invisible',
    'invisibleness',
    'invitation',
    'invitational',
    'invitatory',
    'invite',
    'invited',
    'invitee',
    'invites',
    'inviting',
    'invitingly',
    'invocation',
    'invocations',
    'invoice',
    'invoiced',
    'invoke',
    'invoked',
    'invokes',
    'invoking',
    'involucrate',
    'involucre',
    'involucres',
    'involuntarily',
    'involuntariness',
    'involuntary',
    'involute',
    'involution',
    'involve',
    'involved',
    'involvement',
    'involves',
    'involving',
    'invulnerability',
    'invulnerable',
    'inward',
    'inwardly',
    'inwardness',
    'inwards',
    'inweave',
    'inwrought',
    'io',
    'ioc',
    'iodide',
    'iodin',
    'iodinate',
    'iodinated',
    'iodinating',
    'iodination',
    'iodine',
    'iodise',
    'iodised',
    'iodize',
    'iodized',
    'iodochlorhydroxyquin',
    'iodocompound',
    'iodoform',
    'iodoprotein',
    'iodopsin',
    'iodothyronine',
    'iodotyrosine',
    'iol',
    'ion',
    'ionate',
    'ionesco',
    'ionia',
    'ionian',
    'ionians',
    'ionic',
    'ionisation',
    'ionise',
    'ionised',
    'ionization',
    'ionize',
    'ionized',
    'ionizes',
    'ionizing',
    'ionophoresis',
    'ionosphere',
    'ions',
    'iontophoresis',
    'iontotherapy',
    'iop',
    'iota',
    'iou',
    'iowa',
    'iowan',
    'ioway',
    'ip',
    'ipecac',
    'iphigenia',
    'ipidae',
    'ipo',
    'ipod',
    'ipomoea',
    'iproclozide',
    'ipsedixitism',
    'ipsilateral',
    'ipsus',
    'ipv',
    'iq',
    'ir',
    'ira',
    'irak',
    'iraki',
    'iran',
    'irani',
    'iranian',
    'iraq',
    'iraqi',
    'iraqis',
    'irascibility',
    'irascible',
    'irate',
    'ire',
    'ireful',
    'ireland',
    'irelander',
    'irena',
    'irenaeus',
    'irenic',
    'irenidae',
    'iresine',
    'iridaceae',
    'iridaceous',
    'iridectomy',
    'iridesce',
    'iridesced',
    'iridescence',
    'iridescent',
    'iridic',
    'iridium',
    'iridocyclitis',
    'iridokeratitis',
    'iridoncus',
    'iridoprocne',
    'iridosmine',
    'iridotomy',
    'iris',
    'irises',
    'irish',
    'irishman',
    'irishwoman',
    'iritic',
    'iritis',
    'irk',
    'irksome',
    'iron',
    'ironclad',
    'ironed',
    'ironic',
    'ironical',
    'ironically',
    'ironing',
    'ironist',
    'ironlike',
    'ironman',
    'ironmonger',
    'ironmongery',
    'irons',
    'ironshod',
    'ironside',
    'ironsides',
    'ironware',
    'ironweed',
    'ironwood',
    'ironwork',
    'ironworker',
    'ironworks',
    'irony',
    'iroquoian',
    'iroquois',
    'irradiate',
    'irradiated',
    'irradiating',
    'irradiation',
    'irrational',
    'irrationality',
    'irrationally',
    'irrawaddy',
    'irreality',
    'irreclaimable',
    'irreconcilable',
    'irrecoverable',
    'irredeemable',
    'irredenta',
    'irredentism',
    'irredentist',
    'irreducible',
    'irrefutable',
    'irregular',
    'irregularities',
    'irregularity',
    'irregularly',
    'irrelevance',
    'irrelevancy',
    'irrelevant',
    'irreligion',
    'irreligionist',
    'irreligious',
    'irreligiousness',
    'irremediable',
    'irremovable',
    'irreparable',
    'irreparably',
    'irreplaceable',
    'irreplaceableness',
    'irrepressibility',
    'irrepressible',
    'irreproachable',
    'irreproducibility',
    'irreproducible',
    'irresistibility',
    'irresistible',
    'irresistibleness',
    'irresolute',
    'irresoluteness',
    'irresolution',
    'irrespective',
    'irresponsibility',
    'irresponsible',
    'irresponsibleness',
    'irresponsibly',
    'irretrievable',
    'irreverence',
    'irreverent',
    'irreverently',
    'irreversibility',
    'irreversible',
    'irrevocable',
    'irrevocably',
    'irrevokable',
    'irridenta',
    'irridentism',
    'irridentist',
    'irrigate',
    'irrigated',
    'irrigating',
    'irrigation',
    'irritability',
    'irritable',
    'irritant',
    'irritants',
    'irritate',
    'irritated',
    'irritates',
    'irritating',
    'irritatingly',
    'irritation',
    'irritations',
    'irritative',
    'irrupt',
    'irrupted',
    'irruption',
    'irruptive',
    'irs',
    'irtish',
    'irtysh',
    'irula',
    'irving',
    'irvingia',
    'irwin',
    'is',
    'isaac',
    'isabella',
    'isaiah',
    'isarithm',
    'isatis',
    'ischaemia',
    'ischaemic',
    'ischemia',
    'ischemic',
    'ischia',
    'ischigualastia',
    'ischium',
    'isentropic',
    'isere',
    'iseult',
    'isfahan',
    'isherwood',
    'ishmael',
    'ishtar',
    'isi',
    'isinglass',
    'isis',
    'iskcon',
    'islam',
    'islamabad',
    'islamic',
    'islamise',
    'islamism',
    'islamist',
    'islamists',
    'islamiyah',
    'islamize',
    'islamized',
    'islamophobia',
    'island',
    'islander',
    'islands',
    'islay',
    'isle',
    'isles',
    'islet',
    'islets',
    'ism',
    'ismaili',
    'ismailian',
    'ismailism',
    'isn',
    'isoagglutination',
    'isoagglutinin',
    'isoagglutinogen',
    'isoantibody',
    'isobar',
    'isobilateral',
    'isobutylene',
    'isocarboxazid',
    'isochronal',
    'isochrone',
    'isochronous',
    'isoclinal',
    'isoclinic',
    'isocrates',
    'isocyanate',
    'isocyanic',
    'isocyclic',
    'isoetaceae',
    'isoetales',
    'isoetes',
    'isoflurane',
    'isogamete',
    'isogamy',
    'isogon',
    'isogone',
    'isogonic',
    'isogram',
    'isohel',
    'isolable',
    'isolate',
    'isolated',
    'isolates',
    'isolating',
    'isolation',
    'isolationism',
    'isolationist',
    'isolationistic',
    'isolde',
    'isoleucine',
    'isomer',
    'isomerase',
    'isomeric',
    'isomerisation',
    'isomerise',
    'isomerism',
    'isomerization',
    'isomerize',
    'isomers',
    'isometric',
    'isometrical',
    'isometrics',
    'isometries',
    'isometropia',
    'isometry',
    'isomorphic',
    'isomorphism',
    'isomorphous',
    'isomorphy',
    'isoniazid',
    'isopleth',
    'isopod',
    'isopoda',
    'isopods',
    'isopropanol',
    'isopropyl',
    'isoproterenol',
    'isoptera',
    'isopteran',
    'isoptin',
    'isopyrum',
    'isordil',
    'isosceles',
    'isosmotic',
    'isosorbide',
    'isospondyli',
    'isostasy',
    'isotherm',
    'isothermal',
    'isothermic',
    'isothiocyanate',
    'isotonic',
    'isotope',
    'isotopes',
    'isotopic',
    'isotropic',
    'isotropous',
    'isotropy',
    'israel',
    'israeli',
    'israelis',
    'israelite',
    'israelites',
    'issachar',
    'issuance',
    'issue',
    'issued',
    'issuer',
    'issues',
    'issuing',
    'issus',
    'istanbul',
    'isthmian',
    'isthmus',
    'istiophoridae',
    'istiophorus',
    'isuprel',
    'isuridae',
    'isurus',
    'it',
    'italia',
    'italian',
    'italians',
    'italic',
    'italica',
    'italicise',
    'italicize',
    'italics',
    'italy',
    'itch',
    'itchiness',
    'itching',
    'itchy',
    'item',
    'itemisation',
    'itemise',
    'itemization',
    'itemize',
    'itemized',
    'items',
    'iterate',
    'iteration',
    'iterative',
    'ithaca',
    'ithaki',
    'ithunn',
    'itinerant',
    'itinerary',
    'itinerate',
    'itinerating',
    'itineration',
    'itraconazole',
    'its',
    'itself',
    'iud',
    'iv',
    'iva',
    'ivan',
    'ivanov',
    'ives',
    'ivied',
    'ivory',
    'ivorybill',
    'ivp',
    'ivry',
    'ivy',
    'iw',
    'iwo',
    'iww',
    'ix',
    'ixc',
    'ixia',
    'ixl',
    'ixobrychus',
    'ixodes',
    'ixodid',
    'ixodidae',
    'iyar',
    'iyyar',
    'izanagi',
    'izanami',
    'izar',
    'izmir',
    'izzard']
