
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_j_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.172958'}

wordnet_terms_j = [
    'jab',
    'jabalpur',
    'jabbed',
    'jabber',
    'jabberer',
    'jabbering',
    'jabberwocky',
    'jabbing',
    'jabiru',
    'jabirus',
    'jaboncillo',
    'jabot',
    'jaboticaba',
    'jacamar',
    'jacamars',
    'jacaranda',
    'jacinth',
    'jack',
    'jackal',
    'jackals',
    'jackanapes',
    'jackass',
    'jackboot',
    'jackbooted',
    'jackdaw',
    'jacket',
    'jackets',
    'jackfruit',
    'jackhammer',
    'jackknife',
    'jacklight',
    'jackpot',
    'jackrabbit',
    'jacks',
    'jackscrew',
    'jacksmelt',
    'jacksnipe',
    'jackson',
    'jacksonia',
    'jacksonian',
    'jacksonville',
    'jackstones',
    'jackstraw',
    'jackstraws',
    'jacob',
    'jacobean',
    'jacobi',
    'jacobin',
    'jacobinic',
    'jacobinical',
    'jacobinism',
    'jacobins',
    'jacobite',
    'jacobs',
    'jacobus',
    'jaconet',
    'jacquard',
    'jacques',
    'jacquinia',
    'jactation',
    'jactitate',
    'jactitation',
    'jaculus',
    'jade',
    'jaded',
    'jadeite',
    'jadestone',
    'jaeger',
    'jaegers',
    'jafar',
    'jaffa',
    'jaffar',
    'jag',
    'jagannath',
    'jagannatha',
    'jagatai',
    'jagganath',
    'jaggary',
    'jagged',
    'jaggedly',
    'jaggedness',
    'jagger',
    'jaggery',
    'jagghery',
    'jaggy',
    'jaghatai',
    'jagua',
    'jaguar',
    'jaguarondi',
    'jaguarundi',
    'jahan',
    'jahvey',
    'jahweh',
    'jail',
    'jailbird',
    'jailbreak',
    'jailed',
    'jailer',
    'jailhouse',
    'jailor',
    'jain',
    'jainism',
    'jainist',
    'jak',
    'jakarta',
    'jakes',
    'jakob',
    'jakobson',
    'jalalabad',
    'jalapeno',
    'jalopy',
    'jalousie',
    'jam',
    'jamaica',
    'jamaican',
    'jamb',
    'jambalaya',
    'jambeau',
    'jamberry',
    'jambon',
    'jamboree',
    'jambos',
    'jambosa',
    'jambs',
    'james',
    'jamesian',
    'jameson',
    'jamesonia',
    'jamestown',
    'jamison',
    'jamjar',
    'jammed',
    'jammer',
    'jammies',
    'jamming',
    'jampack',
    'jampan',
    'jampot',
    'jams',
    'jan',
    'jane',
    'janeiro',
    'janet',
    'jangle',
    'jangling',
    'jangly',
    'janissary',
    'janitor',
    'jansen',
    'jansenism',
    'jansenist',
    'january',
    'janus',
    'jap',
    'japan',
    'japanese',
    'jape',
    'japery',
    'japheth',
    'japonica',
    'jar',
    'jarful',
    'jargon',
    'jargoon',
    'jarred',
    'jarrell',
    'jarring',
    'jars',
    'jasmine',
    'jasminum',
    'jason',
    'jasper',
    'jaspers',
    'jassid',
    'jassidae',
    'jat',
    'jati',
    'jatropha',
    'jaundice',
    'jaundiced',
    'jaunt',
    'jauntiness',
    'jaunty',
    'java',
    'javan',
    'javanese',
    'javanthropus',
    'javelin',
    'javelina',
    'jaw',
    'jawan',
    'jawbone',
    'jawbones',
    'jawbreaker',
    'jawed',
    'jawfish',
    'jawfishes',
    'jawless',
    'jaws',
    'jay',
    'jaybird',
    'jays',
    'jayshullah',
    'jaywalk',
    'jaywalker',
    'jazz',
    'jazzman',
    'jazzy',
    'jdam',
    'jealous',
    'jealously',
    'jealousy',
    'jean',
    'jeanne',
    'jeans',
    'jeddah',
    'jeep',
    'jeer',
    'jeered',
    'jeerer',
    'jeering',
    'jeers',
    'jeffers',
    'jefferson',
    'jeffersonian',
    'jehad',
    'jehovah',
    'jejune',
    'jejuneness',
    'jejunitis',
    'jejunity',
    'jejunoileitis',
    'jejunostomy',
    'jejunum',
    'jell',
    'jellaba',
    'jelled',
    'jellied',
    'jellies',
    'jellify',
    'jello',
    'jelly',
    'jellyfish',
    'jellyfishes',
    'jellyleaf',
    'jellylike',
    'jellyroll',
    'jem',
    'jemaah',
    'jemmy',
    'jena',
    'jenner',
    'jennet',
    'jennings',
    'jenny',
    'jensen',
    'jeopardise',
    'jeopardize',
    'jeopardy',
    'jerboa',
    'jerboas',
    'jeremiad',
    'jeremiah',
    'jeremy',
    'jerevan',
    'jerez',
    'jericho',
    'jerk',
    'jerked',
    'jerker',
    'jerkin',
    'jerkiness',
    'jerking',
    'jerks',
    'jerkwater',
    'jerky',
    'jernigan',
    'jeroboam',
    'jerome',
    'jerry',
    'jersey',
    'jerusalem',
    'jespersen',
    'jess',
    'jessamine',
    'jesse',
    'jessica',
    'jest',
    'jester',
    'jesting',
    'jesuit',
    'jesuitic',
    'jesuitical',
    'jesuitism',
    'jesuitry',
    'jesuits',
    'jesus',
    'jet',
    'jeth',
    'jetliner',
    'jets',
    'jetsam',
    'jetted',
    'jetting',
    'jettison',
    'jettisoned',
    'jetty',
    'jevons',
    'jew',
    'jewbush',
    'jewel',
    'jeweled',
    'jeweler',
    'jewelers',
    'jewelled',
    'jeweller',
    'jewellery',
    'jewelry',
    'jewels',
    'jewelweed',
    'jewess',
    'jewfish',
    'jewish',
    'jewison',
    'jewry',
    'jews',
    'jezebel',
    'jfk',
    'jhvh',
    'ji',
    'jiang',
    'jiao',
    'jib',
    'jibbed',
    'jibboom',
    'jibe',
    'jibs',
    'jidda',
    'jiddah',
    'jiffy',
    'jig',
    'jigger',
    'jiggered',
    'jiggermast',
    'jiggle',
    'jigsaw',
    'jihad',
    'jihadi',
    'jihadist',
    'jillion',
    'jilt',
    'jilted',
    'jilts',
    'jim',
    'jima',
    'jimdandy',
    'jimenez',
    'jimhickey',
    'jimmied',
    'jimmies',
    'jimmy',
    'jimsonweed',
    'jinghpaw',
    'jinghpo',
    'jingle',
    'jingling',
    'jingly',
    'jingo',
    'jingoism',
    'jingoist',
    'jingoistic',
    'jinja',
    'jinks',
    'jinnah',
    'jinnee',
    'jinni',
    'jinrikisha',
    'jinx',
    'jinxed',
    'jiqui',
    'jird',
    'jirga',
    'jirrbal',
    'jitney',
    'jitter',
    'jitterbug',
    'jitteriness',
    'jittering',
    'jitters',
    'jittery',
    'jiujitsu',
    'jive',
    'jnd',
    'jnr',
    'joachim',
    'joan',
    'joaquin',
    'job',
    'jobbed',
    'jobber',
    'jobbers',
    'jobbery',
    'jobcentre',
    'jobholder',
    'jobless',
    'jobs',
    'jocasta',
    'jock',
    'jockey',
    'jockstrap',
    'jocose',
    'jocoseness',
    'jocosity',
    'jocote',
    'jocular',
    'jocularity',
    'jocund',
    'jocundity',
    'jodhpur',
    'jodhpurs',
    'joe',
    'joel',
    'joewood',
    'joffre',
    'joffrey',
    'jog',
    'jogger',
    'joggers',
    'jogging',
    'joggle',
    'johannes',
    'johannesburg',
    'john',
    'johnny',
    'johnnycake',
    'johns',
    'johnson',
    'johnston',
    'johor',
    'johore',
    'join',
    'joined',
    'joiner',
    'joinery',
    'joining',
    'joins',
    'joint',
    'jointed',
    'jointer',
    'jointly',
    'joints',
    'jointure',
    'jointworm',
    'joist',
    'joists',
    'joke',
    'joker',
    'jokers',
    'jokes',
    'jokester',
    'joking',
    'joliet',
    'joliot',
    'jolliet',
    'jollification',
    'jollify',
    'jolliness',
    'jollity',
    'jolly',
    'jolson',
    'jolt',
    'jolted',
    'jolting',
    'jolts',
    'jolty',
    'jonah',
    'jonathan',
    'jones',
    'jonesboro',
    'jong',
    'jongleur',
    'jonquil',
    'jonson',
    'jook',
    'joplin',
    'joppa',
    'jordan',
    'jordanella',
    'jordanian',
    'jorum',
    'josef',
    'joseph',
    'josephus',
    'josh',
    'joshua',
    'josiah',
    'joss',
    'jostle',
    'jostled',
    'jostling',
    'josue',
    'jot',
    'jotted',
    'jotter',
    'jotting',
    'jotun',
    'jotunn',
    'joule',
    'joules',
    'jounce',
    'journal',
    'journalese',
    'journalism',
    'journalist',
    'journalistic',
    'journalists',
    'journals',
    'journey',
    'journeyer',
    'journeying',
    'journeyman',
    'journeys',
    'joust',
    'jousts',
    'jove',
    'jovial',
    'joviality',
    'jovian',
    'jowett',
    'jowl',
    'jowly',
    'joy',
    'joyce',
    'joyful',
    'joyfully',
    'joyfulness',
    'joyless',
    'joylessness',
    'joyous',
    'joyously',
    'joyousness',
    'joyride',
    'joyrides',
    'joys',
    'joystick',
    'jr',
    'jra',
    'juan',
    'juarez',
    'jubbulpore',
    'jubilance',
    'jubilancy',
    'jubilant',
    'jubilate',
    'jubilation',
    'jubilee',
    'juda',
    'judaea',
    'judah',
    'judaic',
    'judaica',
    'judaical',
    'judaism',
    'judas',
    'judder',
    'jude',
    'judea',
    'judge',
    'judged',
    'judgement',
    'judges',
    'judgeship',
    'judging',
    'judgment',
    'judgmental',
    'judgments',
    'judicable',
    'judicatory',
    'judicature',
    'judicial',
    'judicially',
    'judiciary',
    'judicious',
    'judiciousness',
    'judith',
    'judo',
    'jug',
    'jugale',
    'jugful',
    'juggernaut',
    'juggle',
    'juggled',
    'juggler',
    'jugglers',
    'jugglery',
    'juggles',
    'juggling',
    'juglandaceae',
    'juglandales',
    'juglans',
    'jugoslav',
    'jugoslavian',
    'jugoslavija',
    'jugs',
    'jugular',
    'juice',
    'juiceless',
    'juicer',
    'juices',
    'juiciest',
    'juiciness',
    'juicy',
    'jujitsu',
    'juju',
    'jujube',
    'jujubes',
    'jujutsu',
    'juke',
    'jukebox',
    'julep',
    'jules',
    'julia',
    'julian',
    'julienne',
    'julius',
    'july',
    'jumbal',
    'jumble',
    'jumbled',
    'jumbles',
    'jumbo',
    'jumbojet',
    'jument',
    'jumentous',
    'jump',
    'jumped',
    'jumper',
    'jumpers',
    'jumpiness',
    'jumping',
    'jumps',
    'jumpstart',
    'jumpsuit',
    'jumpy',
    'juncaceae',
    'juncaginaceae',
    'junco',
    'junction',
    'junctions',
    'juncture',
    'junctures',
    'juncus',
    'june',
    'juneau',
    'juneberry',
    'jung',
    'jungermanniaceae',
    'jungermanniales',
    'jungian',
    'jungle',
    'jungles',
    'jungly',
    'junin',
    'junior',
    'juniper',
    'junipers',
    'juniperus',
    'junk',
    'junker',
    'junkers',
    'junket',
    'junketeer',
    'junketing',
    'junkie',
    'junky',
    'junkyard',
    'juno',
    'junoesque',
    'junta',
    'junto',
    'jupati',
    'jupaty',
    'jupiter',
    'jural',
    'jurassic',
    'jure',
    'juridic',
    'juridical',
    'jurisdiction',
    'jurisdictional',
    'jurisdictions',
    'jurisprudence',
    'jurisprudential',
    'jurist',
    'juristic',
    'juror',
    'jurors',
    'jury',
    'juryman',
    'jurywoman',
    'jussieu',
    'just',
    'justice',
    'justiciar',
    'justiciary',
    'justifiable',
    'justifiably',
    'justification',
    'justificative',
    'justificatory',
    'justified',
    'justifier',
    'justifies',
    'justify',
    'justifying',
    'justinian',
    'justly',
    'justness',
    'jut',
    'jute',
    'jutes',
    'jutish',
    'jutland',
    'juts',
    'jutted',
    'jutting',
    'juvenal',
    'juvenescence',
    'juvenile',
    'juvenility',
    'juxtapose',
    'juxtaposed',
    'juxtaposes',
    'juxtaposing',
    'juxtaposition',
    'juxtapositions',
    'jv',
    'jyaistha',
    'jylland',
    'jynx']
