
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_y_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.243458'}

wordnet_terms_y = [
    'yacca',
    'yacht',
    'yachting',
    'yachts',
    'yachtsman',
    'yachtswoman',
    'yack',
    'yafo',
    'yagi',
    'yahi',
    'yahoo',
    'yahoos',
    'yahve',
    'yahveh',
    'yahwe',
    'yahweh',
    'yak',
    'yakima',
    'yakking',
    'yaks',
    'yakut',
    'yakuza',
    'yale',
    'yalta',
    'yaltopya',
    'yalu',
    'yam',
    'yama',
    'yamaltu',
    'yamamoto',
    'yamani',
    'yammer',
    'yamoussukro',
    'yams',
    'yana',
    'yanan',
    'yang',
    'yangon',
    'yangtse',
    'yangtze',
    'yank',
    'yanked',
    'yankee',
    'yankees',
    'yanker',
    'yanquapin',
    'yaounde',
    'yap',
    'yard',
    'yardage',
    'yardarm',
    'yardbird',
    'yarder',
    'yardgrass',
    'yardie',
    'yardman',
    'yardmaster',
    'yards',
    'yardstick',
    'yarmelke',
    'yarmulka',
    'yarmulke',
    'yarn',
    'yarns',
    'yarrow',
    'yashmac',
    'yashmak',
    'yasser',
    'yastrzemski',
    'yataghan',
    'yatobyo',
    'yaup',
    'yautia',
    'yavapai',
    'yaw',
    'yawed',
    'yawing',
    'yawl',
    'yawn',
    'yawned',
    'yawner',
    'yawning',
    'yawns',
    'yawp',
    'yaws',
    'yay',
    'yazoo',
    'yb',
    'ybit',
    'ye',
    'yea',
    'year',
    'yearbook',
    'yearling',
    'yearlong',
    'yearly',
    'yearn',
    'yearner',
    'yearning',
    'years',
    'yeas',
    'yeast',
    'yeastlike',
    'yeasts',
    'yeasty',
    'yeats',
    'yeatsian',
    'yeddo',
    'yedo',
    'yekaterinoslav',
    'yell',
    'yelled',
    'yeller',
    'yelling',
    'yellow',
    'yellowbird',
    'yellowcake',
    'yellowed',
    'yellower',
    'yellowfin',
    'yellowhammer',
    'yellowing',
    'yellowish',
    'yellowknife',
    'yellowlegs',
    'yellowness',
    'yellows',
    'yellowstone',
    'yellowtail',
    'yellowthroat',
    'yellowthroats',
    'yellowwood',
    'yellowwoods',
    'yells',
    'yelp',
    'yelping',
    'yemen',
    'yemeni',
    'yen',
    'yenisei',
    'yeniseian',
    'yenisey',
    'yenta',
    'yeoman',
    'yeomanry',
    'yerba',
    'yerevan',
    'yerkes',
    'yersin',
    'yersinia',
    'yerupaja',
    'yes',
    'yeshiva',
    'yeshivah',
    'yesterday',
    'yesteryear',
    'yet',
    'yeti',
    'yevtushenko',
    'yew',
    'yews',
    'yezo',
    'ygdrasil',
    'yggdrasil',
    'yhvh',
    'yhwh',
    'yi',
    'yib',
    'yibit',
    'yid',
    'yiddish',
    'yield',
    'yielded',
    'yielder',
    'yielding',
    'yields',
    'yin',
    'yip',
    'yips',
    'yisrael',
    'ylem',
    'ymir',
    'yob',
    'yobbo',
    'yobibit',
    'yobibyte',
    'yobo',
    'yodel',
    'yodeling',
    'yodeller',
    'yodh',
    'yoga',
    'yogacara',
    'yoghourt',
    'yoghurt',
    'yogi',
    'yogic',
    'yogistic',
    'yogurt',
    'yoke',
    'yokel',
    'yokelish',
    'yokohama',
    'yokuts',
    'yolk',
    'yolks',
    'yom',
    'yon',
    'yonder',
    'yore',
    'york',
    'yorker',
    'yorkshire',
    'yorktown',
    'yoruba',
    'yosemite',
    'yottabit',
    'yottabyte',
    'you',
    'young',
    'younger',
    'youngest',
    'youngish',
    'youngness',
    'youngster',
    'youngsters',
    'youngstown',
    'younker',
    'your',
    'yourself',
    'youth',
    'youthful',
    'youthfulness',
    'youths',
    'yowl',
    'yowling',
    'ypres',
    'yquem',
    'yr',
    'ytterbite',
    'ytterbium',
    'yttrium',
    'yuan',
    'yucatan',
    'yucatec',
    'yucateco',
    'yucca',
    'yucky',
    'yue',
    'yugoslav',
    'yugoslavia',
    'yugoslavian',
    'yukawa',
    'yukon',
    'yule',
    'yuletide',
    'yuma',
    'yuman',
    'yummy',
    'yung',
    'yunnan',
    'yuppie',
    'yurt']
