
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_z_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.244958'}

wordnet_terms_z = [
    'zaar',
    'zabaglione',
    'zabrze',
    'zacharias',
    'zachary',
    'zaftig',
    'zag',
    'zaglossus',
    'zagreb',
    'zaharias',
    'zaire',
    'zairean',
    'zairese',
    'zakat',
    'zalcitabine',
    'zalophus',
    'zama',
    'zaman',
    'zamang',
    'zambezi',
    'zambia',
    'zambian',
    'zamboni',
    'zamboorak',
    'zamburak',
    'zamburek',
    'zamia',
    'zamiaceae',
    'zamias',
    'zane',
    'zangwill',
    'zannichellia',
    'zannichelliaceae',
    'zantac',
    'zantedeschia',
    'zanthoxylum',
    'zanuck',
    'zany',
    'zanzibar',
    'zap',
    'zapata',
    'zapodidae',
    'zapotec',
    'zapotecan',
    'zapper',
    'zaps',
    'zapus',
    'zaragoza',
    'zarathustra',
    'zarf',
    'zaria',
    'zarontin',
    'zarpanit',
    'zarqa',
    'zayin',
    'zb',
    'zbit',
    'zdv',
    'zea',
    'zeal',
    'zealand',
    'zealander',
    'zealot',
    'zealotry',
    'zealous',
    'zealously',
    'zeaxanthin',
    'zebibit',
    'zebibits',
    'zebibyte',
    'zebibytes',
    'zebra',
    'zebrawood',
    'zebu',
    'zechariah',
    'zed',
    'zedong',
    'zee',
    'zeeman',
    'zeidae',
    'zeitgeist',
    'zen',
    'zenaidura',
    'zend',
    'zenith',
    'zenithal',
    'zeno',
    'zeolite',
    'zeomorphi',
    'zep',
    'zephaniah',
    'zephyr',
    'zeppelin',
    'zeppo',
    'zero',
    'zeroed',
    'zeros',
    'zeroth',
    'zest',
    'zestful',
    'zestfulness',
    'zestril',
    'zesty',
    'zeta',
    'zetland',
    'zettabit',
    'zettabits',
    'zettabyte',
    'zettabytes',
    'zeugma',
    'zeus',
    'zhou',
    'zhu',
    'zhuang',
    'zhukov',
    'zib',
    'zibit',
    'zidovudine',
    'ziegfeld',
    'ziegler',
    'zig',
    'zigadene',
    'zigadenus',
    'ziggurat',
    'zigzag',
    'zigzags',
    'zikkurat',
    'zikurat',
    'zilch',
    'zill',
    'zillion',
    'zimbabwe',
    'zimbabwean',
    'zimbalist',
    'zimmer',
    'zinacef',
    'zinc',
    'zinfandel',
    'zing',
    'zinger',
    'zingiber',
    'zingiberaceae',
    'zinjanthropus',
    'zinkenite',
    'zinnemann',
    'zinnia',
    'zinnwaldite',
    'zinsser',
    'zinzendorf',
    'zion',
    'zionism',
    'zionist',
    'zip',
    'ziphiidae',
    'zipped',
    'zipper',
    'zippo',
    'zippy',
    'zirbanit',
    'zircon',
    'zirconia',
    'zirconium',
    'zit',
    'zither',
    'zithern',
    'zithers',
    'zithromax',
    'ziti',
    'zizania',
    'ziziphus',
    'zizz',
    'zloty',
    'zn',
    'zoanthropy',
    'zoarces',
    'zoarcidae',
    'zocor',
    'zodiac',
    'zodiacal',
    'zoftig',
    'zoic',
    'zoisia',
    'zola',
    'zolaesque',
    'zoloft',
    'zomba',
    'zombi',
    'zombie',
    'zona',
    'zonal',
    'zonary',
    'zone',
    'zones',
    'zoning',
    'zonked',
    'zonotrichia',
    'zonula',
    'zonule',
    'zoo',
    'zooerastia',
    'zooerasty',
    'zooflagellate',
    'zooid',
    'zooids',
    'zoolatry',
    'zoological',
    'zoologist',
    'zoologists',
    'zoology',
    'zoom',
    'zoomastigina',
    'zoomastigote',
    'zoomed',
    'zoomorphism',
    'zoonosis',
    'zoonotic',
    'zoophagous',
    'zoophilia',
    'zoophilism',
    'zoophobia',
    'zoophyte',
    'zooplankton',
    'zoopsia',
    'zoospore',
    'zoospores',
    'zootoxin',
    'zori',
    'zoril',
    'zoroaster',
    'zoroastrian',
    'zoroastrianism',
    'zoster',
    'zostera',
    'zosteraceae',
    'zovirax',
    'zoysia',
    'zr',
    'zsigmondy',
    'zu',
    'zubird',
    'zucchini',
    'zuider',
    'zukerman',
    'zulu',
    'zulus',
    'zumbooruck',
    'zumbooruk',
    'zuni',
    'zurich',
    'zurvan',
    'zurvanism',
    'zweig',
    'zwieback',
    'zwingli',
    'zworykin',
    'zydeco',
    'zygnema',
    'zygnemales',
    'zygnemataceae',
    'zygnematales',
    'zygocactus',
    'zygodactyl',
    'zygoma',
    'zygomatic',
    'zygomorphic',
    'zygomorphous',
    'zygomycetes',
    'zygomycota',
    'zygomycotina',
    'zygophyllaceae',
    'zygophyllum',
    'zygoptera',
    'zygospore',
    'zygospores',
    'zygote',
    'zygotene',
    'zygotic',
    'zyloprim',
    'zymase',
    'zymogen',
    'zymoid',
    'zymology',
    'zymolysis',
    'zymolytic',
    'zymosis',
    'zymotic',
    'zymurgy',
    'zyrian']
