
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_w_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.241458'}

wordnet_terms_w = [
    'wa',
    'wabash',
    'wac',
    'wacko',
    'wacky',
    'waco',
    'wad',
    'wadding',
    'waddle',
    'waddler',
    'waddlers',
    'waddling',
    'wade',
    'waded',
    'wader',
    'waders',
    'wadi',
    'wading',
    'wads',
    'wafer',
    'wafers',
    'waffle',
    'waffler',
    'waft',
    'wafted',
    'wafture',
    'wag',
    'wage',
    'waged',
    'wager',
    'wagered',
    'wagerer',
    'wagers',
    'wages',
    'wagged',
    'waggery',
    'waggish',
    'waggishness',
    'waggle',
    'waggon',
    'waggoner',
    'waggonwright',
    'waging',
    'wagner',
    'wagnerian',
    'wagon',
    'wagoner',
    'wagons',
    'wagonwright',
    'wagram',
    'wagtail',
    'wagtails',
    'wahabi',
    'wahabism',
    'wahhabi',
    'wahhabism',
    'wahoo',
    'wahoos',
    'wahunsonacock',
    'wahvey',
    'waif',
    'waikiki',
    'wail',
    'wailed',
    'wailer',
    'wailful',
    'wailing',
    'wails',
    'wain',
    'wainscot',
    'wainscoted',
    'wainscoting',
    'wainscotting',
    'wainwright',
    'waist',
    'waistband',
    'waistcloth',
    'waistcoat',
    'waistline',
    'wait',
    'waite',
    'waited',
    'waiter',
    'waiters',
    'waiting',
    'waitress',
    'waitresses',
    'waits',
    'waive',
    'waiver',
    'wajda',
    'wakashan',
    'wake',
    'wakeboard',
    'waked',
    'wakeful',
    'wakefulness',
    'wakeless',
    'waken',
    'wakening',
    'wakens',
    'waker',
    'wakes',
    'waking',
    'walapai',
    'walbiri',
    'wald',
    'waldenses',
    'waldheim',
    'waldmeister',
    'waldo',
    'wale',
    'wales',
    'walesa',
    'walhalla',
    'walk',
    'walkabout',
    'walkaway',
    'walked',
    'walker',
    'walking',
    'walkingstick',
    'walkman',
    'walkout',
    'walkover',
    'walks',
    'walkway',
    'wall',
    'wallabies',
    'wallaby',
    'wallace',
    'wallah',
    'wallboard',
    'walled',
    'wallenstein',
    'waller',
    'wallet',
    'walleye',
    'walleyed',
    'wallflower',
    'wallis',
    'walloon',
    'walloons',
    'wallop',
    'walloper',
    'walloping',
    'wallow',
    'wallowing',
    'wallpaper',
    'wallpaperer',
    'walls',
    'wally',
    'walnut',
    'walnuts',
    'walpole',
    'walrus',
    'walruses',
    'walt',
    'walter',
    'walton',
    'waltz',
    'waltzer',
    'waltzes',
    'waltzing',
    'wamble',
    'wampanoag',
    'wampee',
    'wampum',
    'wampumpeag',
    'wan',
    'wanamaker',
    'wand',
    'wandala',
    'wander',
    'wandered',
    'wanderer',
    'wandering',
    'wanderings',
    'wanderlust',
    'wanders',
    'wandflower',
    'wands',
    'wane',
    'waned',
    'wangle',
    'wangler',
    'wangling',
    'waning',
    'wank',
    'wanker',
    'wannabe',
    'wannabee',
    'wanness',
    'wannsee',
    'want',
    'wanted',
    'wanter',
    'wanting',
    'wanton',
    'wantonly',
    'wantonness',
    'wants',
    'wapiti',
    'war',
    'waratah',
    'waratahs',
    'warble',
    'warbler',
    'warblers',
    'warburg',
    'ward',
    'warded',
    'warden',
    'wardenship',
    'warder',
    'wardership',
    'warding',
    'wardress',
    'wardrobe',
    'wardroom',
    'ware',
    'warehouse',
    'warehouseman',
    'warehouser',
    'warehouses',
    'warehousing',
    'wares',
    'warfare',
    'warfarin',
    'warfield',
    'warhead',
    'warheads',
    'warhol',
    'warhorse',
    'warily',
    'wariness',
    'warji',
    'warlike',
    'warlock',
    'warlord',
    'warlpiri',
    'warm',
    'warmed',
    'warmer',
    'warmest',
    'warmhearted',
    'warmheartedness',
    'warming',
    'warmly',
    'warmness',
    'warmonger',
    'warmongering',
    'warmongers',
    'warms',
    'warmth',
    'warn',
    'warned',
    'warner',
    'warning',
    'warnings',
    'warns',
    'warp',
    'warpath',
    'warped',
    'warping',
    'warplane',
    'warragal',
    'warrant',
    'warrantee',
    'warranter',
    'warranting',
    'warrantor',
    'warrants',
    'warranty',
    'warren',
    'warrener',
    'warrigal',
    'warring',
    'warrior',
    'warriorlike',
    'warriors',
    'wars',
    'warsaw',
    'warship',
    'warships',
    'warszawa',
    'wart',
    'warthog',
    'warthogs',
    'wartime',
    'wartimes',
    'wartlike',
    'warts',
    'wartweed',
    'wartwort',
    'warty',
    'warwick',
    'wary',
    'was',
    'wasabi',
    'wash',
    'washable',
    'washables',
    'washbasin',
    'washboard',
    'washboards',
    'washbowl',
    'washcloth',
    'washday',
    'washed',
    'washer',
    'washerman',
    'washerwoman',
    'washes',
    'washhouse',
    'washing',
    'washington',
    'washingtonian',
    'washout',
    'washrag',
    'washroom',
    'washstand',
    'washtub',
    'washup',
    'washwoman',
    'washy',
    'wasp',
    'waspish',
    'wasps',
    'wassail',
    'wassailer',
    'wassermann',
    'wastage',
    'waste',
    'wastebasket',
    'wastebin',
    'wasted',
    'wasteful',
    'wastefully',
    'wastefulness',
    'wasteland',
    'waster',
    'wastes',
    'wastewater',
    'wasteweir',
    'wasteyard',
    'wasting',
    'wastrel',
    'watch',
    'watchband',
    'watchdog',
    'watchdogs',
    'watched',
    'watcher',
    'watchers',
    'watches',
    'watchful',
    'watchfulness',
    'watching',
    'watchmaker',
    'watchman',
    'watchstrap',
    'watchtower',
    'watchword',
    'water',
    'waterbird',
    'waterborne',
    'waterbuck',
    'waterbucks',
    'waterbury',
    'watercannon',
    'watercolor',
    'watercolorist',
    'watercolors',
    'watercolour',
    'watercolourist',
    'watercourse',
    'watercourses',
    'watercraft',
    'watercress',
    'waterdog',
    'watered',
    'waterer',
    'waterfall',
    'waterfalls',
    'waterfinder',
    'waterford',
    'waterfowl',
    'waterfront',
    'watergate',
    'wateriness',
    'watering',
    'waterleaf',
    'waterless',
    'waterlessness',
    'waterline',
    'waterlines',
    'waterlogged',
    'waterloo',
    'waterman',
    'watermark',
    'watermeal',
    'watermelon',
    'watermelons',
    'waterpower',
    'waterproof',
    'waterproofed',
    'waterproofing',
    'waters',
    'waterscape',
    'watershed',
    'waterside',
    'waterskin',
    'waterspout',
    'watertight',
    'watertown',
    'waterway',
    'waterways',
    'waterweed',
    'waterwheel',
    'waterworks',
    'waterworn',
    'watery',
    'wats',
    'watson',
    'watt',
    'wattage',
    'watteau',
    'wattle',
    'wattles',
    'wattmeter',
    'watts',
    'watusi',
    'watutsi',
    'waugh',
    'waul',
    'wausau',
    'wave',
    'waveband',
    'waved',
    'waveform',
    'wavefront',
    'waveguide',
    'wavelength',
    'wavelengths',
    'wavelet',
    'wavelike',
    'wavell',
    'waver',
    'waverer',
    'wavering',
    'waves',
    'waviness',
    'waving',
    'wavy',
    'waw',
    'wawl',
    'wax',
    'waxberry',
    'waxed',
    'waxen',
    'waxes',
    'waxflower',
    'waxiness',
    'waxing',
    'waxlike',
    'waxmallow',
    'waxwing',
    'waxwings',
    'waxwork',
    'waxworks',
    'waxy',
    'waxycap',
    'way',
    'waybill',
    'wayfarer',
    'wayfaring',
    'wayland',
    'waylay',
    'wayne',
    'ways',
    'wayside',
    'wayward',
    'wb',
    'wbc',
    'wbn',
    'wbs',
    'wc',
    'we',
    'weak',
    'weaken',
    'weakened',
    'weakener',
    'weakening',
    'weakens',
    'weaker',
    'weakest',
    'weakfish',
    'weakling',
    'weakly',
    'weakness',
    'weal',
    'weald',
    'weals',
    'wealth',
    'wealthiness',
    'wealthy',
    'wean',
    'weaned',
    'weaning',
    'weapon',
    'weaponed',
    'weaponize',
    'weaponless',
    'weaponry',
    'weapons',
    'wear',
    'wearable',
    'wearer',
    'wearied',
    'weariness',
    'wearing',
    'wearisome',
    'wears',
    'weary',
    'wearying',
    'weasel',
    'weasels',
    'weather',
    'weatherboard',
    'weatherboarding',
    'weathercock',
    'weathered',
    'weatherglass',
    'weathering',
    'weatherliness',
    'weatherly',
    'weatherman',
    'weatherproof',
    'weatherproofing',
    'weatherstrip',
    'weatherstripped',
    'weatherstripping',
    'weathervane',
    'weatherworn',
    'weave',
    'weaver',
    'weaverbird',
    'weaverbirds',
    'weaves',
    'weaving',
    'web',
    'webb',
    'webbed',
    'webber',
    'webbing',
    'webby',
    'webcam',
    'weber',
    'webfoot',
    'weblike',
    'webmaster',
    'webpage',
    'webs',
    'website',
    'webster',
    'webworm',
    'webworms',
    'wed',
    'wedded',
    'weddell',
    'wedding',
    'weddings',
    'wedel',
    'wedge',
    'wedged',
    'wedges',
    'wedgie',
    'wedgwood',
    'wedlock',
    'wednesday',
    'wee',
    'weed',
    'weeded',
    'weeder',
    'weeding',
    'weedkiller',
    'weedless',
    'weeds',
    'weedy',
    'week',
    'weekday',
    'weekdays',
    'weekend',
    'weekender',
    'weekends',
    'weeklong',
    'weekly',
    'weeknight',
    'weeks',
    'weeness',
    'weenie',
    'weensy',
    'weeny',
    'weep',
    'weeper',
    'weepiness',
    'weeping',
    'weeps',
    'weepy',
    'weevil',
    'weevils',
    'weevily',
    'weewee',
    'weft',
    'wegener',
    'wehrmacht',
    'wei',
    'weigela',
    'weigh',
    'weighbridge',
    'weighed',
    'weigher',
    'weighing',
    'weighs',
    'weight',
    'weighted',
    'weightiness',
    'weighting',
    'weightless',
    'weightlessness',
    'weightlift',
    'weightlifter',
    'weightlifters',
    'weightlifting',
    'weights',
    'weighty',
    'weil',
    'weill',
    'weimar',
    'weimaraner',
    'weinberg',
    'weir',
    'weird',
    'weirdie',
    'weirdness',
    'weirdo',
    'weirdy',
    'weisenheimer',
    'weismann',
    'weissbier',
    'weisshorn',
    'weizenbier',
    'weizenbock',
    'weizmann',
    'weka',
    'welch',
    'welcher',
    'welcome',
    'welcomed',
    'welcomer',
    'welcomes',
    'welcoming',
    'weld',
    'welded',
    'welder',
    'welders',
    'welding',
    'weldment',
    'welds',
    'welfare',
    'welfarist',
    'welkin',
    'well',
    'wellbeing',
    'wellborn',
    'welled',
    'wellerism',
    'welles',
    'wellhead',
    'welling',
    'wellington',
    'wellness',
    'wellpoint',
    'wells',
    'wellspring',
    'welsh',
    'welsher',
    'welshman',
    'welt',
    'weltanschauung',
    'welter',
    'weltered',
    'welterweight',
    'weltschmerz',
    'welty',
    'welwitschia',
    'welwitschiaceae',
    'wembley',
    'wen',
    'wench',
    'wencher',
    'wend',
    'wendell',
    'went',
    'wept',
    'were',
    'werewolf',
    'werfel',
    'werner',
    'wernicke',
    'weser',
    'wesley',
    'wesleyan',
    'wesleyanism',
    'wesleyism',
    'wessex',
    'west',
    'westbound',
    'westcott',
    'wester',
    'westerly',
    'western',
    'westerner',
    'westerners',
    'westernisation',
    'westernise',
    'westernization',
    'westernize',
    'westernized',
    'westernmost',
    'westinghouse',
    'westminster',
    'westmost',
    'weston',
    'westphalia',
    'westside',
    'westward',
    'wet',
    'wetback',
    'wether',
    'wetland',
    'wetlands',
    'wetness',
    'wetnurse',
    'wets',
    'wetted',
    'wetter',
    'wetting',
    'whack',
    'whacked',
    'whacker',
    'whacking',
    'whacko',
    'whacky',
    'whale',
    'whaleboat',
    'whalebone',
    'whaler',
    'whalers',
    'whales',
    'whalesucker',
    'whaling',
    'wham',
    'whammy',
    'whang',
    'whap',
    'wharf',
    'wharfage',
    'wharfed',
    'wharton',
    'wharves',
    'what',
    'whatchamacallit',
    'whatchamacallum',
    'whatever',
    'whatnot',
    'whatsis',
    'whatsoever',
    'whatver',
    'wheal',
    'wheat',
    'wheatear',
    'wheatears',
    'wheaten',
    'wheatfield',
    'wheatflake',
    'wheatgrass',
    'wheatley',
    'wheatstone',
    'wheatworm',
    'wheedle',
    'wheedler',
    'wheedling',
    'wheel',
    'wheelbarrow',
    'wheelbase',
    'wheelchair',
    'wheeled',
    'wheeler',
    'wheelhouse',
    'wheeling',
    'wheelless',
    'wheels',
    'wheelwork',
    'wheelwright',
    'wheeze',
    'wheeziness',
    'wheezing',
    'wheezy',
    'whelk',
    'whelks',
    'whelm',
    'whelp',
    'when',
    'whenever',
    'where',
    'whereabouts',
    'whereas',
    'whereby',
    'wherefore',
    'wherein',
    'wherewithal',
    'wherry',
    'whet',
    'whether',
    'whetstone',
    'whey',
    'which',
    'whicker',
    'whidah',
    'whiff',
    'whiffed',
    'whiffer',
    'whiffletree',
    'whiffletrees',
    'whig',
    'whigs',
    'while',
    'whim',
    'whimper',
    'whims',
    'whimsey',
    'whimsical',
    'whimsicality',
    'whimsically',
    'whimsy',
    'whin',
    'whinberry',
    'whinchat',
    'whine',
    'whiner',
    'whiney',
    'whining',
    'whiningly',
    'whinny',
    'whinstone',
    'whiny',
    'whip',
    'whipcord',
    'whiplash',
    'whiplike',
    'whipped',
    'whipper',
    'whippersnapper',
    'whippet',
    'whipping',
    'whippletree',
    'whippoorwill',
    'whippy',
    'whips',
    'whipsaw',
    'whipsnake',
    'whipstitch',
    'whipstitching',
    'whiptail',
    'whiptails',
    'whir',
    'whirl',
    'whirlaway',
    'whirled',
    'whirler',
    'whirligig',
    'whirling',
    'whirlpool',
    'whirls',
    'whirlwind',
    'whirlybird',
    'whirr',
    'whirring',
    'whish',
    'whished',
    'whishing',
    'whisk',
    'whisked',
    'whisker',
    'whiskered',
    'whiskerless',
    'whiskers',
    'whiskery',
    'whiskey',
    'whiskeys',
    'whiskies',
    'whisky',
    'whisper',
    'whispered',
    'whisperer',
    'whispering',
    'whist',
    'whistle',
    'whistleblower',
    'whistleblowers',
    'whistled',
    'whistler',
    'whistles',
    'whistlestop',
    'whistling',
    'whit',
    'white',
    'whitebait',
    'whitecap',
    'whitecup',
    'whiteface',
    'whitefish',
    'whitefishes',
    'whiteflies',
    'whitefly',
    'whitehall',
    'whitehead',
    'whitehorse',
    'whitelash',
    'whiten',
    'whitened',
    'whitener',
    'whiteness',
    'whitening',
    'whiteout',
    'whiter',
    'whites',
    'whitetail',
    'whitethorn',
    'whitethroat',
    'whitewash',
    'whitewashed',
    'whitewater',
    'whitewood',
    'whitey',
    'whiting',
    'whitings',
    'whitish',
    'whitlavia',
    'whitlow',
    'whitlows',
    'whitlowwort',
    'whitlowworts',
    'whitman',
    'whitmonday',
    'whitney',
    'whitsun',
    'whitsunday',
    'whitsuntide',
    'whittier',
    'whittle',
    'whittler',
    'whittles',
    'whittling',
    'whitweek',
    'whiz',
    'whizbang',
    'whizz',
    'whizzbang',
    'whizzing',
    'who',
    'whodunit',
    'whoever',
    'whole',
    'wholehearted',
    'wholeheartedly',
    'wholeheartedness',
    'wholemeal',
    'wholeness',
    'wholesale',
    'wholesaler',
    'wholesalers',
    'wholesome',
    'wholesomeness',
    'wholly',
    'whom',
    'whomp',
    'whoop',
    'whooped',
    'whoopee',
    'whooper',
    'whooping',
    'whoosh',
    'whooshed',
    'whooshing',
    'whop',
    'whopper',
    'whopping',
    'whore',
    'whored',
    'whoredom',
    'whorehouse',
    'whoremaster',
    'whoremonger',
    'whores',
    'whoreson',
    'whorl',
    'whorled',
    'whorls',
    'whorlywort',
    'whortleberry',
    'whose',
    'why',
    'whydah',
    'whydahs',
    'whys',
    'wi',
    'wicca',
    'wiccan',
    'wichita',
    'wick',
    'wicked',
    'wickedness',
    'wicker',
    'wickerwork',
    'wicket',
    'wickiup',
    'wickliffe',
    'wickup',
    'wiclif',
    'wicopy',
    'wide',
    'wideband',
    'widely',
    'widen',
    'widened',
    'wideness',
    'widening',
    'widens',
    'wider',
    'widespread',
    'widest',
    'widgeon',
    'widget',
    'widow',
    'widowed',
    'widower',
    'widowhood',
    'widowman',
    'width',
    'widths',
    'wieland',
    'wield',
    'wielded',
    'wielding',
    'wields',
    'wieldy',
    'wiener',
    'wienerwurst',
    'wiesbaden',
    'wiesel',
    'wiesenboden',
    'wiesenthal',
    'wife',
    'wifelike',
    'wifely',
    'wiffle',
    'wifi',
    'wig',
    'wigeon',
    'wigged',
    'wigging',
    'wiggle',
    'wiggler',
    'wiggliness',
    'wiggling',
    'wiggly',
    'wight',
    'wightiana',
    'wigless',
    'wigmaker',
    'wigner',
    'wigs',
    'wigwag',
    'wigwam',
    'wikiup',
    'wilbur',
    'wild',
    'wildcat',
    'wildcats',
    'wildcatter',
    'wilde',
    'wildebeest',
    'wilder',
    'wilderness',
    'wildest',
    'wildfire',
    'wildflower',
    'wildflowers',
    'wildfowl',
    'wilding',
    'wildlife',
    'wildly',
    'wildness',
    'wile',
    'wilets',
    'wilful',
    'wilfully',
    'wilfulness',
    'wilhelm',
    'wiliness',
    'wilkes',
    'wilkins',
    'wilkinson',
    'will',
    'willa',
    'willamette',
    'willard',
    'willebrand',
    'willed',
    'willet',
    'willful',
    'willfully',
    'willfulness',
    'william',
    'williams',
    'williamstown',
    'willies',
    'willing',
    'willingly',
    'willingness',
    'willis',
    'willow',
    'willowherb',
    'willows',
    'willowware',
    'willowy',
    'willpower',
    'wills',
    'wilmington',
    'wilmut',
    'wilno',
    'wilson',
    'wilsonian',
    'wilt',
    'wilted',
    'wilting',
    'wilton',
    'wily',
    'wimble',
    'wimbledon',
    'wimp',
    'wimpish',
    'wimple',
    'wimpy',
    'win',
    'wince',
    'winced',
    'wincey',
    'winceyette',
    'winch',
    'winchester',
    'winckelmann',
    'wind',
    'windage',
    'windaus',
    'windbag',
    'windblown',
    'windbreak',
    'windbreaker',
    'windburn',
    'windburned',
    'windburnt',
    'windcheater',
    'winded',
    'winder',
    'windfall',
    'windflower',
    'windhoek',
    'windily',
    'windiness',
    'winding',
    'windjammer',
    'windlass',
    'windless',
    'windlessness',
    'windmill',
    'window',
    'windowpane',
    'windows',
    'windowsill',
    'windpipe',
    'winds',
    'windscreen',
    'windshield',
    'windsock',
    'windsor',
    'windstorm',
    'windsurf',
    'windswept',
    'windtalker',
    'windup',
    'windward',
    'windy',
    'wine',
    'wineberry',
    'wined',
    'wineglass',
    'winemaker',
    'winemaking',
    'winepress',
    'winery',
    'wines',
    'winesap',
    'wineskin',
    'winey',
    'winfield',
    'winfred',
    'wing',
    'wingback',
    'winged',
    'winger',
    'wingless',
    'winglike',
    'wingman',
    'wings',
    'wingspan',
    'wingspread',
    'wingstem',
    'wining',
    'wink',
    'winked',
    'winker',
    'winking',
    'winkle',
    'winkled',
    'winks',
    'winless',
    'winnebago',
    'winner',
    'winners',
    'winning',
    'winnings',
    'winnipeg',
    'winnow',
    'winnowed',
    'winnowing',
    'wino',
    'wins',
    'winslow',
    'winsome',
    'winsomeness',
    'winston',
    'winter',
    'wintera',
    'winteraceae',
    'winterana',
    'winterberry',
    'wintered',
    'wintergreen',
    'winterise',
    'winterize',
    'winters',
    'wintertime',
    'wintery',
    'winthrop',
    'wintry',
    'wintun',
    'winy',
    'wipe',
    'wiped',
    'wipeout',
    'wiper',
    'wipes',
    'wiping',
    'wire',
    'wired',
    'wirehair',
    'wireless',
    'wireman',
    'wirer',
    'wires',
    'wiretap',
    'wiretapper',
    'wiretaps',
    'wirework',
    'wireworm',
    'wiriness',
    'wiring',
    'wiry',
    'wisconsin',
    'wisconsinite',
    'wisdom',
    'wise',
    'wiseacre',
    'wisecrack',
    'wised',
    'wisely',
    'wiseness',
    'wisenheimer',
    'wisent',
    'wiser',
    'wish',
    'wishbone',
    'wished',
    'wishes',
    'wishful',
    'wishfulness',
    'wishing',
    'wisp',
    'wisplike',
    'wisps',
    'wispy',
    'wistaria',
    'wister',
    'wisteria',
    'wistful',
    'wistfulness',
    'wit',
    'witch',
    'witchcraft',
    'witchery',
    'witches',
    'witchgrass',
    'witching',
    'witchlike',
    'with',
    'withdraw',
    'withdrawal',
    'withdrawals',
    'withdrawer',
    'withdrawing',
    'withdrawn',
    'withdrawnness',
    'withdraws',
    'withdrew',
    'withe',
    'wither',
    'withered',
    'withering',
    'withers',
    'witherspoon',
    'withheld',
    'withhold',
    'withholder',
    'withholding',
    'within',
    'without',
    'withstand',
    'withstander',
    'withstanders',
    'withstanding',
    'withstands',
    'withstood',
    'withy',
    'witless',
    'witloof',
    'witness',
    'witnessed',
    'witnesser',
    'witnesses',
    'witnessing',
    'wits',
    'wittgenstein',
    'wittgensteinian',
    'witticism',
    'wittiness',
    'witting',
    'wittol',
    'witty',
    'witwatersrand',
    'wive',
    'wivern',
    'wives',
    'wiz',
    'wizard',
    'wizardly',
    'wizardry',
    'wizen',
    'wizened',
    'wlan',
    'wmd',
    'wmo',
    'wnw',
    'woad',
    'woadwaxen',
    'wobble',
    'wobbled',
    'wobbler',
    'wobbles',
    'wobbling',
    'wobbly',
    'wodan',
    'wodehouse',
    'woden',
    'woe',
    'woebegone',
    'woeful',
    'woefully',
    'woefulness',
    'wog',
    'wok',
    'woke',
    'wold',
    'wolf',
    'wolfbane',
    'wolfe',
    'wolfed',
    'wolff',
    'wolffia',
    'wolffiella',
    'wolffish',
    'wolffishes',
    'wolfgang',
    'wolfhound',
    'wolfish',
    'wolflike',
    'wolfman',
    'wolfram',
    'wolframite',
    'wolfsbane',
    'wollaston',
    'wollastonite',
    'wollemi',
    'wollstonecraft',
    'wolof',
    'wolverine',
    'wolves',
    'woman',
    'womanhood',
    'womanise',
    'womaniser',
    'womanish',
    'womanishness',
    'womanize',
    'womanizer',
    'womanizing',
    'womankind',
    'womanlike',
    'womanliness',
    'womanly',
    'womb',
    'wombat',
    'wombats',
    'women',
    'won',
    'wonder',
    'wonderberry',
    'wondered',
    'wonderer',
    'wonderful',
    'wonderfully',
    'wonderfulness',
    'wonderland',
    'wonderment',
    'wonders',
    'wonderworking',
    'wondrous',
    'wong',
    'wonk',
    'wonky',
    'wont',
    'wonted',
    'wonton',
    'woo',
    'wood',
    'woodbine',
    'woodborer',
    'woodbury',
    'woodcarver',
    'woodcarving',
    'woodchuck',
    'woodchucks',
    'woodcock',
    'woodcocks',
    'woodcraft',
    'woodcreeper',
    'woodcreepers',
    'woodcut',
    'woodcuts',
    'woodcutter',
    'wooded',
    'wooden',
    'woodenness',
    'woodenware',
    'woodfern',
    'woodgrain',
    'woodgraining',
    'woodhewer',
    'woodhewers',
    'woodhull',
    'woodiness',
    'woodland',
    'woodlands',
    'woodlet',
    'woodlice',
    'woodlouse',
    'woodman',
    'woodpecker',
    'woodpeckers',
    'woodpile',
    'woodrow',
    'woodruff',
    'woods',
    'woodscrew',
    'woodshed',
    'woodsia',
    'woodsiness',
    'woodsman',
    'woodstock',
    'woodsy',
    'woodward',
    'woodwardia',
    'woodwaxen',
    'woodwind',
    'woodwinds',
    'woodwork',
    'woodworker',
    'woodworking',
    'woodworm',
    'woody',
    'wooed',
    'wooer',
    'woof',
    'woofer',
    'wooing',
    'wool',
    'woolen',
    'woolens',
    'woolf',
    'woolgather',
    'woolgatherer',
    'woolgathering',
    'woollcott',
    'woollen',
    'woolley',
    'woolly',
    'woolsorter',
    'woolworth',
    'wooly',
    'woosh',
    'woozy',
    'wop',
    'worcester',
    'worcestershire',
    'word',
    'wordbook',
    'worded',
    'wordfinder',
    'wordiness',
    'wording',
    'wordless',
    'wordmonger',
    'wordnet',
    'wordplay',
    'words',
    'wordsmith',
    'wordsworth',
    'wordsworthian',
    'wordy',
    'wore',
    'work',
    'workable',
    'workaday',
    'workaholic',
    'workaholism',
    'workbag',
    'workbasket',
    'workbench',
    'workboard',
    'workbook',
    'workbox',
    'workday',
    'worked',
    'worker',
    'workers',
    'workfellow',
    'workflow',
    'workforce',
    'workhorse',
    'workhouse',
    'working',
    'workingman',
    'workings',
    'workload',
    'workman',
    'workmanlike',
    'workmanship',
    'workmate',
    'workmen',
    'workout',
    'workpiece',
    'workplace',
    'workroom',
    'works',
    'worksheet',
    'workshop',
    'workspace',
    'workstation',
    'workstations',
    'worktable',
    'workwear',
    'workweek',
    'world',
    'worldliness',
    'worldling',
    'worldly',
    'worlds',
    'worldwide',
    'worm',
    'wormcast',
    'wormhole',
    'wormlike',
    'worms',
    'wormseed',
    'wormwood',
    'wormy',
    'worn',
    'worried',
    'worrier',
    'worries',
    'worriment',
    'worrisome',
    'worry',
    'worrying',
    'worryingly',
    'worrywart',
    'worse',
    'worsen',
    'worsened',
    'worsening',
    'worship',
    'worshiped',
    'worshiper',
    'worshipful',
    'worshiping',
    'worshipped',
    'worshipper',
    'worshippers',
    'worshipping',
    'worships',
    'worst',
    'worsted',
    'wort',
    'worth',
    'worthful',
    'worthies',
    'worthiness',
    'worthless',
    'worthlessness',
    'worthwhile',
    'worthwhileness',
    'worthy',
    'wotan',
    'wouk',
    'would',
    'wound',
    'wounded',
    'wounding',
    'wounds',
    'woven',
    'wow',
    'wowed',
    'wpm',
    'wrack',
    'wraith',
    'wraithlike',
    'wrangle',
    'wrangler',
    'wrangling',
    'wrap',
    'wraparound',
    'wrapped',
    'wrapper',
    'wrapping',
    'wraps',
    'wrasse',
    'wrasses',
    'wrath',
    'wrathful',
    'wrawl',
    'wreak',
    'wreaking',
    'wreath',
    'wreathe',
    'wreck',
    'wreckage',
    'wrecked',
    'wrecker',
    'wreckfish',
    'wrecking',
    'wrecks',
    'wren',
    'wrench',
    'wrenched',
    'wrenching',
    'wrens',
    'wrest',
    'wrester',
    'wrestle',
    'wrestled',
    'wrestler',
    'wrestlers',
    'wrestling',
    'wretch',
    'wretched',
    'wretchedness',
    'wretches',
    'wrick',
    'wriggle',
    'wriggler',
    'wriggling',
    'wriggly',
    'wright',
    'wring',
    'wringer',
    'wrinkle',
    'wrinkled',
    'wrinkleless',
    'wrinkleproof',
    'wrinkles',
    'wrinkly',
    'wrist',
    'wristband',
    'wristlet',
    'wrists',
    'wristwatch',
    'writ',
    'write',
    'writer',
    'writers',
    'writes',
    'writhe',
    'writhed',
    'writhen',
    'writhing',
    'writing',
    'writings',
    'writs',
    'written',
    'wroclaw',
    'wrong',
    'wrongdoer',
    'wrongdoing',
    'wrongful',
    'wrongfully',
    'wrongfulness',
    'wrongheaded',
    'wrongly',
    'wrongness',
    'wrongs',
    'wrote',
    'wroth',
    'wrothful',
    'wrought',
    'wry',
    'wrymouth',
    'wryneck',
    'wrynecks',
    'ws',
    'wsw',
    'wtc',
    'wto',
    'wtv',
    'wu',
    'wuerzburg',
    'wuhan',
    'wulfenite',
    'wulfila',
    'wurlitzer',
    'wurtzite',
    'wurzburg',
    'wuss',
    'wv',
    'ww',
    'www',
    'wy',
    'wyat',
    'wyatt',
    'wycherley',
    'wyck',
    'wyclif',
    'wycliffe',
    'wye',
    'wyeth',
    'wykeham',
    'wykehamist',
    'wyler',
    'wylie',
    'wyllis',
    'wynette',
    'wynfrith',
    'wynnea',
    'wyoming',
    'wyomingite',
    'wyrd',
    'wysiwyg',
    'wyszynski',
    'wytensin',
    'wyvern']
