
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_k_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.175457'}

wordnet_terms_k = [
    'ka',
    'kaaba',
    'kabala',
    'kabbala',
    'kabbalah',
    'kabbalism',
    'kabbalist',
    'kabbalistic',
    'kabob',
    'kabolin',
    'kabul',
    'kach',
    'kachaturian',
    'kachin',
    'kachina',
    'kachinic',
    'kadai',
    'kadikoy',
    'kaffir',
    'kaffiyeh',
    'kafir',
    'kafiri',
    'kafka',
    'kafkaesque',
    'kafocin',
    'kaftan',
    'kahikatea',
    'kahlua',
    'kahn',
    'kahoolawe',
    'kail',
    'kainite',
    'kainogenesis',
    'kaiser',
    'kakatoe',
    'kakemono',
    'kaki',
    'kakutani',
    'kalahari',
    'kalamazoo',
    'kalansuwa',
    'kalantas',
    'kalapooia',
    'kalapooian',
    'kalapuya',
    'kalapuyan',
    'kalashnikov',
    'kale',
    'kaleidoscope',
    'kaleidoscopic',
    'kaleidoscopical',
    'kalemia',
    'kali',
    'kalian',
    'kalif',
    'kalimantan',
    'kalinin',
    'kaliph',
    'kaliuresis',
    'kalka',
    'kalki',
    'kalmia',
    'kalotermes',
    'kalotermitidae',
    'kalpac',
    'kaluga',
    'kalumpang',
    'kaluresis',
    'kama',
    'kamarupan',
    'kamasutra',
    'kamba',
    'kamchatka',
    'kameez',
    'kamet',
    'kami',
    'kamia',
    'kamikaze',
    'kampala',
    'kampong',
    'kampuchea',
    'kampuchean',
    'kanaf',
    'kanamycin',
    'kananga',
    'kanara',
    'kanarese',
    'kanawha',
    'kanchanjanga',
    'kanchenjunga',
    'kanchil',
    'kandahar',
    'kandinski',
    'kandinsky',
    'kandy',
    'kangaroo',
    'kangaroos',
    'kannada',
    'kansa',
    'kansan',
    'kansas',
    'kansu',
    'kant',
    'kantian',
    'kantrex',
    'kanzu',
    'kaochlor',
    'kaoliang',
    'kaolin',
    'kaoline',
    'kaolinite',
    'kaon',
    'kaopectate',
    'kapeika',
    'kapeikas',
    'kaph',
    'kapital',
    'kapok',
    'kappa',
    'kapsiki',
    'kapuka',
    'kara',
    'karabiner',
    'karachi',
    'karaites',
    'karakalpak',
    'karakoram',
    'karakul',
    'karaoke',
    'karat',
    'karate',
    'karbala',
    'karelia',
    'karelian',
    'karen',
    'karenic',
    'karl',
    'karlfeldt',
    'karloff',
    'karma',
    'karnataka',
    'karok',
    'karpov',
    'karsavina',
    'kartik',
    'kartikeya',
    'karttika',
    'karttikeya',
    'karyokinesis',
    'karyokinetic',
    'karyolymph',
    'karyolysis',
    'karyon',
    'karyoplasm',
    'karyotype',
    'kasai',
    'kasbah',
    'kasha',
    'kashag',
    'kashmir',
    'kashmiri',
    'kasparov',
    'kassite',
    'kassites',
    'kastler',
    'kat',
    'katabatic',
    'katabolic',
    'katabolism',
    'katamorphism',
    'katar',
    'katari',
    'kate',
    'katharevusa',
    'katharine',
    'katharobe',
    'katharobic',
    'katharometer',
    'katharsis',
    'kathleen',
    'kathmandu',
    'katmandu',
    'katowice',
    'katsina',
    'katsura',
    'katsuwonidae',
    'katsuwonus',
    'kattegatt',
    'katydid',
    'katydids',
    'katzenjammer',
    'kauai',
    'kaufman',
    'kaunas',
    'kaunda',
    'kauri',
    'kaury',
    'kava',
    'kavakava',
    'kavrin',
    'kawaka',
    'kayak',
    'kayaked',
    'kayo',
    'kayoed',
    'kazak',
    'kazakh',
    'kazakhs',
    'kazakhstan',
    'kazakhstani',
    'kazakstan',
    'kazan',
    'kazimir',
    'kazoo',
    'kazoos',
    'kb',
    'kbit',
    'kbo',
    'kc',
    'kea',
    'kean',
    'keaton',
    'keats',
    'keb',
    'kebab',
    'keble',
    'kechua',
    'kechuan',
    'ked',
    'kedah',
    'kedgeree',
    'keel',
    'keelboat',
    'keeled',
    'keelson',
    'keen',
    'keenly',
    'keenness',
    'keep',
    'keeper',
    'keepeth',
    'keeping',
    'keeps',
    'keepsake',
    'keeshond',
    'keflex',
    'keflin',
    'keftab',
    'keg',
    'kegful',
    'kegs',
    'keister',
    'kekchi',
    'kekule',
    'kelantan',
    'keller',
    'kellogg',
    'kelly',
    'keloid',
    'kelp',
    'kelpie',
    'kelps',
    'kelpwort',
    'kelpy',
    'kelt',
    'kelter',
    'kelvin',
    'kemadrin',
    'kemal',
    'kempt',
    'ken',
    'kenaf',
    'kenalog',
    'kendal',
    'kendall',
    'kendrew',
    'kennan',
    'kennedia',
    'kennedy',
    'kennedya',
    'kennel',
    'kennelly',
    'kenneth',
    'kennewick',
    'kenning',
    'keno',
    'kenogenesis',
    'kenosis',
    'kent',
    'kentan',
    'kentish',
    'kentuckian',
    'kentucky',
    'kenya',
    'kenyan',
    'kenyapithecus',
    'kenyata',
    'keokuk',
    'kepi',
    'kepler',
    'kept',
    'kera',
    'keratalgia',
    'keratectasia',
    'keratin',
    'keratinisation',
    'keratinise',
    'keratinization',
    'keratinize',
    'keratinized',
    'keratitis',
    'keratoacanthoma',
    'keratocele',
    'keratoconjunctivitis',
    'keratoconus',
    'keratoderma',
    'keratodermia',
    'keratohyalin',
    'keratoiritis',
    'keratomalacia',
    'keratomycosis',
    'keratonosis',
    'keratonosus',
    'keratoplasty',
    'keratoscleritis',
    'keratoscope',
    'keratoscopy',
    'keratosis',
    'keratotomy',
    'kerb',
    'kerbala',
    'kerbela',
    'kerbstone',
    'kerchief',
    'kerensky',
    'kerfuffle',
    'kerion',
    'kern',
    'kernel',
    'kernels',
    'kernicterus',
    'kernite',
    'kerosene',
    'kerosine',
    'kerouac',
    'kerugma',
    'kerygma',
    'kesey',
    'kestrel',
    'ketalar',
    'ketamine',
    'ketch',
    'ketchup',
    'keteleeria',
    'ketembilla',
    'ketoacidosis',
    'ketoaciduria',
    'ketohexose',
    'ketone',
    'ketonemia',
    'ketones',
    'ketonuria',
    'ketoprofen',
    'ketorolac',
    'ketose',
    'ketosis',
    'ketosteroid',
    'kettering',
    'kettle',
    'kettledrum',
    'kettledrums',
    'kettleful',
    'kettles',
    'ketubim',
    'keurboom',
    'key',
    'keyboard',
    'keyboardist',
    'keyboards',
    'keycard',
    'keyed',
    'keyhole',
    'keyless',
    'keynes',
    'keynesian',
    'keynesianism',
    'keynote',
    'keynotes',
    'keypad',
    'keys',
    'keystone',
    'keystroke',
    'keystrokes',
    'kg',
    'kgb',
    'khabarovsk',
    'khachaturian',
    'khadafy',
    'khaddar',
    'khadi',
    'khaki',
    'khakis',
    'khalif',
    'khalifah',
    'khalka',
    'khalkha',
    'khalsa',
    'khama',
    'khamsin',
    'khamti',
    'khan',
    'khanate',
    'khanty',
    'kharkiv',
    'kharkov',
    'khartoum',
    'khat',
    'khaya',
    'khayyam',
    'khedive',
    'khepera',
    'khesari',
    'khi',
    'khimar',
    'khios',
    'khirghiz',
    'khmer',
    'khoikhoi',
    'khoikhoin',
    'khoisan',
    'khomeini',
    'khoum',
    'khoums',
    'khowar',
    'khrushchev',
    'khuen',
    'khufu',
    'khukuri',
    'khyber',
    'khz',
    'ki',
    'kiaat',
    'kiang',
    'kib',
    'kibbitz',
    'kibble',
    'kibbutz',
    'kibbutznik',
    'kibe',
    'kibibit',
    'kibibits',
    'kibibyte',
    'kibibytes',
    'kibit',
    'kibitz',
    'kibitzer',
    'kibosh',
    'kichaga',
    'kichai',
    'kick',
    'kickapoo',
    'kickback',
    'kicked',
    'kicker',
    'kicking',
    'kickoff',
    'kicks',
    'kickshaw',
    'kicksorter',
    'kickstand',
    'kid',
    'kidd',
    'kidded',
    'kiddie',
    'kiddy',
    'kidnap',
    'kidnaper',
    'kidnapped',
    'kidnapper',
    'kidnappers',
    'kidnapping',
    'kidnappings',
    'kidney',
    'kidneys',
    'kids',
    'kidskin',
    'kierkegaard',
    'kieselguhr',
    'kieserite',
    'kieslowski',
    'kiev',
    'kigali',
    'kiggelaria',
    'kike',
    'kikladhes',
    'kildeer',
    'kilderkin',
    'kiley',
    'kilimanjaro',
    'kiliwa',
    'kiliwi',
    'kill',
    'killable',
    'killdeer',
    'killed',
    'killer',
    'killers',
    'killifish',
    'killing',
    'killjoy',
    'kills',
    'kiln',
    'kilns',
    'kilo',
    'kilobit',
    'kilobits',
    'kilobyte',
    'kilobytes',
    'kilocalorie',
    'kilocycle',
    'kilogram',
    'kilograms',
    'kilohertz',
    'kiloliter',
    'kilolitre',
    'kilometer',
    'kilometers',
    'kilometre',
    'kiloton',
    'kilovolt',
    'kilowatt',
    'kilroy',
    'kilt',
    'kilter',
    'kilts',
    'kimberley',
    'kimberlite',
    'kimono',
    'kin',
    'kina',
    'kinaesthesia',
    'kinaesthesis',
    'kinaesthetic',
    'kinanesthesia',
    'kinase',
    'kinchinjunga',
    'kind',
    'kindergarten',
    'kindergartener',
    'kindergartner',
    'kindhearted',
    'kindheartedness',
    'kindle',
    'kindled',
    'kindliness',
    'kindling',
    'kindly',
    'kindness',
    'kindred',
    'kinds',
    'kine',
    'kinematics',
    'kinescope',
    'kinesiology',
    'kinesis',
    'kinesthesia',
    'kinesthesis',
    'kinesthetic',
    'kinesthetics',
    'kinetic',
    'kinetics',
    'kinetochore',
    'kinetoscope',
    'kinetosis',
    'kinfolk',
    'king',
    'kingbird',
    'kingbolt',
    'kingcup',
    'kingdom',
    'kingdoms',
    'kingfish',
    'kingfisher',
    'kingfishers',
    'kinglet',
    'kinglets',
    'kinglike',
    'kingly',
    'kingmaker',
    'kingpin',
    'kings',
    'kingship',
    'kingsley',
    'kingsnake',
    'kingston',
    'kingstown',
    'kingwood',
    'kinin',
    'kink',
    'kinkajou',
    'kinks',
    'kinky',
    'kino',
    'kinosternidae',
    'kinosternon',
    'kinsey',
    'kinsfolk',
    'kinshasa',
    'kinship',
    'kinsman',
    'kinsperson',
    'kinswoman',
    'kinyarwanda',
    'kiosk',
    'kiowa',
    'kip',
    'kipling',
    'kiplingesque',
    'kipper',
    'kippur',
    'kirchhoff',
    'kirchner',
    'kirghiz',
    'kirghizia',
    'kirghizstan',
    'kirgiz',
    'kirgizia',
    'kirgizstan',
    'kiribati',
    'kirk',
    'kirkia',
    'kirkuk',
    'kirpan',
    'kirsch',
    'kirtle',
    'kishar',
    'kishinev',
    'kishke',
    'kislev',
    'kismat',
    'kismet',
    'kiss',
    'kissed',
    'kisser',
    'kisses',
    'kissimmee',
    'kissing',
    'kissinger',
    'kisumu',
    'kiswahili',
    'kit',
    'kitakyushu',
    'kitambilla',
    'kitbag',
    'kitchen',
    'kitchener',
    'kitchenette',
    'kitchens',
    'kitchenware',
    'kite',
    'kited',
    'kitembilla',
    'kites',
    'kith',
    'kiting',
    'kits',
    'kitsch',
    'kitschy',
    'kittee',
    'kitten',
    'kittened',
    'kittenish',
    'kittiwake',
    'kitts',
    'kittul',
    'kitty',
    'kitul',
    'kivu',
    'kiwi',
    'kiwis',
    'kkk',
    'klaipeda',
    'klamath',
    'klan',
    'klansman',
    'klaproth',
    'klavern',
    'klavier',
    'klaxon',
    'klebsiella',
    'klee',
    'kleenex',
    'klein',
    'kleist',
    'kleptomania',
    'kleptomaniac',
    'klick',
    'klimt',
    'kline',
    'klinefelter',
    'klondike',
    'klopstock',
    'klorvess',
    'klotho',
    'kludge',
    'klutz',
    'klux',
    'kluxer',
    'klystron',
    'klyuchevskaya',
    'km',
    'knack',
    'knacker',
    'knackered',
    'knackwurst',
    'knap',
    'knapsack',
    'knapweed',
    'knave',
    'knavery',
    'knavish',
    'knawe',
    'knawel',
    'knead',
    'kneaded',
    'kneading',
    'kneads',
    'knee',
    'kneecap',
    'kneecapped',
    'kneel',
    'kneeler',
    'kneeling',
    'kneepan',
    'knees',
    'knell',
    'knesset',
    'knesseth',
    'knew',
    'knickerbockers',
    'knickers',
    'knickknack',
    'knickknackery',
    'knicks',
    'knife',
    'knifed',
    'knifelike',
    'knight',
    'knighted',
    'knighthood',
    'knightia',
    'knightliness',
    'knightly',
    'knights',
    'kniphofia',
    'knish',
    'knit',
    'knitted',
    'knitter',
    'knitting',
    'knitwear',
    'knitwork',
    'knives',
    'knob',
    'knobbed',
    'knobble',
    'knobbly',
    'knobby',
    'knobkerrie',
    'knobkerry',
    'knobs',
    'knock',
    'knockabout',
    'knockdown',
    'knocked',
    'knocker',
    'knocking',
    'knockoff',
    'knockout',
    'knocks',
    'knockwurst',
    'knoll',
    'knossos',
    'knot',
    'knotgrass',
    'knothole',
    'knots',
    'knotted',
    'knottiness',
    'knotting',
    'knotty',
    'knout',
    'know',
    'knowable',
    'knower',
    'knowing',
    'knowingly',
    'knowingness',
    'knowledge',
    'knowledgeability',
    'knowledgeable',
    'knowledgeableness',
    'known',
    'knows',
    'knox',
    'knoxville',
    'knuckle',
    'knuckleball',
    'knucklebones',
    'knucklehead',
    'knuckler',
    'knuckles',
    'knucks',
    'knut',
    'ko',
    'koala',
    'koalas',
    'koan',
    'koasati',
    'kob',
    'kobe',
    'kobenhavn',
    'kobo',
    'kobos',
    'kobus',
    'koch',
    'kochia',
    'kodiak',
    'koellia',
    'koestler',
    'kogia',
    'kohl',
    'kohleria',
    'kohlrabi',
    'koine',
    'koinonia',
    'kokka',
    'kola',
    'kolam',
    'kolami',
    'kolkata',
    'kolkhoz',
    'kolkhoznik',
    'kolkwitzia',
    'koln',
    'kolonia',
    'komi',
    'komondor',
    'konakri',
    'kong',
    'kongfuze',
    'kongo',
    'konini',
    'konoe',
    'konoye',
    'konqueror',
    'koodoo',
    'kook',
    'kookaburra',
    'kookie',
    'kooky',
    'koopmans',
    'kopeck',
    'kopecks',
    'kopek',
    'kopiyka',
    'kopiykas',
    'kopje',
    'koppie',
    'kor',
    'koran',
    'koranic',
    'korbut',
    'korchnoi',
    'korda',
    'kordofan',
    'kordofanian',
    'kore',
    'korea',
    'korean',
    'koreans',
    'korinthos',
    'koruna',
    'korzybski',
    'kos',
    'kosciusko',
    'kosciuszko',
    'kosher',
    'kosma',
    'kosovo',
    'kosteletzya',
    'kota',
    'kotar',
    'kotex',
    'koto',
    'kotoko',
    'kotow',
    'koudou',
    'koumiss',
    'koussevitzky',
    'kovacs',
    'kovna',
    'kovno',
    'koweit',
    'kowhai',
    'kowtow',
    'kowtowing',
    'kp',
    'kph',
    'kr',
    'kra',
    'kraal',
    'kraft',
    'krait',
    'kraits',
    'krakatao',
    'krakatau',
    'krakatoa',
    'krakau',
    'krakow',
    'krasner',
    'kraurosis',
    'kraut',
    'krauthead',
    'krebs',
    'kreisler',
    'kremlin',
    'krigia',
    'krill',
    'kris',
    'krishna',
    'krishnaism',
    'krispies',
    'kriti',
    'kroeber',
    'krona',
    'krone',
    'kronecker',
    'kronenbergers',
    'kroon',
    'kropotkin',
    'kroto',
    'krubi',
    'kruger',
    'krummhorn',
    'krupp',
    'krypterophaneron',
    'krypton',
    'ks',
    'kshatriya',
    'kshatriyas',
    'kt',
    'ku',
    'kuala',
    'kuan',
    'kuangchou',
    'kublai',
    'kubrick',
    'kuchean',
    'kudos',
    'kudu',
    'kudzu',
    'kuenlun',
    'kuhn',
    'kui',
    'kuiper',
    'kukenaam',
    'kuki',
    'kulanapan',
    'kulun',
    'kumasi',
    'kumis',
    'kummel',
    'kumquat',
    'kumquats',
    'kung',
    'kunlun',
    'kunzite',
    'kuomintang',
    'kura',
    'kurakkan',
    'kurchee',
    'kurchi',
    'kurd',
    'kurdish',
    'kurdistan',
    'kurds',
    'kurosawa',
    'kuroshio',
    'kurrajong',
    'kurrat',
    'kursk',
    'kurta',
    'kuru',
    'kurus',
    'kurux',
    'kusan',
    'kush',
    'kutch',
    'kutuzov',
    'kuvasz',
    'kuvi',
    'kuwait',
    'kuwaiti',
    'kuznets',
    'kv',
    'kvass',
    'kvetch',
    'kw',
    'kwa',
    'kwacha',
    'kwai',
    'kwajalein',
    'kwakiutl',
    'kwangchow',
    'kwangju',
    'kwangtung',
    'kwannon',
    'kwanza',
    'kwanzaa',
    'kwashiorkor',
    'kweek',
    'kwela',
    'kwell',
    'ky',
    'kyanite',
    'kyat',
    'kyd',
    'kylie',
    'kylix',
    'kymograph',
    'kyoto',
    'kyphosidae',
    'kyphosis',
    'kyphosus',
    'kyphotic',
    'kyrgyzstan',
    'kyrgyzstani',
    'kyushu',
    'kyyiv']
