
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_x_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.242458'}

wordnet_terms_x = [
    'xanax',
    'xanthate',
    'xanthelasma',
    'xanthemia',
    'xanthic',
    'xanthine',
    'xanthium',
    'xanthoma',
    'xanthomas',
    'xanthomatosis',
    'xanthomonad',
    'xanthomonas',
    'xanthophyceae',
    'xanthophyl',
    'xanthophyll',
    'xanthopsia',
    'xanthorrhoeaceae',
    'xanthorroea',
    'xanthosis',
    'xanthosoma',
    'xanthous',
    'xantusiidae',
    'xavier',
    'xbox',
    'xc',
    'xci',
    'xcii',
    'xciii',
    'xciv',
    'xcl',
    'xcv',
    'xcvi',
    'xcvii',
    'xcviii',
    'xe',
    'xenarthra',
    'xenicidae',
    'xenicus',
    'xenogeneic',
    'xenogenesis',
    'xenograft',
    'xenolith',
    'xenon',
    'xenophanes',
    'xenophobia',
    'xenophobic',
    'xenophon',
    'xenopodidae',
    'xenopus',
    'xenorhyncus',
    'xenosauridae',
    'xenosaurus',
    'xenotime',
    'xenotransplant',
    'xenotransplantation',
    'xeranthemum',
    'xeric',
    'xerobates',
    'xeroderma',
    'xerodermia',
    'xerographic',
    'xerography',
    'xeroma',
    'xerophile',
    'xerophthalmia',
    'xerophthalmus',
    'xerophyllum',
    'xerophyte',
    'xerophytes',
    'xerophytic',
    'xeroradiography',
    'xerostomia',
    'xerotes',
    'xerox',
    'xhosa',
    'xi',
    'xian',
    'xiao',
    'xii',
    'xiii',
    'xinjiang',
    'xiphias',
    'xiphiidae',
    'xiphosura',
    'xiv',
    'xix',
    'xizang',
    'xl',
    'xli',
    'xlii',
    'xliii',
    'xliv',
    'xlv',
    'xlvi',
    'xlvii',
    'xlviii',
    'xmas',
    'xt',
    'xtc',
    'xv',
    'xvi',
    'xvii',
    'xviii',
    'xx',
    'xxi',
    'xxii',
    'xxiii',
    'xxiv',
    'xxix',
    'xxv',
    'xxvi',
    'xxvii',
    'xxviii',
    'xxx',
    'xxxi',
    'xxxii',
    'xxxiii',
    'xxxiv',
    'xxxv',
    'xxxvi',
    'xxxvii',
    'xxxviii',
    'xxy',
    'xy',
    'xylaria',
    'xylariaceae',
    'xylem',
    'xylene',
    'xylocaine',
    'xylocopa',
    'xylol',
    'xylomelum',
    'xylophone',
    'xylophones',
    'xylophonist',
    'xylopia',
    'xylose',
    'xylosma',
    'xyphophorus',
    'xyridaceae',
    'xyridales',
    'xyris',
    'xyy']
