
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_q_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.205958'}

wordnet_terms_q = [
    'qabala',
    'qabalah',
    'qabalistic',
    'qabbala',
    'qabbalah',
    'qaddafi',
    'qadhafi',
    'qadi',
    'qaeda',
    'qandahar',
    'qat',
    'qatar',
    'qatari',
    'qcd',
    'qed',
    'qepiq',
    'qi',
    'qiang',
    'qiangic',
    'qibla',
    'qin',
    'qindarka',
    'qing',
    'qintar',
    'qoph',
    'quaalude',
    'quack',
    'quackery',
    'quackgrass',
    'quacking',
    'quad',
    'quadragesima',
    'quadrangle',
    'quadrangles',
    'quadrangular',
    'quadrant',
    'quadrantanopia',
    'quadraphonic',
    'quadraphony',
    'quadrasonic',
    'quadrate',
    'quadratic',
    'quadratics',
    'quadrature',
    'quadrennium',
    'quadric',
    'quadriceps',
    'quadrilateral',
    'quadrilaterals',
    'quadrille',
    'quadrillion',
    'quadrillionth',
    'quadripara',
    'quadripartite',
    'quadriphonic',
    'quadriplegia',
    'quadriplegic',
    'quadrisonic',
    'quadrivium',
    'quadroon',
    'quadrumvirate',
    'quadruped',
    'quadrupedal',
    'quadrupeds',
    'quadruple',
    'quadruplet',
    'quadruplex',
    'quadruplicate',
    'quadrupling',
    'quaestor',
    'quaff',
    'quaffed',
    'quaffer',
    'quag',
    'quagga',
    'quaggy',
    'quagmire',
    'quahaug',
    'quahog',
    'quail',
    'quaint',
    'quaintness',
    'quake',
    'quaker',
    'quakerism',
    'quakers',
    'quakes',
    'quaking',
    'qualification',
    'qualifications',
    'qualified',
    'qualifier',
    'qualifies',
    'qualify',
    'qualifying',
    'qualitative',
    'qualities',
    'quality',
    'qualm',
    'quamash',
    'quamassia',
    'quandang',
    'quandary',
    'quandong',
    'quango',
    'quanta',
    'quantal',
    'quantic',
    'quantifiability',
    'quantifiable',
    'quantification',
    'quantified',
    'quantifier',
    'quantifiers',
    'quantify',
    'quantisation',
    'quantise',
    'quantitative',
    'quantities',
    'quantity',
    'quantization',
    'quantize',
    'quantized',
    'quantong',
    'quantum',
    'quaoar',
    'quapaw',
    'quarantine',
    'quarantined',
    'quark',
    'quarks',
    'quarrel',
    'quarreled',
    'quarreler',
    'quarreling',
    'quarrelled',
    'quarreller',
    'quarrels',
    'quarrelsome',
    'quarrelsomeness',
    'quarrier',
    'quarries',
    'quarry',
    'quarrying',
    'quarryman',
    'quart',
    'quartan',
    'quarter',
    'quarterback',
    'quarterdeck',
    'quartered',
    'quarterfinal',
    'quartering',
    'quarterlight',
    'quarterly',
    'quartermaster',
    'quartern',
    'quarters',
    'quarterstaff',
    'quartervine',
    'quartet',
    'quartette',
    'quartic',
    'quartile',
    'quarto',
    'quarts',
    'quartz',
    'quartzite',
    'quartzose',
    'quasar',
    'quash',
    'quashes',
    'quasi',
    'quasiparticle',
    'quassia',
    'quat',
    'quatercentenary',
    'quatercentennial',
    'quatern',
    'quaternary',
    'quaternate',
    'quaternion',
    'quaternity',
    'quatrain',
    'quatrains',
    'quattrocento',
    'quaver',
    'quavering',
    'quay',
    'quayage',
    'queasiness',
    'queasy',
    'quebec',
    'quebecois',
    'quechua',
    'quechuan',
    'queen',
    'queenfish',
    'queenlike',
    'queenly',
    'queens',
    'queensland',
    'queer',
    'queerness',
    'quell',
    'quelled',
    'quelling',
    'quellung',
    'quench',
    'quenched',
    'quenching',
    'quenchless',
    'quercitron',
    'quercus',
    'querier',
    'quern',
    'querulous',
    'querulousness',
    'query',
    'quesadilla',
    'quest',
    'quester',
    'questing',
    'question',
    'questionable',
    'questioned',
    'questioner',
    'questioning',
    'questionnaire',
    'questions',
    'quetch',
    'quetzal',
    'quetzalcoatl',
    'queue',
    'quiaquia',
    'quibble',
    'quibbler',
    'quiche',
    'quick',
    'quicken',
    'quickener',
    'quickening',
    'quickens',
    'quicker',
    'quickest',
    'quickie',
    'quicklime',
    'quickly',
    'quickness',
    'quicksand',
    'quickset',
    'quicksilver',
    'quickstep',
    'quicky',
    'quid',
    'quiddity',
    'quidnunc',
    'quiesce',
    'quiescence',
    'quiescency',
    'quiescent',
    'quiet',
    'quieted',
    'quieten',
    'quietism',
    'quietist',
    'quietly',
    'quietness',
    'quiets',
    'quietude',
    'quietus',
    'quiff',
    'quill',
    'quills',
    'quillwort',
    'quilt',
    'quilted',
    'quilting',
    'quilts',
    'quin',
    'quinacrine',
    'quince',
    'quincentenary',
    'quincentennial',
    'quincy',
    'quine',
    'quinidex',
    'quinidine',
    'quinine',
    'quinone',
    'quinones',
    'quinora',
    'quinquagesima',
    'quinquefoliate',
    'quinquennium',
    'quinsy',
    'quint',
    'quintal',
    'quintessence',
    'quintessential',
    'quintet',
    'quintette',
    'quintillion',
    'quintillionth',
    'quintipara',
    'quintuple',
    'quintuplet',
    'quintupling',
    'quip',
    'quipu',
    'quira',
    'quire',
    'quires',
    'quirk',
    'quirked',
    'quirkiness',
    'quirky',
    'quirt',
    'quiscalus',
    'quisling',
    'quislingism',
    'quit',
    'quitclaim',
    'quite',
    'quito',
    'quits',
    'quittance',
    'quitter',
    'quitting',
    'quiver',
    'quivered',
    'quivering',
    'quixotic',
    'quixotism',
    'quiz',
    'quizmaster',
    'quizzed',
    'quizzer',
    'quizzical',
    'qum',
    'quo',
    'quodlibet',
    'quoin',
    'quoit',
    'quoits',
    'quondam',
    'quoratean',
    'quorum',
    'quota',
    'quotability',
    'quotable',
    'quotas',
    'quotation',
    'quotations',
    'quote',
    'quoted',
    'quoter',
    'quotes',
    'quotidian',
    'quotient',
    'quoting',
    'quran',
    'qurush']
