
#!/usr/bin/env python
# -*- coding: UTF-8 -*-

# pylint:disable=bad-whitespace
# pylint:disable=line-too-long
# pylint:disable=too-many-lines
# pylint:disable=invalid-name

# #########################################################
#
#       ************** !! WARNING !! ***************
#       ******* THIS FILE WAS AUTO-GENERATED *******
#       ********* DO NOT MODIFY THIS FILE **********
#
# #########################################################

wordnet_terms_r_provenance = {
    'action': ['router.py',
               'plac_core.py',
               'csv2py_orchestrator.py',
               'wordnet2py.py',
               'csv_list_writer.py',
               'common_utils.py'],
    'source': 'resources/data/csv/wordnet.csv',
    'time': '2022-05-17 17:00:36.211957'}

wordnet_terms_r = [
    'ra',
    'rabat',
    'rabato',
    'rabbet',
    'rabbeted',
    'rabbets',
    'rabbi',
    'rabbinate',
    'rabbinic',
    'rabbinical',
    'rabbis',
    'rabbit',
    'rabbiteye',
    'rabbitfish',
    'rabbits',
    'rabbitweed',
    'rabbitwood',
    'rabble',
    'rabelais',
    'rabelaisian',
    'rabid',
    'rabidity',
    'rabidly',
    'rabidness',
    'rabies',
    'raccoon',
    'raccoons',
    'race',
    'raceabout',
    'racecard',
    'racecourse',
    'raced',
    'racehorse',
    'racehorses',
    'raceme',
    'racemes',
    'racemose',
    'racer',
    'racers',
    'racerunner',
    'races',
    'racetrack',
    'racetracks',
    'raceway',
    'rachel',
    'rachet',
    'rachis',
    'rachischisis',
    'rachitic',
    'rachitis',
    'rachmaninoff',
    'rachmaninov',
    'rachycentridae',
    'rachycentron',
    'racial',
    'racialism',
    'racialist',
    'racially',
    'racine',
    'raciness',
    'racing',
    'racism',
    'racist',
    'racists',
    'rack',
    'racked',
    'racker',
    'racket',
    'racketeer',
    'racketeering',
    'racketiness',
    'rackets',
    'rackety',
    'racking',
    'racon',
    'raconteur',
    'racoon',
    'racquet',
    'racquetball',
    'racy',
    'rad',
    'radar',
    'raddle',
    'raddled',
    'radhakrishnan',
    'radial',
    'radially',
    'radian',
    'radiance',
    'radiancy',
    'radians',
    'radiant',
    'radiate',
    'radiated',
    'radiates',
    'radiating',
    'radiation',
    'radiations',
    'radiator',
    'radiators',
    'radical',
    'radicalism',
    'radicalize',
    'radicalized',
    'radically',
    'radicals',
    'radicchio',
    'radicle',
    'radiculitis',
    'radii',
    'radiigera',
    'radio',
    'radioactive',
    'radioactively',
    'radioactivity',
    'radiobiologist',
    'radiobiology',
    'radiocarbon',
    'radiochemist',
    'radiochemistry',
    'radiochlorine',
    'radiocommunication',
    'radioed',
    'radiogram',
    'radiograph',
    'radiographer',
    'radiographic',
    'radiographs',
    'radiography',
    'radioimmunoassay',
    'radioisotope',
    'radioisotopes',
    'radiolaria',
    'radiolarian',
    'radiolarians',
    'radiolocate',
    'radiolocation',
    'radiological',
    'radiologist',
    'radiology',
    'radiolucent',
    'radiolysis',
    'radiometer',
    'radiomicrometer',
    'radiopacity',
    'radiopaque',
    'radiopharmaceutical',
    'radiophone',
    'radiophonic',
    'radiophoto',
    'radiophotograph',
    'radiophotography',
    'radioprotection',
    'radios',
    'radioscopy',
    'radiosensitive',
    'radiosensitivity',
    'radiotelegraph',
    'radiotelegraphy',
    'radiotelephone',
    'radiotelephonic',
    'radiotelephony',
    'radiotherapist',
    'radiotherapy',
    'radiothorium',
    'radish',
    'radishes',
    'radium',
    'radius',
    'radix',
    'radome',
    'radon',
    'radyera',
    'raetam',
    'raf',
    'raffia',
    'raffinose',
    'raffish',
    'raffle',
    'raffled',
    'raffles',
    'rafflesiaceae',
    'raft',
    'rafter',
    'raftered',
    'rafters',
    'rafting',
    'raftman',
    'rafts',
    'raftsman',
    'rag',
    'ragamuffin',
    'ragamuffins',
    'ragbag',
    'rage',
    'ragee',
    'ragged',
    'raggedness',
    'ragi',
    'raging',
    'raglan',
    'ragnarok',
    'ragout',
    'ragpicker',
    'rags',
    'ragsorter',
    'ragtag',
    'ragtime',
    'ragusa',
    'ragweed',
    'ragweeds',
    'ragwort',
    'rahu',
    'raid',
    'raided',
    'raider',
    'raiding',
    'raids',
    'rail',
    'railbird',
    'railcar',
    'railed',
    'railhead',
    'railing',
    'railings',
    'raillery',
    'railroad',
    'railroader',
    'railroading',
    'railroads',
    'rails',
    'railway',
    'railwayman',
    'railways',
    'railyard',
    'raiment',
    'raimentless',
    'rain',
    'rainbow',
    'raincoat',
    'raindrop',
    'rained',
    'rainfall',
    'rainfly',
    'rainforest',
    'rainier',
    'raininess',
    'raining',
    'rainless',
    'rainmaker',
    'rainmaking',
    'rainproof',
    'rains',
    'rainstorm',
    'rainwater',
    'rainy',
    'raisable',
    'raise',
    'raiseable',
    'raised',
    'raiser',
    'raises',
    'raisin',
    'raising',
    'raisins',
    'raita',
    'raiu',
    'raj',
    'raja',
    'rajab',
    'rajah',
    'rajanya',
    'rajidae',
    'rajiformes',
    'rajpoot',
    'rajput',
    'rajputs',
    'rakaposhi',
    'rake',
    'raked',
    'rakehell',
    'raking',
    'rakish',
    'rakishness',
    'rale',
    'ralegh',
    'raleigh',
    'rallentando',
    'rallidae',
    'rallied',
    'rally',
    'rallying',
    'ralph',
    'ram',
    'rama',
    'ramachandra',
    'ramadan',
    'ramalina',
    'ramanavami',
    'ramate',
    'ramayana',
    'ramble',
    'rambler',
    'rambles',
    'rambling',
    'rambotan',
    'rambouillet',
    'rambunctious',
    'rambutan',
    'rameau',
    'ramee',
    'ramekin',
    'ramequin',
    'rameses',
    'ramesses',
    'ramie',
    'ramification',
    'ramifies',
    'ramify',
    'ramifying',
    'ramipril',
    'ramjet',
    'ramman',
    'rammed',
    'rammer',
    'ramming',
    'ramona',
    'ramontchi',
    'ramose',
    'ramous',
    'ramp',
    'rampage',
    'rampageous',
    'rampant',
    'rampart',
    'ramparts',
    'ramped',
    'ramphastidae',
    'ramphomicron',
    'rampion',
    'ramrod',
    'ramses',
    'ramshackle',
    'ramsons',
    'ramus',
    'ran',
    'rana',
    'ranales',
    'ranatra',
    'ranch',
    'rancher',
    'ranches',
    'ranching',
    'rancid',
    'rancidity',
    'rancidness',
    'rancor',
    'rancorous',
    'rancour',
    'rancourous',
    'rand',
    'randolph',
    'random',
    'randomisation',
    'randomise',
    'randomised',
    'randomization',
    'randomize',
    'randomized',
    'randomly',
    'randomness',
    'randy',
    'ranee',
    'rang',
    'range',
    'ranged',
    'rangefinder',
    'rangeland',
    'rangelands',
    'ranger',
    'rangers',
    'ranges',
    'rangifer',
    'ranging',
    'rangoon',
    'rangpur',
    'rangy',
    'rani',
    'ranid',
    'ranidae',
    'ranitidine',
    'rank',
    'ranked',
    'ranker',
    'rankin',
    'rankine',
    'ranking',
    'rankings',
    'rankle',
    'rankled',
    'rankness',
    'ranks',
    'ransack',
    'ransacked',
    'ransacking',
    'ransom',
    'ransomed',
    'rant',
    'ranter',
    'ranting',
    'rants',
    'ranula',
    'ranunculaceae',
    'ranunculales',
    'ranunculus',
    'raoulia',
    'rap',
    'rapacious',
    'rapaciously',
    'rapaciousness',
    'rapacity',
    'rapateaceae',
    'rape',
    'raped',
    'raper',
    'rapeseed',
    'raphael',
    'raphanus',
    'raphe',
    'raphia',
    'raphicerus',
    'raphidae',
    'raphidiidae',
    'raphus',
    'rapid',
    'rapidity',
    'rapidly',
    'rapidness',
    'rapids',
    'rapier',
    'rapine',
    'rapist',
    'rappahannock',
    'rappee',
    'rappel',
    'rappeller',
    'rapper',
    'rapping',
    'rapport',
    'rapporteur',
    'rapprochement',
    'raps',
    'rapscallion',
    'rapt',
    'raptor',
    'raptores',
    'raptorial',
    'rapture',
    'rapturous',
    'raptus',
    'rare',
    'rarebit',
    'rarefaction',
    'rarefactions',
    'rarefied',
    'rarefy',
    'rarely',
    'rareness',
    'rarest',
    'rarified',
    'rarify',
    'rariora',
    'rarity',
    'ras',
    'rascal',
    'rascality',
    'rascally',
    'rase',
    'rash',
    'rasher',
    'rashes',
    'rashly',
    'rashness',
    'rasht',
    'rask',
    'raskolnikov',
    'rasmussen',
    'rasp',
    'raspberries',
    'raspberry',
    'rasping',
    'rasputin',
    'raspy',
    'rassling',
    'rasta',
    'rastafari',
    'rastafarian',
    'rastafarianism',
    'rastafarians',
    'rastas',
    'raster',
    'rasterize',
    'rat',
    'ratability',
    'ratable',
    'ratables',
    'ratafee',
    'ratafia',
    'ratan',
    'rataplan',
    'ratatouille',
    'ratbite',
    'ratch',
    'ratchet',
    'ratcheting',
    'rate',
    'rateability',
    'rateable',
    'rateables',
    'rated',
    'ratel',
    'ratels',
    'ratepayer',
    'rates',
    'rather',
    'rathole',
    'rathskeller',
    'ratibida',
    'ratification',
    'ratified',
    'ratifier',
    'ratify',
    'ratifying',
    'rating',
    'ratings',
    'ratio',
    'ratiocinate',
    'ratiocination',
    'ratiocinative',
    'ratiocinator',
    'ration',
    'rational',
    'rationale',
    'rationalisation',
    'rationalise',
    'rationalism',
    'rationalist',
    'rationalistic',
    'rationality',
    'rationalization',
    'rationalize',
    'rationalized',
    'rationalizing',
    'rationalness',
    'rationed',
    'rationing',
    'rations',
    'ratios',
    'ratitae',
    'ratite',
    'ratlike',
    'ratlin',
    'ratline',
    'rats',
    'ratsbane',
    'rattail',
    'rattan',
    'ratter',
    'ratters',
    'rattigan',
    'ratting',
    'rattle',
    'rattlebox',
    'rattlebrained',
    'rattled',
    'rattlepated',
    'rattler',
    'rattlesnake',
    'rattlesnakes',
    'rattling',
    'rattrap',
    'rattus',
    'ratty',
    'raucous',
    'raudixin',
    'raunch',
    'raunchy',
    'rauvolfia',
    'rauwolfia',
    'ravage',
    'ravaged',
    'ravages',
    'ravaging',
    'rave',
    'raved',
    'ravehook',
    'ravel',
    'raveling',
    'ravelled',
    'ravelling',
    'ravellings',
    'raven',
    'ravenala',
    'ravened',
    'ravening',
    'ravenna',
    'ravenous',
    'ravenously',
    'ravenousness',
    'ravens',
    'raver',
    'raves',
    'ravigote',
    'ravigotte',
    'ravine',
    'raving',
    'ravioli',
    'ravish',
    'ravisher',
    'ravishing',
    'ravishment',
    'raw',
    'rawalpindi',
    'rawboned',
    'rawhide',
    'rawness',
    'ray',
    'rayed',
    'rayleigh',
    'rayless',
    'raymond',
    'rayon',
    'rayons',
    'rays',
    'razbliuto',
    'raze',
    'razed',
    'razing',
    'razmataz',
    'razor',
    'razorback',
    'razorbill',
    'razorblade',
    'razors',
    'razz',
    'razzed',
    'razzing',
    'razzle',
    'razzmatazz',
    'rb',
    'rbc',
    'rbi',
    'rcmp',
    're',
    'reabsorb',
    'reabsorption',
    'reach',
    'reachable',
    'reached',
    'reaches',
    'reaching',
    'react',
    'reactance',
    'reactant',
    'reacted',
    'reacting',
    'reaction',
    'reactionaries',
    'reactionary',
    'reactionism',
    'reactionist',
    'reactions',
    'reactivate',
    'reactive',
    'reactivity',
    'reactor',
    'reactors',
    'reacts',
    'read',
    'readability',
    'readable',
    'readapt',
    'readapted',
    'reade',
    'reader',
    'readers',
    'readership',
    'readily',
    'readiness',
    'reading',
    'readings',
    'readjust',
    'readjusted',
    'readjustment',
    'readmission',
    'readmit',
    'readmitted',
    'readout',
    'reads',
    'ready',
    'readying',
    'reaffiliation',
    'reaffirm',
    'reaffirmation',
    'reaffirmed',
    'reaffirming',
    'reagan',
    'reagent',
    'reagents',
    'reagin',
    'real',
    'reales',
    'realgar',
    'realign',
    'realigned',
    'realine',
    'realisation',
    'realise',
    'realised',
    'realism',
    'realist',
    'realistic',
    'realistically',
    'realities',
    'reality',
    'realizable',
    'realization',
    'realize',
    'realized',
    'realizes',
    'realizing',
    'reallocate',
    'reallocation',
    'reallot',
    'realloted',
    'reallotment',
    'really',
    'realm',
    'realness',
    'realpolitik',
    'realtor',
    'realtors',
    'realty',
    'ream',
    'reamed',
    'reamer',
    'reams',
    'reanimate',
    'reanimated',
    'reanimates',
    'reap',
    'reaper',
    'reappear',
    'reappearance',
    'reappeared',
    'reappearing',
    'reapportion',
    'reapportioned',
    'reapportioning',
    'reapportionment',
    'reappraisal',
    'reappraise',
    'reappraised',
    'rear',
    'reared',
    'rearguard',
    'rearing',
    'rearm',
    'rearmament',
    'rearmed',
    'rearmost',
    'rearrange',
    'rearranged',
    'rearrangement',
    'rearranging',
    'rears',
    'rearward',
    'reason',
    'reasonable',
    'reasonableness',
    'reasonably',
    'reasoned',
    'reasoner',
    'reasoning',
    'reasonless',
    'reasons',
    'reassail',
    'reassailed',
    'reassemble',
    'reassembly',
    'reassert',
    'reassertion',
    'reassess',
    'reassessment',
    'reassign',
    'reassigned',
    'reassignment',
    'reassurance',
    'reassure',
    'reassured',
    'reassuring',
    'reata',
    'reattribute',
    'reaumur',
    'reave',
    'reawaken',
    'reb',
    'rebarbative',
    'rebate',
    'rebating',
    'rebato',
    'rebecca',
    'rebekah',
    'rebel',
    'rebelled',
    'rebelling',
    'rebellion',
    'rebellions',
    'rebellious',
    'rebelliousness',
    'rebels',
    'rebind',
    'rebirth',
    'reboot',
    'reborn',
    'rebound',
    'rebounding',
    'rebounds',
    'reboxetine',
    'rebozo',
    'rebroadcast',
    'rebuff',
    'rebuffed',
    'rebuild',
    'rebuilding',
    'rebuilt',
    'rebuke',
    'rebuked',
    'rebuker',
    'rebuking',
    'reburial',
    'reburied',
    'rebury',
    'reburying',
    'rebus',
    'rebut',
    'rebuttal',
    'rebutter',
    'recalcitrance',
    'recalcitrancy',
    'recalcitrant',
    'recalcitrate',
    'recalcitrated',
    'recalculate',
    'recalculation',
    'recall',
    'recalled',
    'recalling',
    'recalls',
    'recant',
    'recantation',
    'recap',
    'recapitulate',
    'recapitulation',
    'recapture',
    'recaptured',
    'recaptures',
    'recast',
    'recasting',
    'recce',
    'recco',
    'reccy',
    'recede',
    'receded',
    'receding',
    'receipt',
    'receipts',
    'receivable',
    'receivables',
    'receive',
    'received',
    'receiver',
    'receivers',
    'receivership',
    'receives',
    'receiving',
    'recency',
    'recent',
    'recently',
    'recentness',
    'receptacle',
    'reception',
    'receptionist',
    'receptions',
    'receptive',
    'receptiveness',
    'receptivity',
    'receptor',
    'receptors',
    'recess',
    'recessed',
    'recesses',
    'recession',
    'recessional',
    'recessionary',
    'recessive',
    'recharge',
    'rechargeable',
    'recharged',
    'rechauffe',
    'recherche',
    'recidivate',
    'recidivism',
    'recidivist',
    'recife',
    'recipe',
    'recipes',
    'recipient',
    'recipients',
    'reciprocal',
    'reciprocality',
    'reciprocally',
    'reciprocals',
    'reciprocate',
    'reciprocates',
    'reciprocating',
    'reciprocation',
    'reciprocative',
    'reciprocatory',
    'reciprocity',
    'recirculation',
    'recission',
    'recital',
    'recitalist',
    'recitals',
    'recitation',
    'recitations',
    'recitative',
    'recite',
    'recited',
    'reciter',
    'recites',
    'reciting',
    'reckless',
    'recklessly',
    'recklessness',
    'reckon',
    'reckoned',
    'reckoner',
    'reckoning',
    'reclaim',
    'reclaimable',
    'reclaimed',
    'reclamation',
    'reclassification',
    'reclassified',
    'reclassify',
    'recline',
    'reclined',
    'recliner',
    'reclining',
    'recluse',
    'reclusive',
    'reclusiveness',
    'recode',
    'recoding',
    'recognisable',
    'recognisance',
    'recognise',
    'recognised',
    'recognition',
    'recognizable',
    'recognizance',
    'recognize',
    'recognized',
    'recognizes',
    'recognizing',
    'recoil',
    'recoilless',
    'recoils',
    'recollect',
    'recollection',
    'recollective',
    'recombinant',
    'recombination',
    'recombine',
    'recombining',
    'recommence',
    'recommenced',
    'recommencement',
    'recommend',
    'recommendation',
    'recommendations',
    'recommended',
    'recommending',
    'recommends',
    'recommit',
    'recommitted',
    'recompense',
    'reconcilable',
    'reconcile',
    'reconciled',
    'reconciler',
    'reconciliation',
    'reconciling',
    'recondite',
    'reconditeness',
    'recondition',
    'reconditioned',
    'reconfirm',
    'reconnaissance',
    'reconnoiter',
    'reconnoitering',
    'reconnoitre',
    'reconnoitring',
    'reconquer',
    'reconquered',
    'reconsecrate',
    'reconsider',
    'reconsideration',
    'reconstitute',
    'reconstituting',
    'reconstruct',
    'reconstructed',
    'reconstruction',
    'reconstructions',
    'reconstructive',
    'reconstructs',
    'reconvene',
    'reconvenes',
    'reconvening',
    'reconvert',
    'reconverting',
    'reconvict',
    'recopy',
    'record',
    'recorded',
    'recorder',
    'recorders',
    'recording',
    'recordings',
    'records',
    'recount',
    'recounting',
    'recoup',
    'recourse',
    'recourses',
    'recover',
    'recoverable',
    'recovered',
    'recoverer',
    'recovering',
    'recovers',
    'recovery',
    'recreant',
    'recreate',
    'recreated',
    'recreation',
    'recreational',
    'recriminate',
    'recrimination',
    'recriminative',
    'recriminatory',
    'recrudesce',
    'recrudescence',
    'recrudescent',
    'recruit',
    'recruited',
    'recruiter',
    'recruitment',
    'recruits',
    'rectal',
    'rectangle',
    'rectangular',
    'rectangularity',
    'rectifiable',
    'rectification',
    'rectified',
    'rectifier',
    'rectifiers',
    'rectify',
    'rectifying',
    'rectilineal',
    'rectilinear',
    'rectitude',
    'recto',
    'rectocele',
    'rectoplasty',
    'rector',
    'rectorate',
    'rectorship',
    'rectory',
    'rectosigmoid',
    'rectum',
    'rectus',
    'recumb',
    'recumbent',
    'recuperate',
    'recuperation',
    'recuperative',
    'recur',
    'recurrence',
    'recurrences',
    'recurrent',
    'recurring',
    'recurs',
    'recursion',
    'recursive',
    'recurvate',
    'recurve',
    'recurved',
    'recurvirostra',
    'recurvirostridae',
    'recusal',
    'recusancy',
    'recusant',
    'recusation',
    'recuse',
    'recused',
    'recyclable',
    'recycle',
    'recycled',
    'recycling',
    'red',
    'redact',
    'redaction',
    'redactor',
    'redbelly',
    'redberry',
    'redbird',
    'redbone',
    'redbreast',
    'redbrick',
    'redbrush',
    'redbud',
    'redbug',
    'redcap',
    'redcoat',
    'redden',
    'reddened',
    'reddening',
    'reddens',
    'redding',
    'reddish',
    'reddle',
    'rede',
    'redecorate',
    'rededicate',
    'rededication',
    'redeem',
    'redeemable',
    'redeemed',
    'redeemer',
    'redeeming',
    'redeems',
    'redefine',
    'redefined',
    'redefinition',
    'redemption',
    'redemptional',
    'redemptive',
    'redemptory',
    'redeploy',
    'redeployment',
    'redeposit',
    'redeposited',
    'redeposition',
    'redesign',
    'redetermination',
    'redetermine',
    'redetermined',
    'redevelop',
    'redeveloping',
    'redevelopment',
    'redeye',
    'redfield',
    'redfish',
    'redford',
    'redhead',
    'redheaded',
    'redheader',
    'redhorse',
    'rediffusion',
    'redirect',
    'rediscover',
    'rediscovered',
    'rediscovery',
    'redispose',
    'redisposed',
    'redisposition',
    'redistribute',
    'redistributed',
    'redistribution',
    'redline',
    'redmaids',
    'redneck',
    'redness',
    'redo',
    'redolence',
    'redolent',
    'redonda',
    'redouble',
    'redoubled',
    'redoubt',
    'redoubtable',
    'redound',
    'redounded',
    'redounds',
    'redox',
    'redpoll',
    'redraft',
    'redress',
    'redressed',
    'redroot',
    'reds',
    'redshank',
    'redshift',
    'redskin',
    'redstart',
    'redtail',
    'reduce',
    'reduced',
    'reducer',
    'reduces',
    'reducible',
    'reducing',
    'reductant',
    'reductase',
    'reductio',
    'reduction',
    'reductionism',
    'reductionist',
    'reductive',
    'reductivism',
    'redundance',
    'redundancy',
    'redundant',
    'reduplicate',
    'reduplicated',
    'reduplicates',
    'reduplication',
    'reduviid',
    'reduviidae',
    'redwing',
    'redwood',
    'reecho',
    'reechoing',
    'reed',
    'reedbird',
    'reedlike',
    'reedmace',
    'reeds',
    'reedy',
    'reef',
    'reefer',
    'reefs',
    'reefy',
    'reek',
    'reeking',
    'reeks',
    'reel',
    'reelect',
    'reelection',
    'reeled',
    'reeler',
    'reeling',
    'reels',
    'reenact',
    'reenacted',
    'reenactment',
    'reenactor',
    'reenforce',
    'reenforcement',
    'reenlistment',
    'reentrant',
    'reentry',
    'reestablish',
    'reestablishing',
    'reevaluate',
    'reevaluation',
    'reeve',
    'reexamination',
    'reexamine',
    'reexamined',
    'ref',
    'refabrication',
    'reface',
    'refaced',
    'refashion',
    'refection',
    'refectory',
    'refer',
    'referable',
    'referee',
    'refereeing',
    'reference',
    'referenced',
    'references',
    'referencing',
    'referendum',
    'referent',
    'referential',
    'referents',
    'referral',
    'referred',
    'referring',
    'refers',
    'refill',
    'refilling',
    'refills',
    'refinance',
    'refine',
    'refined',
    'refinement',
    'refiner',
    'refinery',
    'refining',
    'refinish',
    'refinisher',
    'refit',
    'reflate',
    'reflated',
    'reflation',
    'reflect',
    'reflectance',
    'reflected',
    'reflecting',
    'reflection',
    'reflections',
    'reflective',
    'reflectiveness',
    'reflectivity',
    'reflectometer',
    'reflector',
    'reflectorise',
    'reflectorize',
    'reflectorized',
    'reflectors',
    'reflects',
    'reflex',
    'reflexed',
    'reflexes',
    'reflexion',
    'reflexive',
    'reflexiveness',
    'reflexivity',
    'reflexology',
    'refloat',
    'reflux',
    'refocus',
    'refocused',
    'refocusing',
    'reforest',
    'reforestation',
    'reforested',
    'reforge',
    'reform',
    'reformable',
    'reformation',
    'reformative',
    'reformatory',
    'reformed',
    'reformer',
    'reformers',
    'reforming',
    'reformism',
    'reformist',
    'reforms',
    'reformulate',
    'refract',
    'refracted',
    'refractile',
    'refracting',
    'refraction',
    'refractive',
    'refractiveness',
    'refractivity',
    'refractometer',
    'refractories',
    'refractoriness',
    'refractory',
    'refracture',
    'refrain',
    'refrained',
    'refraining',
    'refrains',
    'refresh',
    'refreshed',
    'refreshen',
    'refresher',
    'refreshes',
    'refreshful',
    'refreshing',
    'refreshingly',
    'refreshment',
    'refreshments',
    'refried',
    'refrigerant',
    'refrigerate',
    'refrigerated',
    'refrigerating',
    'refrigeration',
    'refrigerator',
    'refrigerators',
    'refuel',
    'refueled',
    'refueling',
    'refuge',
    'refugee',
    'refugees',
    'refulgence',
    'refulgency',
    'refulgent',
    'refund',
    'refunded',
    'refurbish',
    'refurbished',
    'refurbishment',
    'refurnish',
    'refurnished',
    'refusal',
    'refuse',
    'refused',
    'refuses',
    'refusing',
    'refutable',
    'refutal',
    'refutation',
    'refute',
    'refuted',
    'refuter',
    'refutes',
    'refuting',
    'regain',
    'regained',
    'regaining',
    'regal',
    'regale',
    'regalecidae',
    'regalia',
    'regard',
    'regarded',
    'regardful',
    'regarding',
    'regardless',
    'regards',
    'regatta',
    'regency',
    'regenerate',
    'regenerated',
    'regenerating',
    'regeneration',
    'regent',
    'regents',
    'reggae',
    'reggane',
    'regia',
    'regicide',
    'regift',
    'regifted',
    'regime',
    'regimen',
    'regiment',
    'regimental',
    'regimentals',
    'regimentation',
    'regimented',
    'regiments',
    'regina',
    'regiomontanus',
    'region',
    'regional',
    'regionalism',
    'regionally',
    'regions',
    'register',
    'registered',
    'registering',
    'registers',
    'registrant',
    'registrar',
    'registration',
    'registry',
    'regius',
    'reglaecus',
    'regnant',
    'regnellidium',
    'regorge',
    'regosol',
    'regress',
    'regression',
    'regressive',
    'regret',
    'regretful',
    'regrets',
    'regrettable',
    'regretted',
    'regroup',
    'regrow',
    'regular',
    'regularisation',
    'regularise',
    'regularity',
    'regularization',
    'regularize',
    'regularized',
    'regularly',
    'regulate',
    'regulated',
    'regulates',
    'regulating',
    'regulation',
    'regulations',
    'regulative',
    'regulator',
    'regulatory',
    'regulus',
    'regur',
    'regurgitate',
    'regurgitated',
    'regurgitates',
    'regurgitating',
    'regurgitation',
    'rehabilitate',
    'rehabilitated',
    'rehabilitating',
    'rehabilitation',
    'rehabilitative',
    'reharmonisation',
    'reharmonise',
    'reharmonization',
    'reharmonize',
    'rehash',
    'rehear',
    'rehearing',
    'rehearsal',
    'rehearsals',
    'rehearse',
    'rehearsed',
    'rehearses',
    'reheat',
    'reheating',
    'reheel',
    'rehnquist',
    'rehouse',
    'reich',
    'reichstein',
    'reid',
    'reification',
    'reify',
    'reign',
    'reigned',
    'reigning',
    'reignite',
    'reignited',
    'reigns',
    'reimburse',
    'reimbursed',
    'reimbursement',
    'reimbursing',
    'reimpose',
    'reimposition',
    'reims',
    'rein',
    'reincarnate',
    'reincarnated',
    'reincarnation',
    'reincarnationism',
    'reindeer',
    'reined',
    'reinforce',
    'reinforced',
    'reinforcement',
    'reinforcements',
    'reinforcer',
    'reinforces',
    'reinforcing',
    'reins',
    'reinstall',
    'reinstalled',
    'reinstate',
    'reinstated',
    'reinstatement',
    'reinsurance',
    'reinsure',
    'reintegrate',
    'reintegrated',
    'reinterpret',
    'reinterpretation',
    'reinterpretations',
    'reinterpreted',
    'reintroduce',
    'reintroduced',
    'reintroduction',
    'reinvent',
    'reinvented',
    'reinvigorate',
    'reinvigorated',
    'reissue',
    'reissued',
    'reit',
    'reiter',
    'reiterate',
    'reiterating',
    'reiteration',
    'reiterative',
    'reithrodontomys',
    'reject',
    'rejected',
    'rejecting',
    'rejection',
    'rejective',
    'rejects',
    'rejig',
    'rejoice',
    'rejoiced',
    'rejoicing',
    'rejoin',
    'rejoinder',
    'rejoining',
    'rejoins',
    'rejuvenate',
    'rejuvenated',
    'rejuvenation',
    'rekindle',
    'relace',
    'relaced',
    'relafen',
    'relapse',
    'relapsing',
    'relate',
    'related',
    'relatedness',
    'relates',
    'relating',
    'relation',
    'relational',
    'relations',
    'relationship',
    'relationships',
    'relative',
    'relatively',
    'relatives',
    'relativise',
    'relativism',
    'relativistic',
    'relativistically',
    'relativity',
    'relativize',
    'relatum',
    'relax',
    'relaxant',
    'relaxants',
    'relaxation',
    'relaxations',
    'relaxed',
    'relaxer',
    'relaxes',
    'relaxin',
    'relaxing',
    'relay',
    'relayed',
    'relays',
    'relearn',
    'release',
    'released',
    'releases',
    'releasing',
    'relegate',
    'relegated',
    'relegating',
    'relegation',
    'relent',
    'relentless',
    'relentlessly',
    'relentlessness',
    'relevance',
    'relevancy',
    'relevant',
    'reliability',
    'reliable',
    'reliableness',
    'reliably',
    'reliance',
    'reliant',
    'relic',
    'relics',
    'relict',
    'relied',
    'relief',
    'relies',
    'relieve',
    'relieved',
    'reliever',
    'relieves',
    'relieving',
    'relievo',
    'religion',
    'religionism',
    'religionist',
    'religions',
    'religiosity',
    'religious',
    'religiousism',
    'religiously',
    'religiousness',
    'reline',
    'relinquish',
    'relinquished',
    'relinquishes',
    'relinquishing',
    'relinquishment',
    'reliquary',
    'relish',
    'relished',
    'relishes',
    'relishing',
    'relistening',
    'relive',
    'relived',
    'relives',
    'reliving',
    'reload',
    'reloaded',
    'reloading',
    'reloads',
    'relocate',
    'relocated',
    'relocation',
    'reluctance',
    'reluctant',
    'reluctantly',
    'reluctivity',
    'rely',
    'relying',
    'relyric',
    'rem',
    'remain',
    'remainder',
    'remaindered',
    'remained',
    'remaining',
    'remains',
    'remake',
    'remaking',
    'remand',
    'remark',
    'remarkable',
    'remarkably',
    'remarks',
    'remarriage',
    'remarried',
    'remarry',
    'rematch',
    'rembrandt',
    'rembrandtesque',
    'remediable',
    'remedial',
    'remediate',
    'remediation',
    'remedied',
    'remedies',
    'remedy',
    'remedying',
    'remelted',
    'remember',
    'remembered',
    'remembering',
    'remembers',
    'remembrance',
    'remicade',
    'remilegia',
    'remilitarisation',
    'remilitarise',
    'remilitarization',
    'remilitarize',
    'remind',
    'reminded',
    'reminder',
    'remindful',
    'reminds',
    'reminisce',
    'reminiscence',
    'reminiscent',
    'reminiscing',
    'remise',
    'remiss',
    'remission',
    'remissness',
    'remit',
    'remitment',
    'remittal',
    'remittance',
    'remittent',
    'remitting',
    'remnant',
    'remnants',
    'remodel',
    'remodeled',
    'remodeling',
    'remold',
    'remolded',
    'remonstrance',
    'remonstrate',
    'remonstration',
    'remora',
    'remoras',
    'remorse',
    'remorseful',
    'remorseless',
    'remote',
    'remoteness',
    'remotion',
    'remould',
    'remount',
    'remounted',
    'removable',
    'removal',
    'remove',
    'removed',
    'remover',
    'removes',
    'removing',
    'remuda',
    'remunerate',
    'remunerated',
    'remuneration',
    'remunerative',
    'remunerator',
    'remus',
    'renaissance',
    'renal',
    'rename',
    'renamed',
    'renaming',
    'renascence',
    'renascent',
    'rend',
    'render',
    'rendered',
    'rendering',
    'renderings',
    'renders',
    'rendezvous',
    'rending',
    'rendition',
    'renditions',
    'rene',
    'renegade',
    'renege',
    'renegociate',
    'renegociated',
    'renegotiate',
    'renew',
    'renewable',
    'renewal',
    'renewed',
    'renewing',
    'renews',
    'reniform',
    'renin',
    'rennet',
    'rennin',
    'reno',
    'renoir',
    'renormalise',
    'renormalize',
    'renounce',
    'renounced',
    'renouncement',
    'renounces',
    'renouncing',
    'renovate',
    'renovated',
    'renovating',
    'renovation',
    'renovator',
    'renown',
    'renowned',
    'rensselaerite',
    'rent',
    'rentable',
    'rental',
    'rente',
    'rented',
    'renter',
    'rentier',
    'renting',
    'rents',
    'renunciant',
    'renunciation',
    'renunciative',
    'reopen',
    'reopened',
    'reopening',
    'reorder',
    'reordering',
    'reorganisation',
    'reorganise',
    'reorganised',
    'reorganization',
    'reorganize',
    'reorganized',
    'reorganizing',
    'reorient',
    'reorientate',
    'reorientation',
    'reoviridae',
    'reovirus',
    'rep',
    'repaid',
    'repaint',
    'repainted',
    'repair',
    'repaired',
    'repairer',
    'repairing',
    'repairman',
    'repairs',
    'repand',
    'reparable',
    'reparation',
    'reparations',
    'repartee',
    'repast',
    'repatriate',
    'repatriation',
    'repaving',
    'repay',
    'repayable',
    'repaying',
    'repayment',
    'repeal',
    'repealed',
    'repeat',
    'repeatable',
    'repeated',
    'repeatedly',
    'repeater',
    'repeaters',
    'repeating',
    'repeats',
    'repechage',
    'repel',
    'repellant',
    'repelled',
    'repellent',
    'repellently',
    'repellents',
    'repelling',
    'repels',
    'repent',
    'repentance',
    'repentant',
    'repents',
    'repercuss',
    'repercussion',
    'repercussions',
    'repertoire',
    'repertory',
    'repetition',
    'repetitions',
    'repetitious',
    'repetitiousness',
    'repetitive',
    'repetitively',
    'repetitiveness',
    'rephrase',
    'rephrasing',
    'repine',
    'replace',
    'replaceability',
    'replaceable',
    'replaced',
    'replacement',
    'replaces',
    'replacing',
    'replant',
    'replanted',
    'replay',
    'replayed',
    'replenish',
    'replenished',
    'replenishment',
    'replete',
    'repletion',
    'replica',
    'replicate',
    'replicated',
    'replicates',
    'replication',
    'replied',
    'replies',
    'reply',
    'replying',
    'repoint',
    'report',
    'reportable',
    'reportage',
    'reported',
    'reportedly',
    'reporter',
    'reporters',
    'reporting',
    'reports',
    'repose',
    'reposed',
    'reposeful',
    'reposes',
    'reposing',
    'reposit',
    'reposited',
    'repositing',
    'reposition',
    'repositioning',
    'repository',
    'repossess',
    'repossession',
    'repot',
    'repp',
    'reprehend',
    'reprehensibility',
    'reprehensible',
    'reprehension',
    'represent',
    'representable',
    'representation',
    'representational',
    'representations',
    'representative',
    'representatives',
    'represented',
    'representing',
    'represents',
    'repress',
    'repressed',
    'represser',
    'represses',
    'repressing',
    'repression',
    'repressive',
    'repressor',
    'reprieve',
    'reprimand',
    'reprint',
    'reprinted',
    'reprinting',
    'reprisal',
    'reprise',
    'reprize',
    'reproach',
    'reproached',
    'reproacher',
    'reproaches',
    'reproachful',
    'reprobate',
    'reprobated',
    'reprobation',
    'reprocess',
    'reprocessing',
    'reproduce',
    'reproduced',
    'reproducer',
    'reproduces',
    'reproducibility',
    'reproducible',
    'reproducing',
    'reproduction',
    'reproductions',
    'reproductive',
    'reproof',
    'reproval',
    'reprove',
    'reprover',
    'reproving',
    'reptantia',
    'reptile',
    'reptiles',
    'reptilia',
    'reptilian',
    'republic',
    'republican',
    'republicanism',
    'republicans',
    'republication',
    'republics',
    'republish',
    'republished',
    'republishing',
    'repudiate',
    'repudiated',
    'repudiation',
    'repudiative',
    'repugn',
    'repugnance',
    'repugnant',
    'repulse',
    'repulsed',
    'repulsing',
    'repulsion',
    'repulsive',
    'repulsiveness',
    'repurchase',
    'repurchases',
    'reputability',
    'reputable',
    'reputation',
    'repute',
    'reputed',
    'reputedly',
    'request',
    'requested',
    'requester',
    'requesting',
    'requests',
    'requiem',
    'requiescat',
    'require',
    'required',
    'requirement',
    'requirements',
    'requires',
    'requiring',
    'requisite',
    'requisiteness',
    'requisites',
    'requisition',
    'requital',
    'requite',
    'reread',
    'rerebrace',
    'reredos',
    'rerun',
    'res',
    'resale',
    'rescale',
    'reschedule',
    'rescind',
    'rescindable',
    'rescinded',
    'rescission',
    'rescript',
    'rescriptor',
    'rescue',
    'rescued',
    'rescuer',
    'rescuers',
    'rescues',
    'rescuing',
    'reseal',
    'research',
    'researched',
    'researcher',
    'reseat',
    'reseating',
    'reseau',
    'resect',
    'resection',
    'reseda',
    'resedaceae',
    'reseed',
    'resell',
    'resells',
    'resemblance',
    'resemble',
    'resembled',
    'resembles',
    'resembling',
    'resent',
    'resented',
    'resentful',
    'resentment',
    'resents',
    'reserpine',
    'reservation',
    'reservations',
    'reserve',
    'reserved',
    'reserves',
    'reserving',
    'reservist',
    'reservoir',
    'reservoirs',
    'reset',
    'resetting',
    'resettle',
    'resettled',
    'resettlement',
    'resew',
    'resh',
    'reshape',
    'reshaped',
    'reshapes',
    'reship',
    'reshipment',
    'reshoot',
    'resht',
    'reshuffle',
    'reshuffled',
    'reshuffling',
    'resid',
    'reside',
    'resided',
    'residence',
    'residences',
    'residency',
    'resident',
    'residential',
    'residents',
    'resides',
    'residing',
    'residual',
    'residuary',
    'residue',
    'residues',
    'residuum',
    'resift',
    'resign',
    'resignation',
    'resigned',
    'resile',
    'resilience',
    'resiliency',
    'resilient',
    'resin',
    'resinate',
    'resinated',
    'resinlike',
    'resinoid',
    'resinous',
    'resins',
    'resiny',
    'resist',
    'resistance',
    'resistances',
    'resistant',
    'resisted',
    'resister',
    'resistible',
    'resisting',
    'resistive',
    'resistivity',
    'resistless',
    'resistor',
    'resistors',
    'resists',
    'resize',
    'resmudge',
    'resole',
    'resolute',
    'resolutely',
    'resoluteness',
    'resolution',
    'resolvable',
    'resolve',
    'resolved',
    'resolvent',
    'resolves',
    'resolving',
    'resonance',
    'resonances',
    'resonant',
    'resonate',
    'resonates',
    'resonating',
    'resonator',
    'resonators',
    'resorb',
    'resorbed',
    'resorcinol',
    'resorcinolphthalein',
    'resorption',
    'resort',
    'resorted',
    'resorting',
    'resorts',
    'resound',
    'resounded',
    'resounding',
    'resoundingly',
    'resource',
    'resourceful',
    'resourcefully',
    'resourcefulness',
    'resourceless',
    'resources',
    'respect',
    'respectability',
    'respectable',
    'respected',
    'respecter',
    'respectful',
    'respectfulness',
    'respective',
    'respectively',
    'respects',
    'respighi',
    'respiration',
    'respirations',
    'respirator',
    'respiratory',
    'respire',
    'respite',
    'resplend',
    'resplended',
    'resplendence',
    'resplendency',
    'resplendent',
    'respond',
    'responded',
    'respondent',
    'responder',
    'responding',
    'responds',
    'response',
    'responses',
    'responsibilities',
    'responsibility',
    'responsible',
    'responsibleness',
    'responsibly',
    'responsive',
    'responsiveness',
    'rest',
    'restart',
    'restate',
    'restatement',
    'restaurant',
    'restauranter',
    'restaurants',
    'restaurateur',
    'rested',
    'rester',
    'restful',
    'restfulness',
    'restharrow',
    'resting',
    'restitute',
    'restitution',
    'restive',
    'restiveness',
    'restless',
    'restlessness',
    'restock',
    'restocked',
    'restoration',
    'restorative',
    'restore',
    'restored',
    'restorer',
    'restores',
    'restoril',
    'restoring',
    'restrain',
    'restrained',
    'restrainer',
    'restraining',
    'restrains',
    'restraint',
    'restraints',
    'restrengthen',
    'restrict',
    'restricted',
    'restricting',
    'restriction',
    'restrictions',
    'restrictive',
    'restrictiveness',
    'restricts',
    'restroom',
    'restrooms',
    'restructure',
    'rests',
    'resublime',
    'resubmit',
    'result',
    'resultant',
    'resulted',
    'resulting',
    'results',
    'resume',
    'resumed',
    'resumes',
    'resuming',
    'resumption',
    'resupine',
    'resurface',
    'resurfaced',
    'resurge',
    'resurged',
    'resurgence',
    'resurgent',
    'resurrect',
    'resurrected',
    'resurrection',
    'resurvey',
    'resuscitate',
    'resuscitated',
    'resuscitation',
    'resuscitator',
    'resuspend',
    'resuspension',
    'ret',
    'retail',
    'retailer',
    'retailers',
    'retailing',
    'retain',
    'retained',
    'retainer',
    'retaining',
    'retains',
    'retake',
    'retaking',
    'retaliate',
    'retaliated',
    'retaliation',
    'retaliative',
    'retaliator',
    'retaliatory',
    'retama',
    'retard',
    'retardant',
    'retardation',
    'retarded',
    'retardent',
    'retarding',
    'retards',
    'retch',
    'rete',
    'retell',
    'retem',
    'retention',
    'retentive',
    'retentiveness',
    'retentivity',
    'rethink',
    'rethought',
    'reticence',
    'reticent',
    'retick',
    'reticle',
    'reticular',
    'reticulate',
    'reticulated',
    'reticulation',
    'reticule',
    'reticulitermes',
    'reticulocyte',
    'reticulum',
    'retie',
    'retina',
    'retinal',
    'retinene',
    'retinitis',
    'retinoblastoma',
    'retinol',
    'retinopathy',
    'retinue',
    'retire',
    'retired',
    'retiree',
    'retirees',
    'retirement',
    'retiring',
    'retold',
    'retool',
    'retort',
    'retorts',
    'retouch',
    'retouches',
    'retrace',
    'retraced',
    'retract',
    'retractable',
    'retracted',
    'retractile',
    'retraction',
    'retractor',
    'retracts',
    'retrain',
    'retraining',
    'retral',
    'retranslate',
    'retransmission',
    'retransmit',
    'retread',
    'retreat',
    'retreatant',
    'retreated',
    'retreating',
    'retreats',
    'retrench',
    'retrenchment',
    'retrial',
    'retribution',
    'retributive',
    'retributory',
    'retrievable',
    'retrieval',
    'retrieve',
    'retrieved',
    'retriever',
    'retrieves',
    'retrieving',
    'retro',
    'retroactive',
    'retrofit',
    'retrofitted',
    'retroflection',
    'retroflex',
    'retroflexed',
    'retroflexion',
    'retrograde',
    'retrogress',
    'retrogresses',
    'retrogression',
    'retrogressive',
    'retromandibular',
    'retronym',
    'retrophyllum',
    'retrorocket',
    'retrorse',
    'retrospect',
    'retrospection',
    'retrospective',
    'retrousse',
    'retroversion',
    'retrovert',
    'retrovir',
    'retrovirus',
    'retroviruses',
    'retrovision',
    'retry',
    'retsina',
    'return',
    'returnable',
    'returned',
    'returning',
    'returns',
    'reuben',
    'reunification',
    'reunified',
    'reunify',
    'reunion',
    'reunite',
    'reunited',
    'reuptake',
    'reusable',
    'reuse',
    'reusing',
    'rev',
    'revaluation',
    'revalue',
    'revamp',
    'revamped',
    'reveal',
    'revealed',
    'revealing',
    'reveals',
    'reveille',
    'revel',
    'revelation',
    'revelations',
    'revelatory',
    'reveler',
    'revelers',
    'reveller',
    'revelry',
    'revels',
    'revenant',
    'revenge',
    'revengeful',
    'revenue',
    'revenuer',
    'revenues',
    'reverberance',
    'reverberant',
    'reverberate',
    'reverberated',
    'reverberating',
    'reverberation',
    'reverberative',
    'reverberatory',
    'revere',
    'revered',
    'reverence',
    'reverend',
    'reverent',
    'reverential',
    'reverie',
    'revering',
    'revers',
    'reversal',
    'reverse',
    'reversed',
    'reverses',
    'reversibility',
    'reversible',
    'reversibly',
    'reversing',
    'reversion',
    'reversionary',
    'reversioner',
    'reversionist',
    'reversive',
    'revert',
    'reverted',
    'revertible',
    'reverting',
    'reverts',
    'revery',
    'revet',
    'revetement',
    'revetment',
    'review',
    'reviewed',
    'reviewer',
    'reviewers',
    'reviews',
    'revile',
    'revilement',
    'revisal',
    'revise',
    'revised',
    'reviser',
    'revises',
    'revising',
    'revision',
    'revisionism',
    'revisionist',
    'revisions',
    'revisit',
    'revisited',
    'revitalisation',
    'revitalise',
    'revitalised',
    'revitalising',
    'revitalization',
    'revitalize',
    'revitalized',
    'revitalizing',
    'revival',
    'revivalism',
    'revivalist',
    'revivalistic',
    'revive',
    'revived',
    'revivification',
    'revivify',
    'reviving',
    'revocable',
    'revocation',
    'revokable',
    'revoke',
    'revoked',
    'revoking',
    'revolt',
    'revolted',
    'revolting',
    'revoltingly',
    'revolution',
    'revolutionaries',
    'revolutionary',
    'revolutionise',
    'revolutionism',
    'revolutionist',
    'revolutionize',
    'revolutionized',
    'revolutions',
    'revolve',
    'revolved',
    'revolver',
    'revolves',
    'revolving',
    'revue',
    'revues',
    'revulsion',
    'reward',
    'rewarded',
    'rewardful',
    'rewarding',
    'rewards',
    'rewind',
    'rewinding',
    'rewire',
    'rewired',
    'reword',
    'rewording',
    'rework',
    'reworked',
    'rewrite',
    'rewriter',
    'rewrites',
    'rewriting',
    'rewrote',
    'rex',
    'reyes',
    'reykjavik',
    'reynard',
    'reynolds',
    'rf',
    'rfd',
    'rg',
    'rh',
    'rhabdomancer',
    'rhabdomancy',
    'rhabdomyoma',
    'rhabdomyosarcoma',
    'rhabdosarcoma',
    'rhabdoviridae',
    'rhabdovirus',
    'rhadamanthus',
    'rhagades',
    'rhagoletis',
    'rhamnaceae',
    'rhamnales',
    'rhamnus',
    'rhaphe',
    'rhapis',
    'rhapsodic',
    'rhapsodise',
    'rhapsodize',
    'rhapsody',
    'rhd',
    'rhea',
    'rheas',
    'rheidae',
    'rheiformes',
    'rheims',
    'rhein',
    'rheinland',
    'rhenish',
    'rhenium',
    'rheologic',
    'rheological',
    'rheology',
    'rheometer',
    'rheostat',
    'rhesus',
    'rhetoric',
    'rhetorical',
    'rhetorician',
    'rheum',
    'rheumatic',
    'rheumatism',
    'rheumatoid',
    'rheumatologist',
    'rheumatology',
    'rheumy',
    'rhexia',
    'rhibhus',
    'rhinal',
    'rhincodon',
    'rhincodontidae',
    'rhine',
    'rhineland',
    'rhinencephalon',
    'rhinestone',
    'rhinestones',
    'rhinion',
    'rhinitis',
    'rhino',
    'rhinobatidae',
    'rhinoceros',
    'rhinoceroses',
    'rhinocerotidae',
    'rhinolaryngologist',
    'rhinolaryngology',
    'rhinolophidae',
    'rhinonicteris',
    'rhinopathy',
    'rhinophyma',
    'rhinoplasty',
    'rhinoptera',
    'rhinorrhea',
    'rhinoscope',
    'rhinoscopy',
    'rhinosporidiosis',
    'rhinostenosis',
    'rhinotermitidae',
    'rhinotomy',
    'rhinotracheitis',
    'rhinovirus',
    'rhipsalis',
    'rhiptoglossa',
    'rhizobiaceae',
    'rhizobium',
    'rhizoctinia',
    'rhizoid',
    'rhizoidal',
    'rhizoids',
    'rhizomatous',
    'rhizome',
    'rhizomes',
    'rhizomorph',
    'rhizomorphs',
    'rhizophora',
    'rhizophoraceae',
    'rhizopod',
    'rhizopoda',
    'rhizopodan',
    'rhizopods',
    'rhizopogon',
    'rhizopogonaceae',
    'rhizopus',
    'rhizotomy',
    'rho',
    'rhodanthe',
    'rhode',
    'rhodes',
    'rhodesia',
    'rhodesian',
    'rhodium',
    'rhodochrosite',
    'rhododendron',
    'rhodolite',
    'rhodomontade',
    'rhodonite',
    'rhodophyceae',
    'rhodophyta',
    'rhodopsin',
    'rhodosphaera',
    'rhodymenia',
    'rhodymeniaceae',
    'rhoeadales',
    'rhomb',
    'rhombencephalon',
    'rhombic',
    'rhombohedral',
    'rhombohedron',
    'rhomboid',
    'rhomboidal',
    'rhombus',
    'rhombuses',
    'rhonchus',
    'rhone',
    'rhubarb',
    'rhumb',
    'rhumba',
    'rhus',
    'rhyacotriton',
    'rhyme',
    'rhymed',
    'rhymeless',
    'rhymer',
    'rhymes',
    'rhymester',
    'rhymic',
    'rhyming',
    'rhynchocephalia',
    'rhynchoelaps',
    'rhyncostylis',
    'rhynia',
    'rhyniaceae',
    'rhyolite',
    'rhythm',
    'rhythmic',
    'rhythmical',
    'rhythmically',
    'rhythmicity',
    'rhythms',
    'rhytidectomy',
    'rhytidoplasty',
    'ri',
    'rial',
    'riant',
    'riata',
    'rib',
    'ribald',
    'ribaldry',
    'riband',
    'ribavirin',
    'ribband',
    'ribbed',
    'ribbing',
    'ribbon',
    'ribbonfish',
    'ribbonfishes',
    'ribbonlike',
    'ribbons',
    'ribbonwood',
    'ribbony',
    'ribes',
    'ribgrass',
    'ribhus',
    'ribier',
    'ribless',
    'riblike',
    'riboflavin',
    'ribonuclease',
    'ribonucleic',
    'ribonucleinase',
    'ribose',
    'ribosome',
    'ribs',
    'ribwort',
    'rica',
    'rican',
    'ricardo',
    'rice',
    'ricebird',
    'ricegrass',
    'ricer',
    'rich',
    'richard',
    'richards',
    'richardson',
    'richea',
    'richelieu',
    'richer',
    'riches',
    'richler',
    'richly',
    'richmond',
    'richmondena',
    'richness',
    'richter',
    'richweed',
    'ricin',
    'ricing',
    'ricinus',
    'rick',
    'rickenbacker',
    'ricketiness',
    'rickets',
    'rickettsia',
    'rickettsiaceae',
    'rickettsial',
    'rickettsiales',
    'rickettsialpox',
    'rickettsias',
    'rickettsiosis',
    'rickety',
    'rickey',
    'rickover',
    'rickrack',
    'ricks',
    'ricksha',
    'rickshaw',
    'rickshaws',
    'rico',
    'ricochet',
    'ricotta',
    'ricrac',
    'rictus',
    'rid',
    'riddance',
    'ridden',
    'ridding',
    'riddle',
    'riddled',
    'riddles',
    'riddling',
    'ride',
    'rider',
    'riders',
    'rides',
    'ridge',
    'ridged',
    'ridgel',
    'ridgeline',
    'ridgeling',
    'ridgepole',
    'ridges',
    'ridgil',
    'ridgling',
    'ridicule',
    'ridiculed',
    'ridiculer',
    'ridiculous',
    'ridiculousness',
    'riding',
    'ridley',
    'ridleys',
    'riel',
    'riemann',
    'riemannian',
    'riesling',
    'riesman',
    'rifadin',
    'rifampin',
    'rife',
    'riff',
    'riffian',
    'riffle',
    'riffling',
    'riffraff',
    'riffs',
    'rifle',
    'riflebird',
    'rifled',
    'rifleman',
    'rifles',
    'rifling',
    'rift',
    'rig',
    'riga',
    'rigamarole',
    'rigatoni',
    'rigel',
    'rigged',
    'rigger',
    'rigging',
    'right',
    'righted',
    'righteous',
    'righteousness',
    'righteye',
    'rightfield',
    'rightful',
    'rightfulness',
    'righthand',
    'righthander',
    'rightish',
    'rightism',
    'rightist',
    'rightly',
    'rightmost',
    'rightness',
    'rights',
    'rigid',
    'rigidification',
    'rigidify',
    'rigidifying',
    'rigidity',
    'rigidly',
    'rigidness',
    'rigil',
    'rigmarole',
    'rigor',
    'rigorous',
    'rigorously',
    'rigorousness',
    'rigors',
    'rigour',
    'rigourousness',
    'rigout',
    'rigs',
    'rijstafel',
    'rijstaffel',
    'rijsttaffel',
    'riksmaal',
    'riksmal',
    'rile',
    'riled',
    'riley',
    'rilievo',
    'rilke',
    'rill',
    'rim',
    'rima',
    'rimactane',
    'rimbaud',
    'rime',
    'rimed',
    'rimeless',
    'riming',
    'rimless',
    'rimmed',
    'rimose',
    'rims',
    'rimu',
    'rimy',
    'rind',
    'rinderpest',
    'rinds',
    'ring',
    'ringdove',
    'ringed',
    'ringer',
    'ringgit',
    'ringhals',
    'ringing',
    'ringleader',
    'ringlet',
    'ringleted',
    'ringlets',
    'ringlike',
    'ringling',
    'ringmaster',
    'ringneck',
    'rings',
    'ringside',
    'ringtail',
    'ringway',
    'ringworm',
    'rink',
    'rinkhals',
    'rinse',
    'rinsing',
    'rio',
    'rioja',
    'riot',
    'rioter',
    'rioters',
    'rioting',
    'riotous',
    'riotously',
    'riots',
    'rip',
    'riparia',
    'riparian',
    'ripcord',
    'ripe',
    'ripen',
    'ripened',
    'ripeness',
    'ripening',
    'ripens',
    'riposte',
    'ripped',
    'ripper',
    'ripping',
    'ripple',
    'rippled',
    'ripples',
    'rippling',
    'ripsaw',
    'riptide',
    'rira',
    'risc',
    'rise',
    'risen',
    'riser',
    'rises',
    'risibility',
    'risible',
    'rising',
    'risk',
    'risked',
    'riskiness',
    'riskless',
    'risklessness',
    'risks',
    'risky',
    'risotto',
    'risque',
    'rissa',
    'rissole',
    'ritalin',
    'ritardando',
    'rite',
    'ritenuto',
    'rites',
    'ritonavir',
    'rittenhouse',
    'ritual',
    'ritualise',
    'ritualism',
    'ritualist',
    'ritualistic',
    'ritualize',
    'ritualized',
    'ritually',
    'rituals',
    'ritz',
    'ritzy',
    'rival',
    'rivaling',
    'rivalrous',
    'rivalry',
    'rivals',
    'rive',
    'river',
    'rivera',
    'riverbank',
    'riverbanks',
    'riverbed',
    'rivers',
    'riverside',
    'riversides',
    'rivet',
    'riveted',
    'riveter',
    'riveting',
    'rivets',
    'rivetter',
    'riviera',
    'rivina',
    'rivulet',
    'rivulets',
    'rivulus',
    'riyadh',
    'riyal',
    'rn',
    'rna',
    'rnase',
    'ro',
    'roach',
    'roaches',
    'road',
    'roadbed',
    'roadblock',
    'roadbook',
    'roadhog',
    'roadhouse',
    'roadkill',
    'roadless',
    'roadman',
    'roadrunner',
    'roadrunners',
    'roads',
    'roadside',
    'roadsides',
    'roadstead',
    'roadster',
    'roadway',
    'roadways',
    'roadworthiness',
    'roadworthy',
    'roald',
    'roam',
    'roamed',
    'roamer',
    'roaming',
    'roams',
    'roan',
    'roanoke',
    'roar',
    'roared',
    'roarer',
    'roaring',
    'roast',
    'roasted',
    'roaster',
    'roasters',
    'roasting',
    'roasts',
    'rob',
    'robalo',
    'robalos',
    'robaxin',
    'robbed',
    'robber',
    'robbers',
    'robbery',
    'robbing',
    'robbins',
    'robe',
    'robed',
    'robert',
    'roberts',
    'robertson',
    'robes',
    'robeson',
    'robespierre',
    'robin',
    'robinia',
    'robins',
    'robinson',
    'robitussin',
    'roble',
    'robot',
    'robotic',
    'robotics',
    'robotlike',
    'robots',
    'robs',
    'robust',
    'robustious',
    'robustness',
    'robustus',
    'roc',
    'rocambole',
    'roccella',
    'roccellaceae',
    'roccus',
    'rocephin',
    'rochambeau',
    'rochelle',
    'rochester',
    'rock',
    'rockabilly',
    'rockbound',
    'rockchuck',
    'rockcress',
    'rocked',
    'rockefeller',
    'rocker',
    'rockers',
    'rockery',
    'rocket',
    'rocketed',
    'rocketry',
    'rockets',
    'rockfish',
    'rockfishes',
    'rockfoil',
    'rockford',
    'rockies',
    'rockiness',
    'rocking',
    'rockingham',
    'rocklike',
    'rockrose',
    'rockroses',
    'rocks',
    'rockslide',
    'rockweed',
    'rockweeds',
    'rockwell',
    'rocky',
    'rococo',
    'rocroi',
    'rod',
    'rode',
    'rodent',
    'rodentia',
    'rodents',
    'rodeo',
    'rodgers',
    'rodhos',
    'rodin',
    'rodlike',
    'rodolia',
    'rodomontade',
    'rods',
    'roe',
    'roebling',
    'roebuck',
    'roentgen',
    'roentgenium',
    'roentgenogram',
    'roentgenographic',
    'roentgenography',
    'roentgenoscope',
    'rofecoxib',
    'rogaine',
    'rogation',
    'roger',
    'rogers',
    'roget',
    'rogue',
    'roguery',
    'rogues',
    'roguish',
    'roguishness',
    'rohypnol',
    'roi',
    'roil',
    'roiled',
    'roiling',
    'roily',
    'roister',
    'roisterer',
    'rolaids',
    'role',
    'roleplay',
    'roleplaying',
    'roles',
    'rolf',
    'roll',
    'rollback',
    'rolled',
    'roller',
    'rollerblade',
    'rollerblader',
    'rollerblades',
    'rollerblading',
    'rollers',
    'rollick',
    'rollicking',
    'rolling',
    'rollmops',
    'rollo',
    'rollover',
    'rolls',
    'rolodex',
    'rolypoliness',
    'rom',
    'roma',
    'romaic',
    'romaine',
    'roman',
    'romanal',
    'romance',
    'romanced',
    'romances',
    'romancing',
    'romanesque',
    'romani',
    'romania',
    'romanian',
    'romanic',
    'romanise',
    'romanism',
    'romanist',
    'romanize',
    'romanized',
    'romanoff',
    'romanov',
    'romans',
    'romansh',
    'romantic',
    'romantically',
    'romanticisation',
    'romanticise',
    'romanticism',
    'romanticist',
    'romanticistic',
    'romanticization',
    'romanticize',
    'romanticized',
    'romantics',
    'romany',
    'romberg',
    'rome',
    'romeo',
    'romish',
    'rommany',
    'rommel',
    'romneya',
    'romp',
    'romped',
    'romper',
    'romps',
    'romulus',
    'ron',
    'rondeau',
    'rondel',
    'rondelet',
    'rondo',
    'roneo',
    'roneograph',
    'rontgen',
    'rood',
    'roof',
    'roofed',
    'roofer',
    'roofing',
    'roofless',
    'roofs',
    'rooftop',
    'rooftree',
    'roofy',
    'rooibos',
    'rook',
    'rookery',
    'rookie',
    'room',
    'roomer',
    'roomette',
    'roomful',
    'roomie',
    'roominess',
    'roommate',
    'roommates',
    'rooms',
    'roomy',
    'roosevelt',
    'rooseveltian',
    'roost',
    'rooster',
    'root',
    'rootage',
    'rootbound',
    'rooted',
    'rooter',
    'rooting',
    'rootle',
    'rootless',
    'rootlet',
    'roots',
    'rootstalk',
    'rootstock',
    'rootstocks',
    'rope',
    'ropebark',
    'roped',
    'ropedancer',
    'ropemaker',
    'roper',
    'ropes',
    'ropewalk',
    'ropewalker',
    'ropeway',
    'ropey',
    'rophy',
    'ropiness',
    'roping',
    'ropy',
    'roquefort',
    'roquette',
    'roridula',
    'roridulaceae',
    'rorippa',
    'rorqual',
    'rorschach',
    'rosa',
    'rosacea',
    'rosaceae',
    'rosaceous',
    'rosales',
    'rosaries',
    'rosario',
    'rosary',
    'rose',
    'roseate',
    'roseau',
    'rosebay',
    'rosebud',
    'rosebush',
    'rosefish',
    'rosehip',
    'roselle',
    'rosellinia',
    'rosemaling',
    'rosemary',
    'roseola',
    'roses',
    'rosetta',
    'rosette',
    'rosettes',
    'rosewood',
    'rosh',
    'rosicrucian',
    'rosicrucianism',
    'rosicrucians',
    'rosid',
    'rosidae',
    'rosilla',
    'rosin',
    'rosiness',
    'rosinweed',
    'rosita',
    'rosmarinus',
    'ross',
    'rossbach',
    'rossetti',
    'rossini',
    'rostand',
    'roster',
    'rostock',
    'rostov',
    'rostrate',
    'rostrum',
    'roswell',
    'rosy',
    'rot',
    'rota',
    'rotarian',
    'rotary',
    'rotatable',
    'rotate',
    'rotated',
    'rotates',
    'rotating',
    'rotation',
    'rotational',
    'rotations',
    'rotatory',
    'rotavirus',
    'rotc',
    'rote',
    'rotenone',
    'rotgut',
    'roth',
    'rothko',
    'rothschild',
    'rotifer',
    'rotifera',
    'rotifers',
    'rotisserie',
    'rotl',
    'rotogravure',
    'rotor',
    'rotors',
    'rots',
    'rotted',
    'rotten',
    'rottenness',
    'rottenstone',
    'rotter',
    'rotterdam',
    'rotting',
    'rottweiler',
    'rotund',
    'rotunda',
    'rotundity',
    'rotundness',
    'rouble',
    'roue',
    'rouge',
    'rougeberry',
    'rouged',
    'rough',
    'roughage',
    'roughcast',
    'roughdried',
    'roughen',
    'roughened',
    'roughhewn',
    'roughhouse',
    'roughish',
    'roughleg',
    'roughly',
    'roughneck',
    'roughness',
    'roughrider',
    'roughshod',
    'roulade',
    'rouleau',
    'roulette',
    'roumania',
    'roumanian',
    'round',
    'roundabout',
    'rounded',
    'roundedness',
    'roundel',
    'roundelay',
    'rounder',
    'rounders',
    'roundhead',
    'roundheaded',
    'roundhouse',
    'rounding',
    'roundish',
    'roundness',
    'rounds',
    'roundsman',
    'roundtable',
    'roundup',
    'roundworm',
    'roundworms',
    'rous',
    'rouse',
    'roused',
    'rouser',
    'rouses',
    'rousing',
    'rousseau',
    'rousseauan',
    'roustabout',
    'rout',
    'route',
    'routed',
    'routemarch',
    'router',
    'routes',
    'routine',
    'routinely',
    'routing',
    'roux',
    'rove',
    'rover',
    'roving',
    'row',
    'rowan',
    'rowanberry',
    'rowboat',
    'rowdiness',
    'rowdy',
    'rowdyism',
    'rowed',
    'rowel',
    'rower',
    'rowers',
    'rowing',
    'rowlock',
    'rowlocks',
    'rows',
    'royal',
    'royalism',
    'royalist',
    'royalists',
    'royalties',
    'royalty',
    'royce',
    'roystonea',
    'rozelle',
    'rpm',
    'rtlt',
    'ru',
    'ruanda',
    'ruandan',
    'rub',
    'rubato',
    'rubbed',
    'rubber',
    'rubberise',
    'rubberize',
    'rubberized',
    'rubberlike',
    'rubberneck',
    'rubbernecked',
    'rubbernecker',
    'rubbers',
    'rubberstamp',
    'rubbery',
    'rubbing',
    'rubbish',
    'rubbishy',
    'rubble',
    'rubdown',
    'rube',
    'rubefacient',
    'rubel',
    'rubella',
    'rubens',
    'rubeola',
    'rubia',
    'rubiaceae',
    'rubiales',
    'rubicelle',
    'rubicon',
    'rubicund',
    'rubidium',
    'rubies',
    'rubify',
    'rubinstein',
    'ruble',
    'rubles',
    'rubor',
    'rubric',
    'rubricate',
    'rubricated',
    'rubrics',
    'rubs',
    'rubus',
    'ruby',
    'ruck',
    'ruckle',
    'rucksack',
    'ruckus',
    'ruction',
    'rudaceous',
    'rudapithecus',
    'rudbeckia',
    'rudd',
    'rudder',
    'rudderfish',
    'rudderless',
    'rudderpost',
    'rudders',
    'rudderstock',
    'ruddiness',
    'ruddle',
    'ruddles',
    'rudds',
    'ruddy',
    'rude',
    'rudeness',
    'rudiment',
    'rudimentary',
    'rudiments',
    'rudolf',
    'rudolph',
    'rudra',
    'rudyard',
    'rue',
    'rueful',
    'ruefulness',
    'ruf',
    'ruff',
    'ruffed',
    'ruffian',
    'ruffianism',
    'ruffianly',
    'ruffle',
    'ruffled',
    'ruffles',
    'ruffling',
    'ruffs',
    'rug',
    'ruga',
    'rugby',
    'rugelach',
    'rugged',
    'ruggedisation',
    'ruggedise',
    'ruggedization',
    'ruggedize',
    'ruggedized',
    'ruggedness',
    'ruggelach',
    'rugger',
    'rugose',
    'rugs',
    'rugulah',
    'ruhr',
    'ruin',
    'ruination',
    'ruined',
    'ruiner',
    'ruining',
    'ruinous',
    'ruinously',
    'ruins',
    'rule',
    'ruled',
    'ruler',
    'rulers',
    'rulership',
    'rules',
    'ruling',
    'ruly',
    'rum',
    'rumania',
    'rumanian',
    'rumansh',
    'rumba',
    'rumble',
    'rumbling',
    'rumblings',
    'rumbustious',
    'rumen',
    'rumex',
    'ruminant',
    'ruminantia',
    'ruminants',
    'ruminate',
    'rumination',
    'ruminative',
    'ruminator',
    'rummage',
    'rummaged',
    'rummer',
    'rummy',
    'rumohra',
    'rumor',
    'rumored',
    'rumormonger',
    'rumors',
    'rumour',
    'rumourmonger',
    'rump',
    'rumpelstiltskin',
    'rumple',
    'rumpled',
    'rumpus',
    'rumrunner',
    'run',
    'runabout',
    'runaway',
    'runch',
    'runcinate',
    'rundle',
    'rundown',
    'rundstedt',
    'rune',
    'rung',
    'rungs',
    'runic',
    'runnel',
    'runner',
    'runners',
    'runniness',
    'running',
    'runny',
    'runoff',
    'runproof',
    'runs',
    'runt',
    'runtiness',
    'runty',
    'runup',
    'runups',
    'runway',
    'runways',
    'runyon',
    'rupee',
    'rupert',
    'rupestral',
    'rupiah',
    'rupicapra',
    'rupicola',
    'rupicolous',
    'ruptiliocarpon',
    'rupture',
    'ruptured',
    'ruptures',
    'rupturewort',
    'rupturing',
    'rural',
    'ruralism',
    'ruralist',
    'rurality',
    'ruritania',
    'ruritanian',
    'rus',
    'ruscaceae',
    'ruscus',
    'ruse',
    'rush',
    'rushdie',
    'rushed',
    'rusher',
    'rushes',
    'rushing',
    'rushlight',
    'rushlike',
    'rushmore',
    'rushy',
    'rusk',
    'ruskin',
    'russel',
    'russell',
    'russet',
    'russia',
    'russian',
    'russians',
    'russula',
    'russulaceae',
    'rust',
    'rustbelt',
    'rusted',
    'rustic',
    'rusticate',
    'rusticated',
    'rustication',
    'rusticism',
    'rusticity',
    'rustics',
    'rustiness',
    'rusting',
    'rustle',
    'rustler',
    'rustless',
    'rustling',
    'rustproof',
    'rustproofed',
    'rusts',
    'rusty',
    'rut',
    'ruta',
    'rutabaga',
    'rutaceae',
    'rutgers',
    'ruth',
    'ruthenium',
    'rutherford',
    'rutherfordium',
    'ruthful',
    'ruthfulness',
    'ruthless',
    'ruthlessness',
    'rutile',
    'rutilus',
    'rutland',
    'rutledge',
    'rutted',
    'rutting',
    'ruttish',
    'rutty',
    'rv',
    'rwanda',
    'rwandan',
    'rya',
    'rydberg',
    'rye',
    'ryegrass',
    'rynchopidae',
    'rynchops',
    'rypticus',
    'ryukyu',
    'ryukyuan']
