
#!/usr/bin/env python
# -*- coding: UTF-8 -*-


d_enclictics = {
    "can't": [
        'can',
        'not'
    ],
    "could've": [
        'could',
        'have'
    ],
    "everyone's": [
        'everyone',
        'has'
    ],
    "he'd": [
        'he',
        'would'
    ],
    "he'll": [
        'he',
        'will'
    ],
    "he's": [
        'he',
        'is'
    ],
    "here's": [
        'here',
        'is'
    ],
    "how've": [
        'how',
        'have'
    ],
    "i'll": [
        'i',
        'will'
    ],
    "i'm": [
        'I',
        'am'
    ],
    "it's": [
        'it',
        'is'
    ],
    "let's": [
        'let',
        'us'
    ],
    "she'd": [
        'she',
        'would'
    ],
    "she's": [
        'she',
        'is'
    ],
    "should've": [
        'should',
        'have'
    ],
    "that's": [
        'that',
        'is'
    ],
    "the're": [
        'there'
    ],
    "there's": [
        'there',
        'has'
    ],
    "they'd": [
        'they',
        'would'
    ],
    "they'll": [
        'they',
        'will'
    ],
    "they're": [
        'they',
        'are'
    ],
    "they've": [
        'they',
        'have'
    ],
    "wander'd": [
        'wandered'
    ],
    "we'd": [
        'we',
        'had'
    ],
    "we'll": [
        'we',
        'will'
    ],
    "we're": [
        'we',
        'are'
    ],
    "what're": [
        'what',
        'are'
    ],
    "what's": [
        'what',
        'is'
    ],
    "where's": [
        'where',
        'is'
    ],
    "who's": [
        'who',
        'has'
    ],
    "why're": [
        'why',
        'are'
    ],
    "won't": [
        'will',
        'not'
    ],
    "would've": [
        'would',
        'have'
    ],
    "y'all": [
        'you',
        'all'
    ],
    "you'd": [
        'you',
        'would'
    ],
    "you're": [
        'you',
        'are'
    ],
    "you've": [
        'you',
        'have'
    ]
}
